import {
  panel_styles_default
} from "./chunk.7XQ7L7FU.js";
import {
  animateTo,
  shimKeyframesHeightAuto,
  stopAnimations,
  waitForEvent
} from "./chunk.ZSWHGSJ7.js";
import {
  getAnimation,
  setDefaultAnimation
} from "./chunk.25TVLSB6.js";
import {
  HasSlotController
} from "./chunk.OW5NIGGX.js";
import {
  LocalizeController
} from "./chunk.AFESEORB.js";
import {
  LynkIcon
} from "./chunk.4HTNL6JH.js";
import {
  watch
} from "./chunk.JMZM2TDT.js";
import {
  LynkAccordion
} from "./chunk.4VUSA5CU.js";
import {
  e
} from "./chunk.4VMW2AZ2.js";
import {
  LynkElement,
  e as e2,
  n
} from "./chunk.2EAGJTRH.js";
import {
  component_styles_default
} from "./chunk.V6UNAAZX.js";
import {
  x
} from "./chunk.Z3O73C4R.js";
import {
  __decorateClass
} from "./chunk.W27M6RDR.js";

// src/components/panel/panel.component.ts
var LynkPanel = class extends LynkElement {
  constructor() {
    super(...arguments);
    this.hasSlotController = new HasSlotController(this, "prefix", "suffix", "footer");
    this.localize = new LocalizeController(this);
    this.expanded = false;
    this.accordion = false;
    this.disabled = false;
    this.toggleTrigger = "header";
    this.toggleSuffix = false;
    this.toggleIconPlacement = "end";
    this.noHeader = false;
  }
  connectedCallback() {
    super.connectedCallback();
    if (this.hasParentAccordion()) {
      this.accordion = true;
    }
    if (!this.accordion) {
      this.expanded = true;
    }
  }
  firstUpdated() {
    this.body.hidden = !this.expanded;
    this.body.style.height = this.expanded ? "auto" : "0";
  }
  // Checks whether the item is nested into an item
  hasParentAccordion() {
    const parent = this.parentElement;
    return parent instanceof LynkAccordion;
  }
  handleToggleTriggerClick() {
    if (!this.disabled && this.accordion) {
      if (this.expanded) {
        this.collapse();
      } else {
        this.expand();
      }
      this.header.focus();
    }
  }
  handlePrefixSuffixClick(event) {
    event.stopPropagation();
  }
  handlePrefixSuffixKeyDown(event) {
    event.stopPropagation();
  }
  handleHeaderKeyDown(event) {
    if (event.key === "Enter" || event.key === " ") {
      event.preventDefault();
      if (this.expanded) {
        this.collapse();
      } else {
        this.expand();
      }
    }
    if (event.key === "ArrowUp" || event.key === "ArrowLeft") {
      event.preventDefault();
      this.collapse();
    }
    if (event.key === "ArrowDown" || event.key === "ArrowRight") {
      event.preventDefault();
      this.expand();
    }
  }
  async handleExpandedChange() {
    if (this.expanded) {
      const lExpand = this.emit("ev-expand", { cancelable: true });
      if (lExpand.defaultPrevented) {
        this.expanded = false;
        return;
      }
      await stopAnimations(this.body);
      this.body.hidden = false;
      const { keyframes, options } = getAnimation(this, "panel.expand", { dir: this.localize.dir() });
      await animateTo(this.body, shimKeyframesHeightAuto(keyframes, this.body.scrollHeight), options);
      this.body.style.height = "auto";
      this.emit("ev-after-expand");
    } else {
      const lCollapse = this.emit("ev-collapse", { cancelable: true });
      if (lCollapse.defaultPrevented) {
        this.expanded = true;
        return;
      }
      await stopAnimations(this.body);
      const { keyframes, options } = getAnimation(this, "panel.collapse", { dir: this.localize.dir() });
      await animateTo(this.body, shimKeyframesHeightAuto(keyframes, this.body.scrollHeight), options);
      this.body.hidden = true;
      this.body.style.height = "auto";
      this.emit("ev-after-collapse");
    }
  }
  /** Shows the panel. */
  async expand() {
    if (this.expanded || this.disabled) {
      return void 0;
    }
    this.expanded = true;
    return waitForEvent(this, "ev-after-expand");
  }
  /** Hides the panel */
  async collapse() {
    if (!this.expanded || this.disabled) {
      return void 0;
    }
    this.expanded = false;
    return waitForEvent(this, "ev-after-collapse");
  }
  render() {
    const isRtl = this.localize.dir() === "rtl";
    return x`
      <div
        part="base"
        class=${e({
      panel: true,
      "panel--disabled": this.disabled,
      "panel--expanded": this.expanded,
      "panel--accordion": this.accordion,
      "panel--rtl": isRtl,
      "panel--toggle-suffix": this.toggleSuffix,
      "panel--no-header": this.noHeader,
      "panel--has-prefix": this.hasSlotController.test("prefix"),
      "panel--has-suffix": this.hasSlotController.test("suffix"),
      "panel--has-footer": this.hasSlotController.test("footer")
    })}
      >
        ${!this.noHeader ? x`
              <header
                part="header"
                id="header"
                class=${e({
      panel__header: true,
      "panel__header--trigger": this.toggleTrigger === "header"
    })}
                role="button"
                aria-expanded=${this.expanded ? "true" : "false"}
                aria-controls="content"
                aria-disabled=${this.disabled ? "true" : "false"}
                tabindex=${this.disabled ? "-1" : "0"}
                @click=${this.toggleTrigger === "header" ? this.handleToggleTriggerClick : null}
                @keydown=${this.handleHeaderKeyDown}
              >
                <slot
                  name="prefix"
                  part="prefix"
                  class="panel__prefix"
                  @click=${this.handlePrefixSuffixClick}
                  @keydown=${this.handlePrefixSuffixKeyDown}
                ></slot>
                <slot
                  name="heading"
                  part="heading"
                  class=${e({
      panel__heading: true,
      "panel__heading--trigger": this.toggleTrigger === "heading"
    })}
                  @click=${this.toggleTrigger === "heading" ? this.handleToggleTriggerClick : null}
                >
                  ${this.heading}
                </slot>
                <slot
                  name="suffix"
                  part="suffix"
                  class="panel__suffix"
                  @click=${this.handlePrefixSuffixClick}
                  @keydown=${this.handlePrefixSuffixKeyDown}
                ></slot>

                ${this.accordion ? x`
                      <span
                        part="toggle-icon"
                        class=${e({
      "panel__toggle-icon": true,
      "panel__toggle-icon--start": this.toggleIconPlacement === "start",
      "panel__toggle-icon--end": this.toggleIconPlacement === "end",
      "panel__toggle-icon--hidden": this.toggleIconPlacement === "hidden",
      "panel__toggle-icon--trigger": this.toggleTrigger === "heading" || this.toggleTrigger === "icon"
    })}
                        @click=${this.toggleTrigger === "heading" || this.toggleTrigger === "icon" ? this.handleToggleTriggerClick : null}
                      >
                        <slot name="expand-icon">
                          <lynk-icon library="system" name=${isRtl ? "chevron-left" : "chevron-right"}></lynk-icon>
                        </slot>
                        <slot name="collapse-icon">
                          <lynk-icon library="system" name=${isRtl ? "chevron-left" : "chevron-right"}></lynk-icon>
                        </slot>
                      </span>
                    ` : ""}
              </header>
            ` : ""}

        <div class="panel__body">
          <div part="content" id="content" class="panel__content" role="region" aria-labelledby="header">
            <slot></slot>
          </div>

          <slot name="footer" part="footer" class="panel__footer"></slot>
        </div>
      </div>
    `;
  }
};
LynkPanel.styles = [component_styles_default, panel_styles_default];
LynkPanel.dependencies = { "lynk-popup": LynkIcon };
__decorateClass([
  e2(".panel")
], LynkPanel.prototype, "panel", 2);
__decorateClass([
  e2(".panel__header")
], LynkPanel.prototype, "header", 2);
__decorateClass([
  e2(".panel__body")
], LynkPanel.prototype, "body", 2);
__decorateClass([
  e2(".panel__toggle-icon-slot")
], LynkPanel.prototype, "toggleIconSlot", 2);
__decorateClass([
  n({ type: Boolean, reflect: true })
], LynkPanel.prototype, "expanded", 2);
__decorateClass([
  n({ type: Boolean, reflect: true })
], LynkPanel.prototype, "accordion", 2);
__decorateClass([
  n({ type: Boolean, reflect: true })
], LynkPanel.prototype, "disabled", 2);
__decorateClass([
  n()
], LynkPanel.prototype, "heading", 2);
__decorateClass([
  n({ attribute: "toggle-trigger", reflect: true })
], LynkPanel.prototype, "toggleTrigger", 2);
__decorateClass([
  n({ attribute: "toggle-suffix", type: Boolean, reflect: true })
], LynkPanel.prototype, "toggleSuffix", 2);
__decorateClass([
  n({ attribute: "toggle-icon-placement", reflect: true })
], LynkPanel.prototype, "toggleIconPlacement", 2);
__decorateClass([
  n({ attribute: "no-header", type: Boolean, reflect: true })
], LynkPanel.prototype, "noHeader", 2);
__decorateClass([
  watch("expanded", { waitUntilFirstUpdate: true })
], LynkPanel.prototype, "handleExpandedChange", 1);
setDefaultAnimation("panel.expand", {
  keyframes: [
    { height: "0", opacity: "0" },
    { height: "auto", opacity: "1" }
  ],
  options: { duration: 250, easing: "linear" }
});
setDefaultAnimation("panel.collapse", {
  keyframes: [
    { height: "auto", opacity: "1" },
    { height: "0", opacity: "0" }
  ],
  options: { duration: 250, easing: "linear" }
});

export {
  LynkPanel
};
