import {
  radio_group_styles_default
} from "./chunk.CX2VAHVQ.js";
import {
  LynkTooltip
} from "./chunk.ZYCYIAT3.js";
import {
  form_control_styles_default
} from "./chunk.GJLY5JLB.js";
import {
  FormControlController,
  customErrorValidityState,
  validValidityState,
  valueMissingValidityState
} from "./chunk.UDRCCTEL.js";
import {
  LynkButtonGroup
} from "./chunk.KPK6YG2V.js";
import {
  HasSlotController
} from "./chunk.OW5NIGGX.js";
import {
  watch
} from "./chunk.JMZM2TDT.js";
import {
  e
} from "./chunk.4VMW2AZ2.js";
import {
  LynkElement,
  e as e2,
  n,
  r
} from "./chunk.2EAGJTRH.js";
import {
  component_styles_default
} from "./chunk.V6UNAAZX.js";
import {
  x
} from "./chunk.Z3O73C4R.js";
import {
  __decorateClass
} from "./chunk.W27M6RDR.js";

// src/components/radio-group/radio-group.component.ts
var LynkRadioGroup = class extends LynkElement {
  constructor() {
    super(...arguments);
    this.formControlController = new FormControlController(this);
    this.hasSlotController = new HasSlotController(this, "help-text", "help-tip", "label");
    this.customValidityMessage = "";
    this.hasButtonGroup = false;
    this.errorMessage = "";
    this.defaultValue = "";
    this.label = "";
    this.helpText = "";
    this.helpTip = "";
    this.name = "option";
    this.value = "";
    this.size = "medium";
    this.form = "";
    this.required = false;
    this.state = "default";
  }
  /** Gets the validity state object */
  get validity() {
    const isRequiredAndEmpty = this.required && !this.value;
    const hasCustomValidityMessage = this.customValidityMessage !== "";
    if (hasCustomValidityMessage) {
      return customErrorValidityState;
    } else if (isRequiredAndEmpty) {
      return valueMissingValidityState;
    }
    return validValidityState;
  }
  /** Gets the validation message */
  get validationMessage() {
    const isRequiredAndEmpty = this.required && !this.value;
    const hasCustomValidityMessage = this.customValidityMessage !== "";
    if (hasCustomValidityMessage) {
      return this.customValidityMessage;
    } else if (isRequiredAndEmpty) {
      return this.validationInput.validationMessage;
    }
    return "";
  }
  connectedCallback() {
    super.connectedCallback();
    this.defaultValue = this.value;
  }
  firstUpdated() {
    this.formControlController.updateValidity();
  }
  getAllRadios() {
    return [...this.querySelectorAll("lynk-radio, lynk-radio-button")];
  }
  handleRadioClick(event) {
    const target = event.target.closest("lynk-radio, lynk-radio-button");
    const radios = this.getAllRadios();
    const oldValue = this.value;
    if (!target || target.disabled) {
      return;
    }
    this.value = target.value;
    radios.forEach((radio) => radio.checked = radio === target);
    if (this.value !== oldValue) {
      this.emit("ev-change");
      this.emit("ev-input");
    }
  }
  handleKeyDown(event) {
    var _a;
    if (!["ArrowUp", "ArrowDown", "ArrowLeft", "ArrowRight", " "].includes(event.key)) {
      return;
    }
    const radios = this.getAllRadios().filter((radio) => !radio.disabled);
    const checkedRadio = (_a = radios.find((radio) => radio.checked)) != null ? _a : radios[0];
    const incr = event.key === " " ? 0 : ["ArrowUp", "ArrowLeft"].includes(event.key) ? -1 : 1;
    const oldValue = this.value;
    let index = radios.indexOf(checkedRadio) + incr;
    if (index < 0) {
      index = radios.length - 1;
    }
    if (index > radios.length - 1) {
      index = 0;
    }
    this.getAllRadios().forEach((radio) => {
      radio.checked = false;
      if (!this.hasButtonGroup) {
        radio.setAttribute("tabindex", "-1");
      }
    });
    this.value = radios[index].value;
    radios[index].checked = true;
    if (!this.hasButtonGroup) {
      radios[index].setAttribute("tabindex", "0");
      radios[index].focus();
    } else {
      radios[index].shadowRoot.querySelector("button").focus();
    }
    if (this.value !== oldValue) {
      this.emit("ev-change");
      this.emit("ev-input");
    }
    event.preventDefault();
  }
  handleLabelClick() {
    this.focus();
  }
  handleInvalid(event) {
    this.formControlController.setValidity(false);
    this.formControlController.emitInvalidEvent(event);
  }
  async syncRadioElements() {
    var _a, _b;
    const radios = this.getAllRadios();
    await Promise.all(
      // Sync the checked state and size
      radios.map(async (radio) => {
        await radio.updateComplete;
        radio.checked = radio.value === this.value;
        radio.size = this.size;
      })
    );
    this.hasButtonGroup = radios.some((radio) => radio.tagName.toLowerCase() === "lynk-radio-button");
    if (radios.length > 0 && !radios.some((radio) => radio.checked)) {
      if (this.hasButtonGroup) {
        const buttonRadio = (_a = radios[0].shadowRoot) == null ? void 0 : _a.querySelector("button");
        if (buttonRadio) {
          buttonRadio.setAttribute("tabindex", "0");
        }
      } else {
        radios[0].setAttribute("tabindex", "0");
      }
    }
    if (this.hasButtonGroup) {
      const buttonGroup = (_b = this.shadowRoot) == null ? void 0 : _b.querySelector("lynk-button-group");
      if (buttonGroup) {
        buttonGroup.disableRole = true;
      }
    }
  }
  syncRadios() {
    if (customElements.get("lynk-radio") && customElements.get("lynk-radio-button")) {
      this.syncRadioElements();
      return;
    }
    if (customElements.get("lynk-radio")) {
      this.syncRadioElements();
    } else {
      customElements.whenDefined("lynk-radio").then(() => this.syncRadios());
    }
    if (customElements.get("lynk-radio-button")) {
      this.syncRadioElements();
    } else {
      customElements.whenDefined("lynk-radio-button").then(() => this.syncRadios());
    }
  }
  updateCheckedRadio() {
    const radios = this.getAllRadios();
    radios.forEach((radio) => radio.checked = radio.value === this.value);
    this.formControlController.setValidity(this.validity.valid);
  }
  handleSizeChange() {
    this.syncRadios();
  }
  handleValueChange() {
    if (this.hasUpdated) {
      this.updateCheckedRadio();
    }
  }
  /** Checks for validity but does not show a validation message. Returns `true` when valid and `false` when invalid. */
  checkValidity() {
    const isRequiredAndEmpty = this.required && !this.value;
    const hasCustomValidityMessage = this.customValidityMessage !== "";
    if (isRequiredAndEmpty || hasCustomValidityMessage) {
      this.formControlController.emitInvalidEvent();
      return false;
    }
    return true;
  }
  /** Gets the associated form, if one exists. */
  getForm() {
    return this.formControlController.getForm();
  }
  /** Checks for validity and shows the browser's validation message if the control is invalid. */
  reportValidity() {
    const isValid = this.validity.valid;
    this.errorMessage = this.customValidityMessage || isValid ? "" : this.validationInput.validationMessage;
    this.formControlController.setValidity(isValid);
    this.validationInput.hidden = true;
    clearTimeout(this.validationTimeout);
    if (!isValid) {
      this.validationInput.hidden = false;
      this.validationInput.reportValidity();
      this.validationTimeout = setTimeout(() => this.validationInput.hidden = true, 1e4);
    }
    return isValid;
  }
  /** Sets a custom validation message. Pass an empty string to restore validity. */
  setCustomValidity(message = "") {
    this.customValidityMessage = message;
    this.errorMessage = message;
    this.validationInput.setCustomValidity(message);
    this.formControlController.updateValidity();
  }
  /** Sets focus on the radio-group. */
  focus(options) {
    const radios = this.getAllRadios();
    const checked = radios.find((radio) => radio.checked);
    const firstEnabledRadio = radios.find((radio) => !radio.disabled);
    const radioToFocus = checked || firstEnabledRadio;
    if (radioToFocus) {
      radioToFocus.focus(options);
    }
  }
  render() {
    const hasLabelSlot = this.hasSlotController.test("label");
    const hasHelpTextSlot = this.hasSlotController.test("help-text");
    const hasHelpTipSlot = this.hasSlotController.test("help-tip");
    const hasLabel = this.label ? true : !!hasLabelSlot;
    const hasHelpText = this.helpText ? true : !!hasHelpTextSlot;
    const hasHelpTip = this.helpTip ? true : !!hasHelpTipSlot;
    const defaultSlot = x`
      <slot
        class=${e({
      "radio-group__control": true,
      "radio-group__control--has-button-group": this.hasButtonGroup
    })}
        @slotchange=${this.syncRadios}
        @click=${this.handleRadioClick}
        @keydown=${this.handleKeyDown}
      ></slot>
    `;
    return x`
      <fieldset
        part="form-control"
        class=${e({
      "form-control": true,
      "form-control--medium": true,
      "form-control--radio-group": true,
      "form-control--has-label": hasLabel,
      "form-control--has-help-text": hasHelpText,
      "form-control--has-error": this.state === "error" || this.hasAttribute("data-user-invalid"),
      "form-control--has-warning": this.state === "warning",
      "form-control--has-success": this.state === "success"
    })}
        role="radiogroup"
        aria-labelledby="label"
        aria-describedby="help-text"
        aria-errormessage="error-message"
      >
        <label
          id="label"
          part="form-control-label"
          class=${e({
      "form-control__label": true
    })}
          aria-hidden=${hasLabel ? "false" : "true"}
          @click=${this.handleLabelClick}
        >
          <slot name="label">${this.label}</slot>

          ${this.required ? x`
                <lynk-tooltip content="Required" hoist>
                  <lynk-icon style="font-size: 9px;" name="asterisk" library="system"></lynk-icon>
                </lynk-tooltip>
              ` : ""}
          ${hasHelpTip ? x`
                <lynk-tooltip hoist>
                  <div slot="content">
                    <slot name="help-tip">${this.helpTip}</slot>
                  </div>
                  <lynk-icon style="font-size: 11px;" name="question-fill" library="system"></lynk-icon>
                </lynk-tooltip>
              ` : ""}
        </label>

        <div part="form-control-input" class="form-control-input">
          <div class="visually-hidden">
            <div id="error-message" aria-live="assertive">${this.errorMessage}</div>
            <label class="radio-group__validation">
              <input
                type="text"
                class="radio-group__validation-input"
                ?required=${this.required}
                tabindex="-1"
                hidden
                @invalid=${this.handleInvalid}
              />
            </label>
          </div>

          ${this.hasButtonGroup ? x`
                <lynk-button-group part="button-group" exportparts="base:button-group__base">
                  ${defaultSlot}
                </lynk-button-group>
              ` : defaultSlot}
        </div>

        <div
          part="form-control-help-text"
          id="help-text"
          class="form-control__help-text"
          aria-hidden=${hasHelpText ? "false" : "true"}
        >
          <slot name="help-text">${this.helpText}</slot>
        </div>
      </fieldset>
    `;
  }
};
LynkRadioGroup.styles = [component_styles_default, form_control_styles_default, radio_group_styles_default];
LynkRadioGroup.dependencies = { "lynk-button-group": LynkButtonGroup, "lynk-tooltip": LynkTooltip };
__decorateClass([
  e2("slot:not([name])")
], LynkRadioGroup.prototype, "defaultSlot", 2);
__decorateClass([
  e2(".radio-group__validation-input")
], LynkRadioGroup.prototype, "validationInput", 2);
__decorateClass([
  r()
], LynkRadioGroup.prototype, "hasButtonGroup", 2);
__decorateClass([
  r()
], LynkRadioGroup.prototype, "errorMessage", 2);
__decorateClass([
  r()
], LynkRadioGroup.prototype, "defaultValue", 2);
__decorateClass([
  n()
], LynkRadioGroup.prototype, "label", 2);
__decorateClass([
  n({ attribute: "help-text" })
], LynkRadioGroup.prototype, "helpText", 2);
__decorateClass([
  n({ attribute: "help-tip" })
], LynkRadioGroup.prototype, "helpTip", 2);
__decorateClass([
  n()
], LynkRadioGroup.prototype, "name", 2);
__decorateClass([
  n({ reflect: true })
], LynkRadioGroup.prototype, "value", 2);
__decorateClass([
  n({ reflect: true })
], LynkRadioGroup.prototype, "size", 2);
__decorateClass([
  n({ reflect: true })
], LynkRadioGroup.prototype, "form", 2);
__decorateClass([
  n({ type: Boolean, reflect: true })
], LynkRadioGroup.prototype, "required", 2);
__decorateClass([
  n({ reflect: true })
], LynkRadioGroup.prototype, "state", 2);
__decorateClass([
  watch("size", { waitUntilFirstUpdate: true })
], LynkRadioGroup.prototype, "handleSizeChange", 1);
__decorateClass([
  watch("value")
], LynkRadioGroup.prototype, "handleValueChange", 1);

export {
  LynkRadioGroup
};
