import {
  LynkIconButton
} from "./chunk.OI2YJPCU.js";
import {
  animateTo,
  stopAnimations,
  waitForEvent
} from "./chunk.ZSWHGSJ7.js";
import {
  getAnimation,
  setDefaultAnimation
} from "./chunk.25TVLSB6.js";
import {
  HasSlotController
} from "./chunk.OW5NIGGX.js";
import {
  LocalizeController
} from "./chunk.AFESEORB.js";
import {
  watch
} from "./chunk.JMZM2TDT.js";
import {
  alert_styles_default
} from "./chunk.JAE35DUS.js";
import {
  e
} from "./chunk.4VMW2AZ2.js";
import {
  LynkElement,
  e as e2,
  n,
  r
} from "./chunk.2EAGJTRH.js";
import {
  component_styles_default
} from "./chunk.V6UNAAZX.js";
import {
  x
} from "./chunk.Z3O73C4R.js";
import {
  __decorateClass
} from "./chunk.W27M6RDR.js";

// src/components/alert/alert.component.ts
var toastStack = Object.assign(document.createElement("div"), { className: "lynk-toast-stack" });
var LynkAlert = class extends LynkElement {
  constructor() {
    super(...arguments);
    this.hasSlotController = new HasSlotController(this, "icon", "suffix", "action");
    this.localize = new LocalizeController(this);
    this.open = false;
    this.closable = false;
    this.type = "primary";
    this.duration = Infinity;
    this.remainingTime = this.duration;
  }
  firstUpdated() {
    this.base.hidden = !this.open;
  }
  restartAutoHide() {
    this.handleCountdownChange();
    clearTimeout(this.autoHideTimeout);
    clearInterval(this.remainingTimeInterval);
    if (this.open && this.duration < Infinity) {
      this.autoHideTimeout = window.setTimeout(() => this.hide(), this.duration);
      this.remainingTime = this.duration;
      this.remainingTimeInterval = window.setInterval(() => {
        this.remainingTime -= 100;
      }, 100);
    }
  }
  pauseAutoHide() {
    var _a;
    (_a = this.countdownAnimation) == null ? void 0 : _a.pause();
    clearTimeout(this.autoHideTimeout);
    clearInterval(this.remainingTimeInterval);
  }
  resumeAutoHide() {
    var _a;
    if (this.duration < Infinity) {
      this.autoHideTimeout = window.setTimeout(() => this.hide(), this.remainingTime);
      this.remainingTimeInterval = window.setInterval(() => {
        this.remainingTime -= 100;
      }, 100);
      (_a = this.countdownAnimation) == null ? void 0 : _a.play();
    }
  }
  handleCountdownChange() {
    if (this.open && this.duration < Infinity && this.countdown) {
      const { countdownElement } = this;
      const start = "100%";
      const end = "0";
      this.countdownAnimation = countdownElement.animate([{ width: start }, { width: end }], {
        duration: this.duration,
        easing: "linear"
      });
    }
  }
  handleCloseClick() {
    this.hide();
  }
  async handleOpenChange() {
    if (this.open) {
      this.emit("ev-show");
      if (this.duration < Infinity) {
        this.restartAutoHide();
      }
      await stopAnimations(this.base);
      this.base.hidden = false;
      const { keyframes, options } = getAnimation(this, "alert.show", { dir: this.localize.dir() });
      await animateTo(this.base, keyframes, options);
      this.emit("ev-after-show");
    } else {
      this.emit("ev-hide");
      clearTimeout(this.autoHideTimeout);
      clearInterval(this.remainingTimeInterval);
      await stopAnimations(this.base);
      const { keyframes, options } = getAnimation(this, "alert.hide", { dir: this.localize.dir() });
      await animateTo(this.base, keyframes, options);
      this.base.hidden = true;
      this.emit("ev-after-hide");
    }
  }
  handleDurationChange() {
    this.restartAutoHide();
  }
  /** Shows the alert. */
  async show() {
    if (this.open) {
      return void 0;
    }
    this.open = true;
    return waitForEvent(this, "ev-after-show");
  }
  /** Hides the alert */
  async hide() {
    if (!this.open) {
      return void 0;
    }
    this.open = false;
    return waitForEvent(this, "ev-after-hide");
  }
  /**
   * Displays the alert as a toast notification. This will move the alert out of its position in the DOM and, when
   * dismissed, it will be removed from the DOM completely. By storing a reference to the alert, you can reuse it by
   * calling this method again. The returned promise will resolve after the alert is hidden.
   */
  async toast() {
    return new Promise((resolve) => {
      this.handleCountdownChange();
      if (toastStack.parentElement === null) {
        document.body.append(toastStack);
      }
      toastStack.appendChild(this);
      requestAnimationFrame(() => {
        this.clientWidth;
        this.show();
      });
      this.addEventListener(
        "ev-after-hide",
        () => {
          toastStack.removeChild(this);
          resolve();
          if (toastStack.querySelector("lynk-alert") === null) {
            toastStack.remove();
          }
        },
        { once: true }
      );
    });
  }
  render() {
    return x`
      <div
        part="base"
        class=${e({
      alert: true,
      "alert--open": this.open,
      "alert--closable": this.closable,
      "alert--has-icon": this.hasSlotController.test("icon") || this.type === "info" || this.type === "neutral" || this.type === "success" || this.type === "warning" || this.type === "danger",
      "alert--primary": this.type === "primary" || this.type === "info",
      "alert--success": this.type === "success",
      "alert--neutral": this.type === "neutral",
      "alert--warning": this.type === "warning",
      "alert--danger": this.type === "danger"
    })}
        role="alert"
        aria-hidden=${this.open ? "false" : "true"}
        @mouseenter=${this.pauseAutoHide}
        @mouseleave=${this.resumeAutoHide}
      >
        <div part="icon" class="alert__icon">
          <slot name="icon">
            ${this.type ? x`
                  <lynk-icon
                    library="system"
                    name="${this.type === "info" ? "info-circle" : this.type === "neutral" ? "question-square" : this.type === "success" ? "check-circle" : this.type === "warning" ? "exclamation-triangle" : this.type === "danger" ? "exclamation-octagon" : ""}"
                  ></lynk-icon>
                ` : ""}
          </slot>
        </div>

        <div part="message" class="alert__message" aria-live="polite">
          <slot></slot>
        </div>

        ${this.hasSlotController.test("action") ? x`
              <span part="action" class="alert__action">
                <slot name="action"></slot>
              </span>
            ` : ""}
        ${this.closable ? x`
              <lynk-icon-button
                part="close-button"
                exportparts="base:close-button__base"
                class="alert__close-button"
                name="x"
                library="system"
                label=${this.localize.term("close")}
                @click=${this.handleCloseClick}
              ></lynk-icon-button>
            ` : ""}

        <div role="timer" class="alert__timer">${this.remainingTime}</div>

        ${this.countdown ? x`
              <div
                class=${e({
      alert__countdown: true,
      "alert__countdown--ltr": this.countdown === "ltr"
    })}
              >
                <div class="alert__countdown-elapsed"></div>
              </div>
            ` : ""}
      </div>
    `;
  }
};
LynkAlert.styles = [component_styles_default, alert_styles_default];
LynkAlert.dependencies = { "lynk-icon-button": LynkIconButton };
__decorateClass([
  e2('[part="base"]')
], LynkAlert.prototype, "base", 2);
__decorateClass([
  e2(".alert__countdown-elapsed")
], LynkAlert.prototype, "countdownElement", 2);
__decorateClass([
  n({ type: Boolean, reflect: true })
], LynkAlert.prototype, "open", 2);
__decorateClass([
  n({ type: Boolean, reflect: true })
], LynkAlert.prototype, "closable", 2);
__decorateClass([
  n({ reflect: true })
], LynkAlert.prototype, "type", 2);
__decorateClass([
  n({ type: Number })
], LynkAlert.prototype, "duration", 2);
__decorateClass([
  n({ type: String, reflect: true })
], LynkAlert.prototype, "countdown", 2);
__decorateClass([
  r()
], LynkAlert.prototype, "remainingTime", 2);
__decorateClass([
  watch("open", { waitUntilFirstUpdate: true })
], LynkAlert.prototype, "handleOpenChange", 1);
__decorateClass([
  watch("duration")
], LynkAlert.prototype, "handleDurationChange", 1);
setDefaultAnimation("alert.show", {
  keyframes: [
    { opacity: 0, scale: 0.8 },
    { opacity: 1, scale: 1 }
  ],
  options: { duration: 250, easing: "ease" }
});
setDefaultAnimation("alert.hide", {
  keyframes: [
    { opacity: 1, scale: 1 },
    { opacity: 0, scale: 0.8 }
  ],
  options: { duration: 250, easing: "ease" }
});

export {
  LynkAlert
};
