import LynkElement from '../../internal/lynk-element.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary Badges are used to draw attention and display statuses or counts.
 * @documentation https://lynk.design/components/badge
 * @since 1.0.0
 * @status stable
 *
 * @slot - The badge's content.
 *
 * @csspart base - The component's internal wrapper.
 *
 * @cssproperty --background-color - The badges background and pulse color.
 * @cssproperty --color - The badges text color.
 * @cssproperty --pulse-speed - The badges pulse speed in seconds or ms. Default is 1.5s.
 *
 */
export default class LynkBadge extends LynkElement {
    static styles: CSSResultGroup;
    /** The badge's variant. */
    type?: 'primary' | 'accent' | 'success' | 'neutral' | 'warning' | 'danger' | 'info';
    /** Draws a pill-style badge with rounded edges. */
    pill: boolean;
    /** Makes the badge pulsate to draw attention. */
    pulse: boolean;
    render(): import("lit").TemplateResult<1>;
}
