import LynkElement from '../../internal/lynk-element.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary The Grid component helps create visual consistency and structure between layouts while allowing flexibility across a wide variety of designs. It uses [CSS's Flexible Box module](https://www.w3.org/TR/css-flexbox-1/) for high flexibility.
 * @documentation https://lynk.design/components/grid
 * @since 1.0.0
 * @status experimental
 *
 * @slot - The default slot.
 *
 * @csspart base - The component's internal wrapper.
 *
 * @cssproperty --width - Set a custom width for the grid container element. Defaults to 100%.
 */
export default class LynkGrid extends LynkElement {
    static styles: CSSResultGroup;
    /** A container of grid items */
    container: boolean;
    /** A singular grid item */
    item: boolean;
    /** The flow direction of grid items, requires container property being set */
    direction?: 'row' | 'row-reverse' | 'column' | 'column-revers';
    /** How to justify grid items, requires container property */
    justify?: 'start' | 'center' | 'end' | 'between' | 'around' | 'evenly';
    /** Hot to align grid items to each-other, requires container property */
    align?: 'start' | 'center' | 'end' | 'stretch' | 'baseline';
    /** The width of a grid item. Requires item property  being set. This can be a single string or an array. */
    span?: string;
    /** The space between grid items. Uses spacing token sizes.  */
    gap: '0' | 'tiny' | '2x-small' | 'x-small' | 'small' | 'base' | 'medium' | 'large' | 'x-large' | '2x-large' | '3x-large';
    getBreakpointClasses(): string;
    render(): import("lit").TemplateResult<1>;
}
