import LynkElement from '../../internal/lynk-element.js';
import LynkIcon from '../icon/icon.component.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary Icons buttons are simple, icon-only buttons that can be used for actions and in toolbars.
 * @documentation https://lynk.design/components/icon-button
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon
 *
 * @event ev-blur - Emitted when the icon button loses focus.
 * @event ev-click - Emitted when the button is clicked.
 * @event ev-focus - Emitted when the icon button gains focus.
 *
 * @csspart base - The component's internal wrapper.
 */
export default class LynkIconButton extends LynkElement {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-icon': typeof LynkIcon;
    };
    button: HTMLButtonElement | HTMLLinkElement;
    private hasFocus;
    private readonly hasSlotController;
    /** The button's color. */
    color: 'default' | 'primary' | 'success' | 'neutral' | 'warning' | 'danger';
    /** The name of the icon to draw. */
    name?: string;
    /** The name of a registered custom icon library. */
    library?: string;
    /** An external URL of an SVG file. */
    src?: string;
    /** When set, the underlying button will be rendered as an `<a>` with this `href` instead of a `<button>`. */
    href?: string;
    /** Tells the browser where to open the link. Only used when `href` is set. */
    target?: '_blank' | '_parent' | '_self' | '_top';
    /** Tells the browser to download the linked file as this filename. Only used when `href` is set. */
    download?: string;
    /**
     * A description that gets read by screen readers and other assistive devices. For optimal accessibility, you should
     * always include a label that describes what the icon button does.
     */
    label: string;
    /** Disables the button. */
    disabled: boolean;
    /** Simulates a click on the icon button. */
    click(): void;
    /** Sets focus on the icon button. */
    focus(options?: FocusOptions): void;
    /** Removes focus from the icon button. */
    blur(): void;
    handleBlur(): void;
    handleFocus(): void;
    handleClick(event: MouseEvent): void;
    render(): import("lit").TemplateResult;
}
