import LynkElement from '../../internal/lynk-element.js';
import LynkNavItem from '../nav-item/nav-item.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary Navs display a hierarchical menu of [nav items](/components/nav-item) for navigating within an app or page. Items with children can be expanded and collapsed as desired by the user.
 * @documentation https://lynk.design/components/nav
 * @since 1.0.0
 * @status stable
 *
 * @event {{ selection: LynkNavItem }} ev-select - Emitted when a nav item is selected.
 *
 * @slot - The nav's content, including nav items, nav groups, and dividers.
 *
 * @csspart base - The component's base wrapper.
 *
 * @cssproperty [--max-width=100%] - Customize the max nav width.
 * @cssproperty [--background=transparent] - Customize the nav background.
 * @cssproperty [--padding=var(--lynk-spacing-x-small) 0] - Customize the nav padding.
 * @cssproperty [--border-top=none] - Customize the top border.
 * @cssproperty [--border-right=none] - Customize the right border.
 * @cssproperty [--border-bottom=none] - Customize the bottom border.
 * @cssproperty [--border-left=none] - Customize the left border.
 * @cssproperty [--border-radius=0] - Customize the border radius.
 */
export default class LynkNav extends LynkElement {
    static styles: CSSResultGroup;
    defaultSlot: HTMLSlotElement;
    value: string | undefined;
    /** Simplifies the nav and draws the nav items in a slim style. */
    squished: boolean;
    private lastFocusedItem;
    private readonly localize;
    private mutationObserver;
    constructor();
    connectedCallback(): Promise<void>;
    disconnectedCallback(): void;
    private handleNavChanged;
    private getAllNavItems;
    private getNavGroups;
    getFocusableItems(): LynkNavItem[];
    private focusItem;
    private handleKeyDown;
    private handleClick;
    private handleFocusOut;
    private handleFocusIn;
    handleSquishedChange(): void;
    render(): import("lit").TemplateResult<1>;
}
