import LynkDivider from '../divider/divider.component.js';
import LynkElement from '../../internal/lynk-element.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary Creates a grouping for [options](/components/option) within a [select](/components/select) or [combobox](/components/combobox).
 * @documentation https://lynk.design/components/optgroup
 * @status experimental
 * @since 1.0.0
 *
 * @dependency lynk-divider
 *
 * @slot - The given options. Must be `lynk-option` elements.
 * @slot prefix - A presentational prefix icon or similar element.
 * @slot label - The label for the optgroup
 * @slot suffix - A presentational suffix icon or similar element.
 *
 * @csspart base - The component's base wrapper.
 * @csspart label-container - The container that wraps prefix, label and base
 * @csspart divider - The divider that is displayed above the content
 * @csspart prefix - The container that wraps the prefix.
 * @csspart suffix - The container that wraps the suffix.
 * @csspart options - The container that wraps the option elements.
 *
 * @cssproperty --display-divider - Display property of the divider. Defaults to "block"
 */
export default class LynkOptgroup extends LynkElement {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-divider': typeof LynkDivider;
    };
    private readonly hasSlotController;
    defaultSlot: HTMLSlotElement;
    /**
     * Syncs the disabled prop for all slotted lynk-options when it is triggered
     */
    private handleDisableOptions;
    /**
     * Disables all options in the optgroup.
     */
    disabled: boolean;
    /**
     * The optgroups label. If you need to display HTML, use the `label` slot instead.
     */
    label: string;
    handleDisabledChange(): void;
    render(): import("lit").TemplateResult;
}
