import LynkElement from '../../internal/lynk-element.js';
import LynkPage from '../page/page.component.js';
import LynkPageContent from '../page-content/page-content.component.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary A Page Footer is used inside a [Page Layout](/components/page) to render a standardized sticky page footer with slots for typical page controls.
 * @documentation https://lynk.design/components/page-footer
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-page
 * @dependency lynk-page-content
 *
 * @slot - The default start-aligned slot for primary page actions, Typically where `save` and `cancel` of form based pages should go.
 * @slot center - Typically used for pagination info or other non interactive page metadata.
 * @slot secondary - The end-aligned slot for secondary page actions. Typically where `delete` or other secondary destructive actions should go..
 *
 * @csspart base - The component's base wrapper.
 * @csspart primary - The component's primary slot area.
 * @csspart center - The component's center slot area.
 * @csspart secondary - The component's secondary slot area.
 */
export default class LynkPageFooter extends LynkElement {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-page-content': typeof LynkPageContent;
        'lynk-page': typeof LynkPage;
    };
    /** Set an optional maximum width for page header  */
    width: 'auto' | 'small' | 'medium' | 'large' | 'x-large' | '2x-large' | 'fluid';
    connectedCallback(): void;
    private hasParentLayout;
    render(): import("lit").TemplateResult<1>;
}
