import LynkElement from '../../internal/lynk-element.js';
import type { CSSResultGroup } from 'lit';
import type { LynkFormControl } from '../../internal/lynk-element.js';
/**
 * @summary Switches allow the user to toggle an option on or off.
 * @documentation https://lynk.design/components/switch
 * @since 1.0.0
 * @status stable
 *
 * @slot - The switch's label.
 *
 * @event ev-blur - Emitted when the control loses focus.
 * @event ev-change - Emitted when the control's checked state changes.
 * @event ev-input - Emitted when the control receives input.
 * @event ev-focus - Emitted when the control gains focus.
 * @event ev-invalid - Emitted when the form control has been checked for validity and its constraints aren't satisfied.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart control - The switch control.
 * @csspart thumb - The switch position indicator.
 * @csspart label - The switch label.
 *
 * @cssproperty --width - The width of the switch.
 * @cssproperty --height - The height of the switch.
 * @cssproperty --thumb-size - The size of the thumb.
 */
export default class LynkSwitch extends LynkElement implements LynkFormControl {
    static styles: CSSResultGroup;
    private readonly formControlController;
    input: HTMLInputElement;
    private hasFocus;
    title: string;
    /** The switch's name attribute. */
    name: string;
    /** The switch's value attribute. */
    value: string;
    /** The switch's size. */
    size: 'small' | 'medium' | 'large';
    /** The switch's color */
    color: 'default' | 'success' | 'warning' | 'danger';
    /** Disables the switch. */
    disabled: boolean;
    /** Draws the switch in a checked state. */
    checked: boolean;
    /** The default value of the form control. Primarily used for resetting the form control. */
    defaultChecked: boolean;
    /**
     * By default, form controls are associated with the nearest containing `<form>` element. This attribute allows you
     * to place the form control outside of a form and associate it with the form that has this `id`. The form must be in
     * the same document or shadow root for this to work.
     */
    form: string;
    /** Makes the switch a required field. */
    required: boolean;
    /** Gets the validity state object */
    get validity(): ValidityState;
    /** Gets the validation message */
    get validationMessage(): string;
    firstUpdated(): void;
    private handleBlur;
    private handleInput;
    private handleInvalid;
    private handleClick;
    private handleFocus;
    private handleKeyDown;
    handleCheckedChange(): void;
    handleDisabledChange(): void;
    /** Simulates a click on the switch. */
    click(): void;
    /** Sets focus on the switch. */
    focus(options?: FocusOptions): void;
    /** Removes focus from the switch. */
    blur(): void;
    /** Checks for validity but does not show the browser's validation message. */
    checkValidity(): boolean;
    /** Gets the associated form, if one exists. */
    getForm(): HTMLFormElement | null;
    /** Checks for validity and shows the browser's validation message if the control is invalid. */
    reportValidity(): boolean;
    /** Sets a custom validation message. Pass an empty string to restore validity. */
    setCustomValidity(message: string): void;
    render(): import("lit").TemplateResult<1>;
}
