import LynkElement from '../../internal/lynk-element.js';
import type { CSSResultGroup } from 'lit';
import type { ILynkTableCol, ILynkTableRow } from './models.js';
import type { LynkTableSortEvent } from '../../events/table-sort.js';
import type LynkTbody from '../tbody/tbody.component.js';
import type LynkThead from '../thead/thead.component.js';
/**
 * @summary Tables display tabular data in a basic grid composed of cells, columns, and rows. This format makes it easy for users to scan and compare large amounts of data. Lynk based tables are intended to behave like native html `<table>` elements.
 * @documentation https://lynk.design/components/table
 * @since 1.0.0
 * @status stable
 *
 * @slot - The tables content. If constructing manually, should contain 1 or more `<lynk-thead>` and `<lynk-tbody>` components. Should be unused for automatically constructed tables that use the `cols` and `rows` properties.
 *
 * @csspart base - The component's internal wrapper.
 */
export default class LynkTable extends LynkElement {
    static styles: CSSResultGroup;
    /**
     * Objects used for mapping column data, ths, and sorting.
     * Required for data-driven tables.
     * Optional for custom tables, except if you want to use the built-in sorting.
     * Each object is expected to have a "key" corresponding a property in each row object.
     **/
    cols: ILynkTableCol[];
    /**
     * Objects used for mapping row data.
     * Required for data-driven tables.
     * Optional for custom tables, except if you want to use the built-in sorting.
     * Each object is expected to have a string property corresponding to a "key" in one of the cols.
     */
    rows: ILynkTableRow[];
    /** Enables slotted children, and disables automatic table element construction */
    custom: boolean;
    assignedHead: NodeListOf<LynkThead>;
    assignedBody: NodeListOf<LynkTbody>;
    connectedCallback(): void;
    disconnectedCallback(): void;
    handleSort(event: LynkTableSortEvent): void;
    render(): import("lit").TemplateResult<1>;
}
