import LynkElement from '../../internal/lynk-element.js';
import LynkIconButton from '../icon-button/icon-button.component.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary Tags are used as labels to organize things or to indicate a selection.
 * @documentation https://lynk.design/components/tag
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon-button
 *
 * @slot - The tag's content.
 *
 * @event ev-remove - Emitted when the remove button is activated.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart content - The tag content.
 * @csspart remove-button - The remove button.
 * @csspart remove-button__base - The remove button's `base` part.
 */
export default class LynkTag extends LynkElement {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-icon-button': typeof LynkIconButton;
    };
    private readonly localize;
    /** The tag's variant. */
    type: 'primary' | 'accent' | 'success' | 'neutral' | 'warning' | 'danger' | 'info' | 'text';
    /** The tag's size. */
    size: 'tiny' | 'small' | 'medium' | 'large';
    /** Draws a pill-style tag with rounded edges. */
    pill: boolean;
    /** Makes the tag removable. */
    removable: boolean;
    /** Makes the tag pulsate to draw attention. */
    pulse: boolean;
    /** Draws a solid filled badge-styled tag . */
    badge: boolean;
    handleRemoveClick(): void;
    render(): import("lit").TemplateResult<1>;
}
