import { TableSortDirection } from '../table/models.js';
import LynkElement from '../../internal/lynk-element.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary Table `<lynk-th>` components will behave like a native `<th>` HTML element within a `<lynk-table>`.
 * @documentation https://lynk.design/components/th
 * @since 1.0.0
 * @status stable
 *
 * @slot - The table column header label
 *
 * @event ev-table-sort - Emitted when a sortable table header is clicked on.
 */
export default class LynkTh extends LynkElement {
    static styles: CSSResultGroup;
    /** The column key associated with this table header */
    key: string;
    /** The sorting direction currently applied to the rows with the corresponding column key */
    sortDirection: TableSortDirection;
    /** Toggles sort events and the display of sorting related icons with the corresponding column key */
    sortable: boolean;
    connectedCallback(): void;
    disconnectedCallback(): void;
    handleClick(): void;
    render(): import("lit").TemplateResult<1>;
}
