import Component from '../../components/alert/alert.component.js';
import { type EventName } from '@lit/react';
import type { LynkShowEvent } from '../../events/events.js';
import type { LynkAfterShowEvent } from '../../events/events.js';
import type { LynkHideEvent } from '../../events/events.js';
import type { LynkAfterHideEvent } from '../../events/events.js';
export type { LynkShowEvent } from '../../events/events.js';
export type { LynkAfterShowEvent } from '../../events/events.js';
export type { LynkHideEvent } from '../../events/events.js';
export type { LynkAfterHideEvent } from '../../events/events.js';
/**
 * @summary Alerts are used to display important messages inline or as toast notifications.
 * @documentation https://lynk.design/components/alert
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon-button
 *
 * @slot - The alert's content.
 * @slot icon - An icon to show in the alert.
 * @slot action - Append custom actions to alert.
 *
 * @event ev-show - Emitted when the alert opens.
 * @event ev-after-show - Emitted after the alert opens and all animations are complete.
 * @event ev-hide - Emitted when the alert closes.
 * @event ev-after-hide - Emitted after the alert closes and all animations are complete.
 *
 * @csspart base - The component's internal block wrapper.
 * @csspart icon - The container that wraps the alert icon.
 * @csspart message - The alert message.
 * @csspart close-button - The close button.
 * @csspart close-button__base - The close button's `base` part.
 *
 * @cssproperty --box-shadow - The alert's box shadow.
 * @cssproperty --padding - The top and bottom padding of the message. Use any spacing token (--lynk-spacing-large) or a custom value.
 *
 * @animation alert.show - The animation to use when showing the alert.
 * @animation alert.hide - The animation to use when hiding the alert.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvShow: EventName<LynkShowEvent>;
    EvAfterShow: EventName<LynkAfterShowEvent>;
    EvHide: EventName<LynkHideEvent>;
    EvAfterHide: EventName<LynkAfterHideEvent>;
}>;
export default reactWrapper;
