import Component from '../../components/checkbox/checkbox.component.js';
import { type EventName } from '@lit/react';
import type { LynkBlurEvent } from '../../events/events.js';
import type { LynkChangeEvent } from '../../events/events.js';
import type { LynkFocusEvent } from '../../events/events.js';
import type { LynkInputEvent } from '../../events/events.js';
import type { LynkInvalidEvent } from '../../events/events.js';
export type { LynkBlurEvent } from '../../events/events.js';
export type { LynkChangeEvent } from '../../events/events.js';
export type { LynkFocusEvent } from '../../events/events.js';
export type { LynkInputEvent } from '../../events/events.js';
export type { LynkInvalidEvent } from '../../events/events.js';
/**
 * @summary Checkboxes allow the user to toggle an option on or off.
 * @documentation https://lynk.design/components/checkbox
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon
 *
 * @slot - The checkbox's label.
 * @slot help-text - Text that describes how to use the checkbox. Alternatively, you can use the `help-text` attribute.
 *
 * @event ev-blur - Emitted when the control loses focus.
 * @event ev-change - Emitted when the control's checked state changes.
 * @event ev-focus - Emitted when the control gains focus.
 * @event ev-input - Emitted when the checkbox receives input.
 * @event ev-invalid - Emitted when the form control has been checked for validity and its constraints aren't satisfied.
 *
 * @csspart base - The component's base wrapper.
 * @csspart control - The square container that wraps the checkbox's checked state.
 * @csspart control--checked - Matches the control part when the checkbox is checked.
 * @csspart control--indeterminate - Matches the control part when the checkbox is indeterminate.
 * @csspart checked-icon - The checked icon, an `<lynk-icon>` element.
 * @csspart indeterminate-icon - The indeterminate icon, an `<lynk-icon>` element.
 * @csspart label - The container that wraps the checkbox's label.
 * @csspart form-control-help-text - The help text's wrapper.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvBlur: EventName<LynkBlurEvent>;
    EvChange: EventName<LynkChangeEvent>;
    EvFocus: EventName<LynkFocusEvent>;
    EvInput: EventName<LynkInputEvent>;
    EvInvalid: EventName<LynkInvalidEvent>;
}>;
export default reactWrapper;
