import Component from '../../components/copy-button/copy-button.component.js';
import { type EventName } from '@lit/react';
import type { LynkCopyEvent } from '../../events/events.js';
import type { LynkErrorEvent } from '../../events/events.js';
export type { LynkCopyEvent } from '../../events/events.js';
export type { LynkErrorEvent } from '../../events/events.js';
/**
 * @summary Copies text data to the clipboard when the user clicks the trigger.
 * @documentation https://lynk.design/components/copy-button
 * @status stable
 * @since 1.0.0
 *
 * @dependency lynk-icon
 * @dependency lynk-tooltip
 *
 * @event ev-copy - Emitted when the data has been copied.
 * @event ev-error - Emitted when the data could not be copied.
 *
 * @slot copy-icon - The icon to show in the default copy state. Works best with `<lynk-icon>`.
 * @slot success-icon - The icon to show when the content is copied. Works best with `<lynk-icon>`.
 * @slot error-icon - The icon to show when a copy error occurs. Works best with `<lynk-icon>`.
 *
 * @csspart button - The internal `<button>` element.
 * @csspart copy-icon - The container that holds the copy icon.
 * @csspart success-icon - The container that holds the success icon.
 * @csspart error-icon - The container that holds the error icon.
 * @csspart tooltip__base - The tooltip's exported `base` part.
 * @csspart tooltip__base__popup - The tooltip's exported `popup` part.
 * @csspart tooltip__base__arrow - The tooltip's exported `arrow` part.
 * @csspart tooltip__body - The tooltip's exported `body` part.
 *
 * @cssproperty --success-color - The color to use for success feedback.
 * @cssproperty --error-color - The color to use for error feedback.
 *
 * @animation copy.in - The animation to use when feedback icons animate in.
 * @animation copy.out - The animation to use when feedback icons animate out.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvCopy: EventName<LynkCopyEvent>;
    EvError: EventName<LynkErrorEvent>;
}>;
export default reactWrapper;
