import Component from '../../components/menu-item/menu-item.component.js';
import { type EventName } from '@lit/react';
import type { LynkClickEvent } from '../../events/events.js';
export type { LynkClickEvent } from '../../events/events.js';
/**
 * @summary Menu items provide options for the user to pick from in a menu.
 * @documentation https://lynk.design/components/menu-item
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon
 *
 * @event ev-click - Emitted when a menu item is clicked
 *
 * @slot - The menu item's label.
 * @slot prefix - Used to prepend an icon or similar element to the menu item.
 * @slot suffix - Used to append an icon or similar element to the menu item.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart checked-icon - The checked icon, which is only visible when the menu item is checked.
 * @csspart prefix - The prefix container.
 * @csspart label - The menu item label.
 * @csspart suffix - The suffix container.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvClick: EventName<LynkClickEvent>;
}>;
export default reactWrapper;
