import Component from '../../components/nav-item/nav-item.component.js';
import { type EventName } from '@lit/react';
import type { LynkExpandEvent } from '../../events/events.js';
import type { LynkAfterExpandEvent } from '../../events/events.js';
import type { LynkCollapseEvent } from '../../events/events.js';
import type { LynkAfterCollapseEvent } from '../../events/events.js';
export type { LynkExpandEvent } from '../../events/events.js';
export type { LynkAfterExpandEvent } from '../../events/events.js';
export type { LynkCollapseEvent } from '../../events/events.js';
export type { LynkAfterCollapseEvent } from '../../events/events.js';
/**
 * @summary Nav items allow the user to navigate or trigger actions from within a navigation menu.
 * @documentation https://lynk.design/components/nav-item
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon
 * @dependency lynk-tooltip
 *
 * @event ev-expand - Emitted when the nav item expands.
 * @event ev-after-expand - Emitted after the nav item expands and all animations are complete.
 * @event ev-collapse - Emitted when the nav item collapses.
 * @event ev-after-collapse - Emitted after the nav item collapses and all animations are complete.
 *
 * @slot - The nav item's label.
 * @slot prefix - Used to prepend an icon or similar element to the nav item.
 * @slot suffix - Used to append an icon or similar element to the nav item.
 * @slot children - Used to nest nav items under a nav item.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart prefix - The prefix container.
 * @csspart label - The nav item label.
 * @csspart suffix - The suffix container.
 *
 * @cssproperty [--hover-bg-color=var(--lynk-color-gray-a25)] - Customize the hover styles.
 * @cssproperty [--selected-bg-color=var(--lynk-color-primary-700)] - Customize the selected styles.
 * @cssproperty [--selected-color=var(--lynk-color-gray-a25)] - Customize the selected styles.
 * @cssproperty [--border-radius=var(--lynk-border-radius-medium)] - Customize the border radius.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvExpand: EventName<LynkExpandEvent>;
    EvAfterExpand: EventName<LynkAfterExpandEvent>;
    EvCollapse: EventName<LynkCollapseEvent>;
    EvAfterCollapse: EventName<LynkAfterCollapseEvent>;
}>;
export default reactWrapper;
