import Component from '../../components/popover/popover.component.js';
import { type EventName } from '@lit/react';
import type { LynkShowEvent } from '../../events/events.js';
import type { LynkAfterShowEvent } from '../../events/events.js';
import type { LynkHideEvent } from '../../events/events.js';
import type { LynkAfterHideEvent } from '../../events/events.js';
export type { LynkShowEvent } from '../../events/events.js';
export type { LynkAfterShowEvent } from '../../events/events.js';
export type { LynkHideEvent } from '../../events/events.js';
export type { LynkAfterHideEvent } from '../../events/events.js';
/**
 * @summary Popover's display rich content in a "pop over" panel to add additional information or functionality when a user interacts with a triggering element.
 * @documentation https://lynk.design/components/popover
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-popup
 *
 * @slot - The popover's content.
 * @slot label - The dialog's label. Alternatively, you can use the label prop.
 * @slot trigger - The popover's trigger, usually a `<lynk-button>` element.
 * @slot footer - The dialog's footer, usually one or more buttons representing various options.
 *
 * @event ev-show - Emitted when the popover opens.
 * @event ev-after-show - Emitted after the popover opens and all animations are complete.
 * @event ev-hide - Emitted when the popover closes.
 * @event ev-after-hide - Emitted after the popover closes and all animations are complete.
 *
 * @cssproperty --width - The preferred width of the popover. Defaults to 320px or 20rem.
 * @cssproperty --max-width - The max width of the popover as determined by its contents. Defaults to 480px or 30rem.
 * @cssproperty --header-spacing - The amount of padding to use for the header.
 * @cssproperty --body-spacing - The amount of padding to use for the body.
 * @cssproperty --footer-spacing - The amount of padding to use for the footer.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart trigger - The container that wraps the trigger.
 * @csspart panel - The panel that gets shown when the popover is open.
 *
 * @animation popover.show - The animation to use when showing the popover.
 * @animation popover.hide - The animation to use when hiding the popover.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvShow: EventName<LynkShowEvent>;
    EvAfterShow: EventName<LynkAfterShowEvent>;
    EvHide: EventName<LynkHideEvent>;
    EvAfterHide: EventName<LynkAfterHideEvent>;
}>;
export default reactWrapper;
