// src/components/alert/alert.styles.ts
import { css } from "lit";
var alert_styles_default = css`
  :host {
    display: contents;

    --padding: var(--lynk-spacing-base);

    /* For better DX, we'll reset the margin here so the base part can inherit it */
    margin: 0;
  }

  .alert {
    position: relative;
    display: flex;
    align-items: stretch;
    background-color: var(--lynk-panel-background-color);
    border: solid var(--lynk-panel-border-width) var(--lynk-panel-border-color);
    border-left-width: calc(var(--lynk-panel-border-width) * 4);
    border-right-width: calc(var(--lynk-panel-border-width) * 4);
    border-radius: var(--lynk-border-radius-medium);
    box-shadow: var(--box-shadow);
    font-family: var(--lynk-font-sans);
    font-size: var(--lynk-font-size-medium);
    font-weight: var(--lynk-font-weight-normal);
    line-height: 1.6;
    color: var(--lynk-color-neutral-900);
    margin: inherit;
  }

  .alert:not(.alert--has-icon) .alert__icon,
  .alert:not(.alert--closable) .alert__close-button {
    display: none;
  }

  .alert__icon {
    flex: 0 0 auto;
    display: flex;
    align-items: center;
    font-size: var(--lynk-font-size-x-large);
    padding-inline-start: var(--lynk-spacing-medium);
  }

  .alert--has-countdown {
    border-bottom: none;
  }

  .alert--primary {
    border-left-color: var(--lynk-color-primary-600);
    border-right-color: var(--lynk-color-primary-600);
  }

  .alert--primary .alert__icon {
    color: var(--lynk-color-primary-600);
  }

  .alert--success {
    border-left-color: var(--lynk-color-success-600);
    border-right-color: var(--lynk-color-success-600);
  }

  .alert--success .alert__icon {
    color: var(--lynk-color-success-600);
  }

  .alert--neutral {
    border-left-color: var(--lynk-color-neutral-600);
    border-right-color: var(--lynk-color-neutral-600);
  }

  .alert--neutral .alert__icon {
    color: var(--lynk-color-neutral-600);
  }

  .alert--warning {
    border-left-color: var(--lynk-color-warning-600);
    border-right-color: var(--lynk-color-warning-600);
  }

  .alert--warning .alert__icon {
    color: var(--lynk-color-warning-600);
  }

  .alert--danger {
    border-left-color: var(--lynk-color-danger-600);
    border-right-color: var(--lynk-color-danger-600);
  }

  .alert--danger .alert__icon {
    color: var(--lynk-color-danger-600);
  }

  .alert__message {
    flex: 1 1 auto;
    display: block;
    padding: var(--padding) var(--lynk-spacing-medium);
    overflow: hidden;
  }

  .alert__close-button {
    flex: 0 0 auto;
    display: flex;
    align-items: center;
    font-size: var(--lynk-font-size-large);
    padding-inline-end: var(--lynk-spacing-base);
  }

  .alert__countdown {
    position: absolute;
    bottom: 0;
    left: 0;
    width: 100%;
    height: calc(var(--lynk-panel-border-width) * 3);
    background-color: var(--lynk-panel-border-color);
    display: flex;
  }

  .alert__countdown--ltr {
    justify-content: flex-end;
  }

  .alert__countdown .alert__countdown-elapsed {
    height: 100%;
    width: 0;
  }

  .alert--primary .alert__countdown-elapsed {
    background-color: var(--lynk-color-primary-600);
  }

  .alert--success .alert__countdown-elapsed {
    background-color: var(--lynk-color-success-600);
  }

  .alert--neutral .alert__countdown-elapsed {
    background-color: var(--lynk-color-neutral-600);
  }

  .alert--warning .alert__countdown-elapsed {
    background-color: var(--lynk-color-warning-600);
  }

  .alert--danger .alert__countdown-elapsed {
    background-color: var(--lynk-color-danger-600);
  }

  .alert__timer {
    display: none;
  }

  .alert__action {
    flex: 0 0 auto;
    display: flex;
    align-items: center;
    padding-inline-end: var(--lynk-spacing-base);
  }
`;

export {
  alert_styles_default
};
