import {
  tab_styles_default
} from "./chunk.XLFQEV7M.js";
import {
  LynkIconButton
} from "./chunk.2KULQMOI.js";
import {
  LocalizeController
} from "./chunk.6CTB5ZDJ.js";
import {
  watch
} from "./chunk.GMYPQTFK.js";
import {
  LynkElement
} from "./chunk.7M4AVQ6D.js";
import {
  component_styles_default
} from "./chunk.Y7724W4D.js";
import {
  __decorateClass
} from "./chunk.KAW7D32O.js";

// src/components/tab/tab.component.ts
import { classMap } from "lit/directives/class-map.js";
import { html, literal } from "lit/static-html.js";
import { ifDefined } from "lit/directives/if-defined.js";
import { property, query } from "lit/decorators.js";
var id = 0;
var LynkTab = class extends LynkElement {
  constructor() {
    super(...arguments);
    this.localize = new LocalizeController(this);
    this.attrId = ++id;
    this.componentId = `lynk-tab-${this.attrId}`;
    this.panel = "";
    this.active = false;
    this.closable = false;
    this.disabled = false;
    this.href = "";
    this.rel = "noreferrer noopener";
  }
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "tab");
  }
  handleCloseClick() {
    this.emit("ev-close");
  }
  isLink() {
    return this.href ? true : false;
  }
  handleActiveChange() {
    this.setAttribute("aria-selected", this.active ? "true" : "false");
  }
  handleDisabledChange() {
    this.setAttribute("aria-disabled", this.disabled ? "true" : "false");
    if (this.disabled && !this.active) {
      this.tabIndex = -1;
    } else {
      this.tabIndex = 0;
    }
  }
  /** Sets focus to the tab. */
  focus(options) {
    this.tab.focus(options);
  }
  /** Removes focus from the tab. */
  blur() {
    this.tab.blur();
  }
  render() {
    const isLink = this.isLink();
    const tag = isLink ? literal`a` : literal`div`;
    this.id = this.id.length > 0 ? this.id : this.componentId;
    return html`
      <${tag}
        part="base"
        href=${ifDefined(isLink ? this.href : void 0)}
        rel=${ifDefined(isLink ? this.rel : void 0)}
        class=${classMap({
      tab: true,
      "tab--active": this.active,
      "tab--closable": this.closable,
      "tab--disabled": this.disabled
    })}
        tabindex=${this.disabled ? "-1" : "0"}
      >
        <slot></slot>
        ${this.closable ? html`
                <lynk-icon-button
                  part="close-button"
                  exportparts="base:close-button__base"
                  name="x-lg"
                  library="system"
                  label=${this.localize.term("close")}
                  class="tab__close-button"
                  @click=${this.handleCloseClick}
                  tabindex="-1"
                ></lynk-icon-button>
              ` : ""}
      </${tag}>
    `;
  }
};
LynkTab.styles = [component_styles_default, tab_styles_default];
LynkTab.dependencies = { "lynk-icon-button": LynkIconButton };
__decorateClass([
  query(".tab")
], LynkTab.prototype, "tab", 2);
__decorateClass([
  property({ reflect: true })
], LynkTab.prototype, "panel", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkTab.prototype, "active", 2);
__decorateClass([
  property({ type: Boolean })
], LynkTab.prototype, "closable", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkTab.prototype, "disabled", 2);
__decorateClass([
  property()
], LynkTab.prototype, "href", 2);
__decorateClass([
  property()
], LynkTab.prototype, "rel", 2);
__decorateClass([
  watch("active")
], LynkTab.prototype, "handleActiveChange", 1);
__decorateClass([
  watch("disabled")
], LynkTab.prototype, "handleDisabledChange", 1);

export {
  LynkTab
};
