import {
  clamp
} from "./chunk.HF7GESMZ.js";
import {
  nav_item_default
} from "./chunk.BK6H6UBW.js";
import {
  nav_styles_default
} from "./chunk.ZGDA6XYZ.js";
import {
  LocalizeController
} from "./chunk.6CTB5ZDJ.js";
import {
  watch
} from "./chunk.GMYPQTFK.js";
import {
  LynkElement
} from "./chunk.7M4AVQ6D.js";
import {
  component_styles_default
} from "./chunk.Y7724W4D.js";
import {
  __decorateClass
} from "./chunk.KAW7D32O.js";

// src/components/nav/nav.component.ts
import { classMap } from "lit/directives/class-map.js";
import { html } from "lit";
import { property, query } from "lit/decorators.js";
var LynkNav = class extends LynkElement {
  constructor() {
    super();
    this.value = void 0;
    this.squished = false;
    this.localize = new LocalizeController(this);
    this.handleFocusOut = (event) => {
      const relatedTarget = event.relatedTarget;
      if (!relatedTarget || !this.contains(relatedTarget)) {
        this.tabIndex = 0;
      }
    };
    this.handleFocusIn = (event) => {
      const target = event.target;
      if (event.target === this) {
        this.focusItem(this.lastFocusedItem || this.getAllNavItems()[0]);
      }
      if (nav_item_default.isTreeItem(target) && !target.disabled) {
        if (this.lastFocusedItem) {
          this.lastFocusedItem.tabIndex = -1;
        }
        this.lastFocusedItem = target;
        this.tabIndex = -1;
        target.tabIndex = 0;
      }
    };
    this.addEventListener("focusin", this.handleFocusIn);
    this.addEventListener("focusout", this.handleFocusOut);
  }
  async connectedCallback() {
    super.connectedCallback();
    if (this.squished) {
      this.handleSquishedChange();
    }
    this.setAttribute("role", "navigation");
    this.setAttribute("tabindex", "0");
    await this.updateComplete;
    this.mutationObserver = new MutationObserver(this.handleNavChanged);
    this.mutationObserver.observe(this, { childList: true, subtree: true });
  }
  disconnectedCallback() {
    var _a;
    super.disconnectedCallback();
    (_a = this.mutationObserver) == null ? void 0 : _a.disconnect();
  }
  handleNavChanged(mutations) {
    for (const mutation of mutations) {
      const removedNodes = [...mutation.removedNodes].filter(nav_item_default.isTreeItem);
      if (removedNodes.includes(this.lastFocusedItem)) {
        this.focusItem(this.getFocusableItems()[0]);
      }
    }
  }
  getAllNavItems() {
    return [...this.querySelectorAll("lynk-nav-item")];
  }
  getNavGroups() {
    return [...this.querySelectorAll("lynk-nav-group")];
  }
  getFocusableItems() {
    const items = this.getAllNavItems();
    const collapsedItems = /* @__PURE__ */ new Set();
    return items.filter((item) => {
      var _a;
      if (item.disabled) return false;
      const parent = (_a = item.parentElement) == null ? void 0 : _a.closest("[role=treeitem]");
      if (parent && (!parent.expanded || collapsedItems.has(parent))) {
        collapsedItems.add(item);
      }
      return !collapsedItems.has(item);
    });
  }
  focusItem(item) {
    item == null ? void 0 : item.focus();
  }
  handleKeyDown(event) {
    if (!["ArrowDown", "ArrowUp", "ArrowRight", "ArrowLeft", "Home", "End", "Enter", "Tab", " "].includes(event.key)) {
      return;
    }
    const items = this.getFocusableItems();
    const isLtr = this.localize.dir() === "ltr";
    const isRtl = this.localize.dir() === "rtl";
    if (items.length > 0) {
      const activeItemIndex = items.findIndex((item) => item.matches(":focus"));
      const activeItem = items[activeItemIndex];
      const focusItemAt = (index) => {
        const item = items[clamp(index, 0, items.length - 1)];
        this.focusItem(item);
      };
      const toggleExpand = (expanded) => {
        activeItem.expanded = expanded;
      };
      if (event.key === "Tab" && !event.shiftKey && activeItemIndex === items.length - 1) {
        this.tabIndex = 0;
        activeItem.tabIndex = 0;
      } else if (event.key === "Tab" && event.shiftKey && activeItemIndex === 0) {
        this.tabIndex = -1;
        activeItem.tabIndex = -1;
      } else {
        event.preventDefault();
        if (event.key === "ArrowDown" || event.key === "Tab" && !event.shiftKey) {
          focusItemAt(activeItemIndex + 1);
        } else if (event.key === "ArrowUp" || event.key === "Tab" && event.shiftKey) {
          focusItemAt(activeItemIndex - 1);
        } else if (isLtr && event.key === "ArrowRight" || isRtl && event.key === "ArrowLeft") {
          if (!activeItem || activeItem.disabled || activeItem.isParent && activeItem.expanded || !activeItem.isParent) {
            focusItemAt(activeItemIndex + 1);
          } else {
            toggleExpand(true);
          }
        } else if (isLtr && event.key === "ArrowLeft" || isRtl && event.key === "ArrowRight") {
          if (!activeItem || activeItem.disabled || !activeItem.isParent || activeItem.isParent && !activeItem.expanded) {
            focusItemAt(activeItemIndex - 1);
          } else {
            toggleExpand(false);
          }
        } else if (event.key === "Home") {
          focusItemAt(0);
        } else if (event.key === "End") {
          focusItemAt(items.length - 1);
        } else if (event.key === "Enter" || event.key === " ") {
          if (!activeItem.disabled) {
            activeItem.click();
          }
        }
      }
    }
  }
  handleClick(event) {
    const target = event.target;
    const item = target.closest("lynk-nav-item");
    if (!item || item.disabled || item.inert) {
      return;
    }
    this.emit("ev-nav-select", { detail: { item } });
  }
  handleSquishedChange() {
    const items = this.getAllNavItems();
    const groups = this.getNavGroups();
    items.forEach((item) => {
      item.squished = this.squished;
      item.expanded = false;
      item.isParent = false;
    });
    groups.forEach((item) => {
      item.squished = this.squished;
    });
  }
  render() {
    return html`
      <div
        part="base"
        class=${classMap({
      nav: true,
      "nav--squished": this.squished
    })}
        role="tree"
        @click=${this.handleClick}
        @keydown=${this.handleKeyDown}
      >
        <slot part="list"></slot>
      </div>
    `;
  }
};
LynkNav.styles = [component_styles_default, nav_styles_default];
__decorateClass([
  query("slot:not([name])")
], LynkNav.prototype, "defaultSlot", 2);
__decorateClass([
  property({ reflect: true })
], LynkNav.prototype, "value", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkNav.prototype, "squished", 2);
__decorateClass([
  watch("squished", { waitUntilFirstUpdate: true })
], LynkNav.prototype, "handleSquishedChange", 1);

export {
  LynkNav
};
