import {
  LynkSpinner
} from "./chunk.NOUUOVAR.js";
import {
  FormControlController,
  validValidityState
} from "./chunk.74PYJKHH.js";
import {
  button_styles_default
} from "./chunk.QKFJOBUJ.js";
import {
  HasSlotController
} from "./chunk.OW5NIGGX.js";
import {
  LocalizeController
} from "./chunk.6CTB5ZDJ.js";
import {
  LynkIcon
} from "./chunk.OTHQ47SZ.js";
import {
  watch
} from "./chunk.GMYPQTFK.js";
import {
  LynkElement
} from "./chunk.7M4AVQ6D.js";
import {
  component_styles_default
} from "./chunk.Y7724W4D.js";
import {
  __decorateClass
} from "./chunk.KAW7D32O.js";

// src/components/button/button.component.ts
import { classMap } from "lit/directives/class-map.js";
import { html, literal } from "lit/static-html.js";
import { ifDefined } from "lit/directives/if-defined.js";
import { property, query, state } from "lit/decorators.js";
var LynkButton = class extends LynkElement {
  constructor() {
    super(...arguments);
    this.formControlController = new FormControlController(this, {
      assumeInteractionOn: ["click"]
    });
    this.hasSlotController = new HasSlotController(this, "[default]", "prefix", "suffix");
    this.localize = new LocalizeController(this);
    this.hasFocus = false;
    this.invalid = false;
    this.title = "";
    this.color = "default";
    this.size = "medium";
    this.block = false;
    this.caret = false;
    this.disabled = false;
    this.thinking = false;
    this.outline = false;
    this.stealth = false;
    this.pill = false;
    this.circle = false;
    this.square = false;
    this.type = "button";
    this.name = "";
    this.value = "";
    this.href = "";
    this.rel = "noreferrer noopener";
    this.noBubble = false;
  }
  /** Gets the validity state object */
  get validity() {
    if (this.isButton()) {
      return this.button.validity;
    }
    return validValidityState;
  }
  /** Gets the validation message */
  get validationMessage() {
    if (this.isButton()) {
      return this.button.validationMessage;
    }
    return "";
  }
  connectedCallback() {
    super.connectedCallback();
    this.handleHostClick = this.handleHostClick.bind(this);
    this.addEventListener("click", this.handleHostClick);
  }
  disconnectedCallback() {
    super.disconnectedCallback();
    this.removeEventListener("click", this.handleHostClick);
  }
  firstUpdated() {
    if (this.isButton()) {
      this.formControlController.updateValidity();
    }
  }
  handleBlur() {
    this.hasFocus = false;
    this.emit("ev-blur");
  }
  handleFocus() {
    this.hasFocus = true;
    this.emit("ev-focus");
  }
  handleClick() {
    if (this.type === "submit") {
      this.formControlController.submit(this);
    }
    if (this.type === "reset") {
      this.formControlController.reset(this);
    }
    this.emit("ev-click", {
      bubbles: !this.noBubble
    });
  }
  handleHostClick(event) {
    if (this.disabled || this.thinking) {
      event.preventDefault();
      event.stopImmediatePropagation();
    }
    if (this.noBubble) {
      event.stopPropagation();
    }
  }
  handleInvalid(event) {
    this.formControlController.setValidity(false);
    this.formControlController.emitInvalidEvent(event);
  }
  isButton() {
    return this.href ? false : true;
  }
  isLink() {
    return this.href ? true : false;
  }
  handleDisabledChange() {
    if (this.isButton()) {
      this.formControlController.setValidity(this.disabled);
    }
  }
  /** Simulates a click on the button. */
  click() {
    this.button.click();
  }
  /** Sets focus on the button. */
  focus(options) {
    this.button.focus(options);
  }
  /** Removes focus from the button. */
  blur() {
    this.button.blur();
  }
  /** Checks for validity but does not show the browser's validation message. */
  checkValidity() {
    if (this.isButton()) {
      return this.button.checkValidity();
    }
    return true;
  }
  /** Gets the associated form, if one exists. */
  getForm() {
    return this.formControlController.getForm();
  }
  /** Checks for validity and shows the browser's validation message if the control is invalid. */
  reportValidity() {
    if (this.isButton()) {
      return this.button.reportValidity();
    }
    return true;
  }
  /** Sets a custom validation message. Pass an empty string to restore validity. */
  setCustomValidity(message) {
    if (this.isButton()) {
      this.button.setCustomValidity(message);
      this.formControlController.updateValidity();
    }
  }
  render() {
    const isLink = this.isLink();
    const tag = isLink ? literal`a` : literal`button`;
    return html`
      <${tag}
        part="base"
        class=${classMap({
      button: true,
      "button--default": this.color === "default",
      "button--primary": this.color === "primary",
      "button--accent": this.color === "accent",
      "button--success": this.color === "success",
      "button--neutral": this.color === "neutral",
      "button--warning": this.color === "warning",
      "button--info": this.color === "info",
      "button--danger": this.color === "danger",
      "button--text": this.color === "text",
      "button--tiny": this.size === "tiny",
      "button--small": this.size === "small",
      "button--medium": this.size === "medium",
      "button--large": this.size === "large",
      "button--caret": this.caret,
      "button--circle": this.circle,
      "button--square": this.square,
      "button--disabled": this.disabled,
      "button--focused": this.hasFocus,
      "button--thinking": this.thinking,
      "button--standard": !this.outline && !this.stealth,
      "button--outline": this.outline,
      "button--stealth": this.stealth,
      "button--pill": this.pill,
      "button--rtl": this.localize.dir() === "rtl",
      "button--has-label": this.hasSlotController.test("[default]"),
      "button--has-prefix": this.hasSlotController.test("prefix"),
      "button--has-suffix": this.hasSlotController.test("suffix")
    })}
        ?disabled=${ifDefined(isLink ? void 0 : this.disabled)}
        type=${ifDefined(isLink ? void 0 : this.type)}
        title=${this.title}
        name=${ifDefined(isLink ? void 0 : this.name)}
        value=${ifDefined(isLink ? void 0 : this.value)}
        href=${ifDefined(isLink ? this.href : void 0)}
        target=${ifDefined(isLink ? this.target : void 0)}
        download=${ifDefined(isLink ? this.download : void 0)}
        rel=${ifDefined(isLink ? this.rel : void 0)}
        role=${ifDefined(isLink ? void 0 : "button")}
        aria-disabled=${this.disabled ? "true" : "false"}
        tabindex=${this.disabled ? "-1" : "0"}
        @blur=${this.handleBlur}
        @focus=${this.handleFocus}
        @invalid=${this.isButton() ? this.handleInvalid : null}
        @click=${this.handleClick}
      >
      <slot name="prefix" part="prefix" class="button__prefix"></slot>
      <slot part="label" class="button__label"></slot>
      <slot name="suffix" part="suffix" class="button__suffix"></slot>
      ${this.caret ? html` <lynk-icon part="caret" class="button__caret" library="system" name="caret"></lynk-icon> ` : ""}
        ${this.thinking ? html`<lynk-spinner part="spinner"></lynk-spinner>` : ""}
      </${tag}>
    `;
  }
};
LynkButton.styles = [component_styles_default, button_styles_default];
LynkButton.dependencies = {
  "lynk-icon": LynkIcon,
  "lynk-spinner": LynkSpinner
};
__decorateClass([
  query(".button")
], LynkButton.prototype, "button", 2);
__decorateClass([
  state()
], LynkButton.prototype, "hasFocus", 2);
__decorateClass([
  state()
], LynkButton.prototype, "invalid", 2);
__decorateClass([
  property()
], LynkButton.prototype, "title", 2);
__decorateClass([
  property({ reflect: true })
], LynkButton.prototype, "color", 2);
__decorateClass([
  property({ reflect: true })
], LynkButton.prototype, "size", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkButton.prototype, "block", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkButton.prototype, "caret", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkButton.prototype, "disabled", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkButton.prototype, "thinking", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkButton.prototype, "outline", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkButton.prototype, "stealth", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkButton.prototype, "pill", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkButton.prototype, "circle", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkButton.prototype, "square", 2);
__decorateClass([
  property()
], LynkButton.prototype, "type", 2);
__decorateClass([
  property()
], LynkButton.prototype, "name", 2);
__decorateClass([
  property()
], LynkButton.prototype, "value", 2);
__decorateClass([
  property()
], LynkButton.prototype, "href", 2);
__decorateClass([
  property()
], LynkButton.prototype, "target", 2);
__decorateClass([
  property()
], LynkButton.prototype, "rel", 2);
__decorateClass([
  property()
], LynkButton.prototype, "download", 2);
__decorateClass([
  property()
], LynkButton.prototype, "form", 2);
__decorateClass([
  property({ attribute: "formaction" })
], LynkButton.prototype, "formAction", 2);
__decorateClass([
  property({ attribute: "formenctype" })
], LynkButton.prototype, "formEnctype", 2);
__decorateClass([
  property({ attribute: "formmethod" })
], LynkButton.prototype, "formMethod", 2);
__decorateClass([
  property({ attribute: "formnovalidate", type: Boolean })
], LynkButton.prototype, "formNoValidate", 2);
__decorateClass([
  property({ attribute: "formtarget" })
], LynkButton.prototype, "formTarget", 2);
__decorateClass([
  property({ attribute: "no-bubble", type: Boolean, reflect: true })
], LynkButton.prototype, "noBubble", 2);
__decorateClass([
  watch("disabled", { waitUntilFirstUpdate: true })
], LynkButton.prototype, "handleDisabledChange", 1);

export {
  LynkButton
};
