import {
  optgroup_styles_default
} from "./chunk.LMSOUC4X.js";
import {
  LynkDivider
} from "./chunk.HYF7H5JR.js";
import {
  HasSlotController
} from "./chunk.OW5NIGGX.js";
import {
  watch
} from "./chunk.GMYPQTFK.js";
import {
  LynkElement
} from "./chunk.7M4AVQ6D.js";
import {
  __decorateClass
} from "./chunk.KAW7D32O.js";

// src/components/optgroup/optgroup.component.ts
import { classMap } from "lit/directives/class-map.js";
import { html } from "lit/static-html.js";
import { property, query } from "lit/decorators.js";
var LynkOptgroup = class extends LynkElement {
  constructor() {
    super(...arguments);
    this.hasSlotController = new HasSlotController(this, "[default]", "prefix", "suffix", "label");
    this.disabled = false;
    this.label = "";
  }
  /**
   * Syncs the disabled prop for all slotted lynk-options when it is triggered
   */
  handleDisableOptions() {
    const { disabled } = this;
    this.defaultSlot.assignedElements().filter((opt) => opt.tagName.toLowerCase() === "lynk-option").forEach((opt) => {
      opt.disabled = disabled;
    });
  }
  handleDisabledChange() {
    this.handleDisableOptions();
  }
  render() {
    const { disabled } = this;
    const hasLabelSlot = this.hasSlotController.test("label");
    const hasLabel = this.label ? true : !!hasLabelSlot;
    return html`
      <div
        class=${classMap({
      optgroup: true,
      "optgroup--has-label": hasLabel,
      "optgroup--has-prefix": this.hasSlotController.test("prefix"),
      "optgroup--has-suffix": this.hasSlotController.test("suffix"),
      "optgroup--is-disabled": this.disabled
    })}
        role="${disabled ? "presentation" : "group"}"
        part="base"
      >
        <lynk-divider class="optgroup__divider" part="divider"></lynk-divider>
        <div class="optgroup__label-container" part="label-container">
          <slot name="prefix" part="prefix" class="optgroup__prefix"></slot>
          <slot name="label" part="label" class="optgroup__label">
            <span class="optgroup__label-content"> ${this.label} </span>
          </slot>
          <slot name="suffix" part="suffix" class="optgroup__suffix"></slot>
        </div>
        <div class="optgroup__options" role="group" part="options">
          <slot @slotchange=${this.handleDisableOptions}></slot>
        </div>
      </div>
    `;
  }
};
LynkOptgroup.styles = optgroup_styles_default;
LynkOptgroup.dependencies = {
  "lynk-divider": LynkDivider
};
__decorateClass([
  query("slot:not([name])")
], LynkOptgroup.prototype, "defaultSlot", 2);
__decorateClass([
  property({ reflect: true, type: Boolean })
], LynkOptgroup.prototype, "disabled", 2);
__decorateClass([
  property()
], LynkOptgroup.prototype, "label", 2);
__decorateClass([
  watch("disabled", { waitUntilFirstUpdate: true })
], LynkOptgroup.prototype, "handleDisabledChange", 1);

export {
  LynkOptgroup
};
