import {
  menu_item_styles_default
} from "./chunk.6WB5XZE3.js";
import {
  getTextContent
} from "./chunk.OW5NIGGX.js";
import {
  LynkIcon
} from "./chunk.OTHQ47SZ.js";
import {
  watch
} from "./chunk.GMYPQTFK.js";
import {
  LynkElement
} from "./chunk.7M4AVQ6D.js";
import {
  component_styles_default
} from "./chunk.Y7724W4D.js";
import {
  __decorateClass
} from "./chunk.KAW7D32O.js";

// src/components/menu-item/menu-item.component.ts
import { classMap } from "lit/directives/class-map.js";
import { html } from "lit";
import { property, query } from "lit/decorators.js";
var LynkMenuItem = class extends LynkElement {
  constructor() {
    super(...arguments);
    this.type = "normal";
    this.checked = false;
    this.value = "";
    this.disabled = false;
  }
  connectedCallback() {
    super.connectedCallback();
    this.handleHostClick = this.handleHostClick.bind(this);
    this.addEventListener("click", this.handleHostClick);
  }
  disconnectedCallback() {
    super.disconnectedCallback();
    this.removeEventListener("click", this.handleHostClick);
  }
  handleDefaultSlotChange() {
    const textLabel = this.getTextLabel();
    if (typeof this.cachedTextLabel === "undefined") {
      this.cachedTextLabel = textLabel;
      return;
    }
    if (textLabel !== this.cachedTextLabel) {
      this.cachedTextLabel = textLabel;
      this.emit("slotchange", { bubbles: true, composed: false, cancelable: false });
    }
  }
  handleHostClick(event) {
    if (this.disabled) {
      event.preventDefault();
      event.stopImmediatePropagation();
    }
    this.emit("ev-click");
  }
  handleCheckedChange() {
    if (this.checked && this.type !== "checkbox") {
      this.checked = false;
      console.error('The checked attribute can only be used on menu items with type="checkbox"', this);
      return;
    }
    if (this.type === "checkbox") {
      this.setAttribute("aria-checked", this.checked ? "true" : "false");
    } else {
      this.removeAttribute("aria-checked");
    }
  }
  handleDisabledChange() {
    this.setAttribute("aria-disabled", this.disabled ? "true" : "false");
  }
  handleTypeChange() {
    if (this.type === "checkbox") {
      this.setAttribute("role", "menuitemcheckbox");
      this.setAttribute("aria-checked", this.checked ? "true" : "false");
    } else {
      this.setAttribute("role", "menuitem");
      this.removeAttribute("aria-checked");
    }
  }
  /** Returns a text label based on the contents of the menu item's default slot. */
  getTextLabel() {
    return getTextContent(this.defaultSlot);
  }
  render() {
    return html`
      <div
        part="base"
        class=${classMap({
      "menu-item": true,
      "menu-item--checked": this.checked,
      "menu-item--disabled": this.disabled,
      "menu-item--has-submenu": false
      // reserved for future use
    })}
      >
        <span part="checked-icon" class="menu-item__check">
          <lynk-icon name="check" library="system" aria-hidden="true"></lynk-icon>
        </span>

        <slot name="prefix" part="prefix" class="menu-item__prefix"></slot>

        <slot part="label" class="menu-item__label" @slotchange=${this.handleDefaultSlotChange}></slot>

        <slot name="suffix" part="suffix" class="menu-item__suffix"></slot>

        <span class="menu-item__chevron">
          <lynk-icon name="chevron-right" library="system" aria-hidden="true"></lynk-icon>
        </span>
      </div>
    `;
  }
};
LynkMenuItem.styles = [component_styles_default, menu_item_styles_default];
LynkMenuItem.dependencies = {
  "lynk-icon": LynkIcon
};
__decorateClass([
  query("slot:not([name])")
], LynkMenuItem.prototype, "defaultSlot", 2);
__decorateClass([
  query(".menu-item")
], LynkMenuItem.prototype, "menuItem", 2);
__decorateClass([
  property()
], LynkMenuItem.prototype, "type", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkMenuItem.prototype, "checked", 2);
__decorateClass([
  property()
], LynkMenuItem.prototype, "value", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkMenuItem.prototype, "disabled", 2);
__decorateClass([
  watch("checked")
], LynkMenuItem.prototype, "handleCheckedChange", 1);
__decorateClass([
  watch("disabled")
], LynkMenuItem.prototype, "handleDisabledChange", 1);
__decorateClass([
  watch("type")
], LynkMenuItem.prototype, "handleTypeChange", 1);

export {
  LynkMenuItem
};
