import {
  table_styles_default
} from "./chunk.A77KDWFV.js";
import {
  TableSortDirection
} from "./chunk.WGKOAZH2.js";
import {
  LynkElement
} from "./chunk.7M4AVQ6D.js";
import {
  component_styles_default
} from "./chunk.Y7724W4D.js";
import {
  __decorateClass
} from "./chunk.KAW7D32O.js";

// src/components/table/table.component.ts
import { html } from "lit";
import { ifDefined } from "lit/directives/if-defined.js";
import { property, queryAssignedElements } from "lit/decorators.js";
import { repeat } from "lit/directives/repeat.js";
var LynkTable = class extends LynkElement {
  constructor() {
    super(...arguments);
    this.cols = [];
    this.rows = [];
    this.custom = false;
  }
  connectedCallback() {
    super.connectedCallback();
    this.addEventListener("ev-table-sort", this.handleSort);
  }
  disconnectedCallback() {
    super.disconnectedCallback();
    this.removeEventListener("ev-table-sort", this.handleSort);
  }
  handleSort(event) {
    let direction;
    this.assignedHead.forEach((head) => {
      head.querySelectorAll("lynk-tr").forEach((row) => {
        row.querySelectorAll("lynk-th").forEach((th) => {
          if (th.key === event.detail.key) {
            switch (TableSortDirection[th.sortDirection]) {
              case TableSortDirection[1 /* DESC */]:
                th.sortDirection = -1 /* ASC */;
                break;
              case TableSortDirection[-1 /* ASC */]:
              case TableSortDirection[0 /* NONE */]:
                th.sortDirection = 1 /* DESC */;
                break;
            }
            direction = th.sortDirection;
          } else {
            th.sortDirection = 0 /* NONE */;
          }
        });
      });
    });
    this.rows.sort((rowA, rowB) => {
      let val1 = rowA[event.detail.key];
      let val2 = rowB[event.detail.key];
      if (val1 === null || val1 === void 0) val1 = "";
      if (val2 === null || val2 === void 0) val2 = "";
      if (!isNaN(parseFloat(val1)) && !isNaN(parseFloat(val2))) {
        return (Number(val1) - Number(val2)) * direction;
      }
      const str1 = val1.toString();
      const str2 = val2.toString();
      return str1.localeCompare(str2) * direction;
    });
    this.requestUpdate();
  }
  render() {
    return html`
      <slot part="base">
        <lynk-colgroup> ${repeat(this.cols, (col) => html`<lynk-col class="${col.key}"></lynk-col>`)} </lynk-colgroup>
        <lynk-thead>
          <lynk-tr>
            ${repeat(
      this.cols,
      (col) => html`
                <lynk-th
                  key="${col.key}"
                  sort-direction=${ifDefined(col.sortDirection ? col.sortDirection : void 0)}
                  ?sortable=${ifDefined(col.sortable ? col.sortable : void 0)}
                  >${col.title}</lynk-th
                >
              `
    )}
          </lynk-tr>
        </lynk-thead>
        <lynk-tbody>
          ${repeat(
      this.rows,
      (row) => html` <lynk-tr> ${repeat(this.cols, (col) => html`<lynk-td>${row[col.key]}</lynk-td>`)} </lynk-tr>`
    )}
        </lynk-tbody>
      </slot>
    `;
  }
};
LynkTable.styles = [component_styles_default, table_styles_default];
__decorateClass([
  property()
], LynkTable.prototype, "cols", 2);
__decorateClass([
  property()
], LynkTable.prototype, "rows", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkTable.prototype, "custom", 2);
__decorateClass([
  queryAssignedElements({ selector: "lynk-thead", flatten: true })
], LynkTable.prototype, "assignedHead", 2);
__decorateClass([
  queryAssignedElements({ selector: "lynk-tbody", flatten: true })
], LynkTable.prototype, "assignedBody", 2);

export {
  LynkTable
};
