import {
  nav_item_styles_default
} from "./chunk.2TXKZODQ.js";
import {
  LynkTooltip
} from "./chunk.TNZ6RBLS.js";
import {
  animateTo,
  shimKeyframesHeightAuto,
  stopAnimations
} from "./chunk.YEUBLCCQ.js";
import {
  getAnimation,
  setDefaultAnimation
} from "./chunk.K7JGTRV7.js";
import {
  getTextContent
} from "./chunk.OW5NIGGX.js";
import {
  LocalizeController
} from "./chunk.6CTB5ZDJ.js";
import {
  LynkIcon
} from "./chunk.OTHQ47SZ.js";
import {
  watch
} from "./chunk.GMYPQTFK.js";
import {
  LynkElement
} from "./chunk.7M4AVQ6D.js";
import {
  component_styles_default
} from "./chunk.Y7724W4D.js";
import {
  __decorateClass
} from "./chunk.KAW7D32O.js";

// src/components/nav-item/nav-item.component.ts
import { classMap } from "lit/directives/class-map.js";
import { html, literal } from "lit/static-html.js";
import { ifDefined } from "lit/directives/if-defined.js";
import { property, query, state } from "lit/decorators.js";
var _LynkNavItem = class _LynkNavItem extends LynkElement {
  constructor() {
    super(...arguments);
    this.localize = new LocalizeController(this);
    this.childItems = [];
    this.isParent = false;
    this.isChild = false;
    this.loading = false;
    this.depth = 0;
    this.squished = false;
    this.title = "";
    this.name = "";
    this.value = "";
    this.href = "";
    this.selected = false;
    this.expanded = false;
    this.disabled = false;
    this.noLabel = false;
  }
  static isTreeItem(node) {
    return node instanceof Element && node.getAttribute("role") === "treeitem";
  }
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "treeitem");
    this.setAttribute("tabindex", "-1");
    if (this.isNestedItem()) {
      this.slot = "children";
      this.isChild = true;
      this.depth = this.getDepth();
    }
  }
  firstUpdated() {
    if (this.childrenContainer) {
      this.childrenContainer.hidden = !this.expanded;
      this.childrenContainer.style.height = this.expanded ? "auto" : "0";
    }
    this.isParent = this.hasChildren;
    this.handleExpandedChange();
    this.handleSquished();
  }
  /** Simulates a click on the nav item. */
  click() {
    this.navItem.click();
  }
  async animateCollapse() {
    this.emit("ev-collapse");
    await stopAnimations(this.childrenContainer);
    const { keyframes, options } = getAnimation(this, "nav-item.collapse", { dir: this.localize.dir() });
    await animateTo(
      this.childrenContainer,
      shimKeyframesHeightAuto(keyframes, this.childrenContainer.scrollHeight),
      options
    );
    this.childrenContainer.hidden = true;
    this.emit("ev-after-collapse");
  }
  async animateExpand() {
    this.emit("ev-expand");
    await stopAnimations(this.childrenContainer);
    this.childrenContainer.hidden = false;
    const { keyframes, options } = getAnimation(this, "nav-item.expand", { dir: this.localize.dir() });
    await animateTo(
      this.childrenContainer,
      shimKeyframesHeightAuto(keyframes, this.childrenContainer.scrollHeight),
      options
    );
    this.childrenContainer.style.height = "auto";
    this.emit("ev-after-expand");
  }
  // Checks whether the item is nested into an item
  isNestedItem() {
    const parent = this.parentElement;
    return !!parent && _LynkNavItem.isTreeItem(parent);
  }
  handleChildrenSlotChange() {
    this.childItems = this.getChildrenItems();
    this.isParent = this.childItems.length > 0;
  }
  get hasChildren() {
    return this.childItems.length > 0;
  }
  getDepth() {
    let depth = 0;
    let element = this.parentElement;
    while (element instanceof _LynkNavItem) {
      depth++;
      element = element.parentElement;
    }
    return depth;
  }
  /** Returns a text label based on the contents of the menu item's default slot. */
  getTextLabel() {
    return getTextContent(this.defaultSlot);
  }
  handleDisabledChange() {
    this.setAttribute("aria-disabled", this.disabled ? "true" : "false");
  }
  handleExpandedChange() {
    if (this.hasChildren) {
      this.setAttribute("aria-expanded", this.expanded ? "true" : "false");
    } else {
      this.removeAttribute("aria-expanded");
    }
  }
  handleExpandAnimation() {
    if (this.expanded) {
      this.animateExpand();
    } else {
      this.animateCollapse();
    }
  }
  handleSquished() {
    if (this.squished) {
      this.setAttribute("squished", this.squished ? "true" : "false");
    } else {
      this.removeAttribute("squished");
    }
  }
  handleClick(event) {
    if (this.disabled) {
      event.preventDefault();
      event.stopPropagation();
      return;
    }
    if (this.hasChildren) {
      this.expanded = !this.expanded;
      event.stopPropagation();
    }
  }
  handleDefaultSlotChange() {
    const textLabel = this.getTextLabel();
    if (typeof this.cachedTextLabel === "undefined") {
      this.cachedTextLabel = textLabel;
      return;
    }
    if (textLabel !== this.cachedTextLabel) {
      this.cachedTextLabel = textLabel;
      this.emit("slotchange", { bubbles: true, composed: false, cancelable: false });
    }
  }
  /** Gets all the nested tree items in this node. */
  getChildrenItems({ includeDisabled = true } = {}) {
    return this.childrenSlot ? [...this.childrenSlot.assignedElements({ flatten: true })].filter(
      (item) => _LynkNavItem.isTreeItem(item) && (includeDisabled || !item.disabled)
    ) : [];
  }
  render() {
    const isLink = Boolean(this.href);
    const tag = isLink ? literal`a` : literal`button`;
    const isRtl = this.localize.dir() === "rtl";
    return html`
      <${tag}
        class=${classMap({
      "nav-item": true,
      "nav-item--disabled": this.disabled,
      "nav-item--selected": this.selected,
      "nav-item--has-children": this.isParent,
      "nav-item--expanded": this.expanded,
      "nav-item--squished": this.squished,
      "nav-item--rtl": isRtl
    })}
        ?disabled=${this.disabled}
        title=${this.title}
        part="nav-item"
        name=${ifDefined(isLink ? void 0 : this.name)}
        value=${ifDefined(isLink ? void 0 : this.value)}
        href=${ifDefined(isLink ? this.href : void 0)}
        target=${ifDefined(isLink ? this.target : void 0)}
        download=${ifDefined(isLink ? this.download : void 0)}
        rel=${ifDefined(isLink && this.target ? "noreferrer noopener" : void 0)}
        data-level=${this.depth}
        aria-disabled=${this.disabled ? "true" : "false"}
        @click=${this.handleClick}
        tabindex="-1"
        aria-current=${ifDefined(this.selected && this.href ? "page" : void 0)}
      >
        <slot name="prefix" part="prefix" class="nav-item__prefix"></slot>
        <slot part="label" class="nav-item__label" @slotchange=${this.handleDefaultSlotChange}></slot>

        <slot name="suffix" part="suffix" class="nav-item__suffix"></slot>

        ${this.isParent ? html`
                <span class="nav-item__chevron">
                  <lynk-icon
                    library="system"
                    aria-hidden="true"
                    name=${this.squished ? "chevron-down" : isRtl ? "chevron-left" : "chevron-right"}
                  ></lynk-icon>
                </span>
              ` : ""}

        ${this.target === "_blank" ? html`
                <span class="nav-item__external">
                  <lynk-icon library="system" aria-hidden="true" name="external"></lynk-icon>
                </span>
              ` : ""}

      </${tag}>

      <div
        part="children"
        class="nav-item__children"
        role="group"
        ?inert=${!this.expanded}
      >
        <slot name="children" @slotchange="${this.handleChildrenSlotChange}"></slot>
      </div>
    `;
  }
};
_LynkNavItem.styles = [component_styles_default, nav_item_styles_default];
_LynkNavItem.dependencies = { "lynk-icon": LynkIcon, "lynk-tooltip": LynkTooltip };
__decorateClass([
  state()
], _LynkNavItem.prototype, "isParent", 2);
__decorateClass([
  state()
], _LynkNavItem.prototype, "isChild", 2);
__decorateClass([
  state()
], _LynkNavItem.prototype, "loading", 2);
__decorateClass([
  state()
], _LynkNavItem.prototype, "depth", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], _LynkNavItem.prototype, "squished", 2);
__decorateClass([
  property()
], _LynkNavItem.prototype, "title", 2);
__decorateClass([
  property()
], _LynkNavItem.prototype, "name", 2);
__decorateClass([
  property()
], _LynkNavItem.prototype, "value", 2);
__decorateClass([
  property()
], _LynkNavItem.prototype, "href", 2);
__decorateClass([
  property()
], _LynkNavItem.prototype, "target", 2);
__decorateClass([
  property()
], _LynkNavItem.prototype, "download", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], _LynkNavItem.prototype, "selected", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], _LynkNavItem.prototype, "expanded", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], _LynkNavItem.prototype, "disabled", 2);
__decorateClass([
  property({ attribute: "no-label", type: Boolean, reflect: true })
], _LynkNavItem.prototype, "noLabel", 2);
__decorateClass([
  query("slot:not([name])")
], _LynkNavItem.prototype, "defaultSlot", 2);
__decorateClass([
  query("slot[name=children]")
], _LynkNavItem.prototype, "childrenSlot", 2);
__decorateClass([
  query(".nav-item")
], _LynkNavItem.prototype, "navItem", 2);
__decorateClass([
  query(".nav-item__children")
], _LynkNavItem.prototype, "childrenContainer", 2);
__decorateClass([
  watch("disabled")
], _LynkNavItem.prototype, "handleDisabledChange", 1);
__decorateClass([
  watch("expanded", { waitUntilFirstUpdate: true })
], _LynkNavItem.prototype, "handleExpandedChange", 1);
__decorateClass([
  watch("expanded", { waitUntilFirstUpdate: true })
], _LynkNavItem.prototype, "handleExpandAnimation", 1);
__decorateClass([
  watch("squished", { waitUntilFirstUpdate: true })
], _LynkNavItem.prototype, "handleSquished", 1);
var LynkNavItem = _LynkNavItem;
setDefaultAnimation("nav-item.expand", {
  keyframes: [
    { height: "0", opacity: "0", overflow: "hidden" },
    { height: "auto", opacity: "1", overflow: "hidden" }
  ],
  options: { duration: 250, easing: "cubic-bezier(0.4, 0.0, 0.2, 1)" }
});
setDefaultAnimation("nav-item.collapse", {
  keyframes: [
    { height: "auto", opacity: "1", overflow: "hidden" },
    { height: "0", opacity: "0", overflow: "hidden" }
  ],
  options: { duration: 200, easing: "cubic-bezier(0.4, 0.0, 0.2, 1)" }
});

export {
  LynkNavItem
};
