// src/components/switch/switch.styles.ts
import { css } from "lit";
var switch_styles_default = css`
  :host {
    display: inline-block;
  }

  :host([size='small']) {
    --height: var(--lynk-toggle-size-small);
    --thumb-size: calc(var(--lynk-toggle-size-small) + 4px);
    --width: calc(var(--height) * 2);

    font-size: var(--lynk-input-font-size-small);
  }

  :host([size='medium']) {
    --height: var(--lynk-toggle-size-medium);
    --thumb-size: calc(var(--lynk-toggle-size-medium) + 4px);
    --width: calc(var(--height) * 2);

    font-size: var(--lynk-input-font-size-medium);
  }

  :host([size='large']) {
    --height: var(--lynk-toggle-size-large);
    --thumb-size: calc(var(--lynk-toggle-size-large) + 4px);
    --width: calc(var(--height) * 2);

    font-size: var(--lynk-input-font-size-large);
  }

  .switch {
    position: relative;
    display: inline-flex;
    align-items: center;
    font-family: var(--lynk-input-font-family);
    font-size: inherit;
    font-weight: var(--lynk-input-font-weight);
    color: var(--lynk-input-color);
    vertical-align: middle;
    cursor: pointer;
  }

  .switch__control {
    flex: 0 0 auto;
    position: relative;
    display: inline-flex;
    align-items: center;
    justify-content: center;
    width: var(--width);
    height: var(--height);
    background-color: var(--lynk-color-neutral-400);
    border: solid var(--lynk-input-border-width) var(--lynk-color-neutral-400);
    border-radius: var(--height);
    transition:
      var(--lynk-transition-fast) border-color,
      var(--lynk-transition-fast) background-color;
  }

  .switch__control .switch__thumb {
    width: var(--thumb-size);
    height: var(--thumb-size);
    background-color: var(--lynk-color-neutral-0);
    border-radius: 50%;
    border: solid var(--lynk-input-border-width) var(--lynk-color-neutral-400);
    translate: calc((var(--width) - var(--height)) / -2);
    transition:
      var(--lynk-transition-fast) translate ease,
      var(--lynk-transition-fast) background-color,
      var(--lynk-transition-fast) border-color,
      var(--lynk-transition-fast) box-shadow;
  }

  .switch__input {
    position: absolute;
    opacity: 0;
    padding: 0;
    margin: 0;
    pointer-events: none;
  }

  /* Hover */
  .switch:not(.switch--checked):not(.switch--disabled) .switch__control:hover {
    background-color: var(--lynk-color-neutral-400);
    border-color: var(--lynk-color-neutral-400);
  }

  .switch:not(.switch--checked):not(.switch--disabled) .switch__control:hover .switch__thumb {
    background-color: var(--lynk-color-neutral-0);
    border-color: var(--lynk-color-neutral-400);
  }

  /* Focus */
  .switch:not(.switch--checked):not(.switch--disabled) .switch__input:focus-visible ~ .switch__control {
    background-color: var(--lynk-color-neutral-400);
    border-color: var(--lynk-color-neutral-400);
  }

  .switch:not(.switch--checked):not(.switch--disabled) .switch__input:focus-visible ~ .switch__control .switch__thumb {
    background-color: var(--lynk-color-neutral-0);
    border-color: var(--lynk-color-primary-600);
    box-shadow: 0 0 0 var(--lynk-focus-ring-width) var(--lynk-input-focus-ring-color);
  }

  /* Checked  */
  .switch--checked .switch__control {
    background-color: var(--lynk-color-primary-600);
    border-color: var(--lynk-color-primary-600);
  }

  .switch--checked .switch__control .switch__thumb {
    background-color: var(--lynk-color-neutral-0);
    border-color: var(--lynk-color-primary-600);
    translate: calc((var(--width) - var(--height)) / 2);
  }

  /* Checked + hover */
  .switch.switch--checked:not(.switch--disabled) .switch__control:hover {
    background-color: var(--lynk-color-primary-600);
    border-color: var(--lynk-color-primary-600);
  }

  .switch.switch--checked:not(.switch--disabled) .switch__control:hover .switch__thumb {
    background-color: var(--lynk-color-neutral-0);
    border-color: var(--lynk-color-primary-600);
  }

  /* Checked + focus */
  .switch.switch--checked:not(.switch--disabled) .switch__input:focus-visible ~ .switch__control {
    background-color: var(--lynk-color-primary-600);
    border-color: var(--lynk-color-primary-600);
  }

  .switch.switch--checked:not(.switch--disabled) .switch__input:focus-visible ~ .switch__control .switch__thumb {
    background-color: var(--lynk-color-neutral-0);
    border-color: var(--lynk-color-primary-600);
    box-shadow: 0 0 0 var(--lynk-focus-ring-width) var(--lynk-input-focus-ring-color);
  }

  /* Success + Checked */
  .switch--checked.switch--success .switch__control {
    background-color: var(--lynk-color-success);
    border-color: var(--lynk-color-success);
  }

  .switch--checked.switch--success .switch__control .switch__thumb {
    border-color: var(--lynk-color-success);
  }

  /* Success + Checked + hover */
  .switch.switch--success.switch--checked:not(.switch--disabled) .switch__control:hover {
    background-color: var(--lynk-color-success);
    border-color: var(--lynk-color-success);
  }

  .switch.switch--success.switch--checked:not(.switch--disabled) .switch__control:hover .switch__thumb {
    border-color: var(--lynk-color-success);
  }

  /* Success + Checked + focus */
  .switch.switch--success.switch--checked:not(.switch--disabled) .switch__input:focus-visible ~ .switch__control {
    background-color: var(--lynk-color-success);
    border-color: var(--lynk-color-success);
  }

  .switch.switch--success.switch--checked:not(.switch--disabled)
    .switch__input:focus-visible
    ~ .switch__control
    .switch__thumb {
    border-color: var(--lynk-color-success);
  }

  /* Warning + Checked */
  .switch--checked.switch--warning .switch__control {
    background-color: var(--lynk-color-warning);
    border-color: var(--lynk-color-warning);
  }

  .switch--checked.switch--warning .switch__control .switch__thumb {
    border-color: var(--lynk-color-warning);
  }

  /* Warning + Checked + hover */
  .switch.switch--warning.switch--checked:not(.switch--disabled) .switch__control:hover {
    background-color: var(--lynk-color-warning);
    border-color: var(--lynk-color-warning);
  }

  .switch.switch--warning.switch--checked:not(.switch--disabled) .switch__control:hover .switch__thumb {
    border-color: var(--lynk-color-warning);
  }

  /* Warning + Checked + focus */
  .switch.switch--warning.switch--checked:not(.switch--disabled) .switch__input:focus-visible ~ .switch__control {
    background-color: var(--lynk-color-warning);
    border-color: var(--lynk-color-warning);
  }

  .switch.switch--warning.switch--checked:not(.switch--disabled)
    .switch__input:focus-visible
    ~ .switch__control
    .switch__thumb {
    border-color: var(--lynk-color-warning);
  }

  /* Danger + Checked */
  .switch--checked.switch--danger .switch__control {
    background-color: var(--lynk-color-danger);
    border-color: var(--lynk-color-danger);
  }

  .switch--checked.switch--danger .switch__control .switch__thumb {
    border-color: var(--lynk-color-danger);
  }

  /* Danger + Checked + hover */
  .switch.switch--danger.switch--checked:not(.switch--disabled) .switch__control:hover {
    background-color: var(--lynk-color-danger);
    border-color: var(--lynk-color-danger);
  }

  .switch.switch--danger.switch--checked:not(.switch--disabled) .switch__control:hover .switch__thumb {
    border-color: var(--lynk-color-danger);
  }

  /* Danger + Checked + focus */
  .switch.switch--danger.switch--checked:not(.switch--disabled) .switch__input:focus-visible ~ .switch__control {
    background-color: var(--lynk-color-danger);
    border-color: var(--lynk-color-danger);
  }

  .switch.switch--danger.switch--checked:not(.switch--disabled)
    .switch__input:focus-visible
    ~ .switch__control
    .switch__thumb {
    border-color: var(--lynk-color-danger);
  }

  /* Disabled */
  .switch--disabled {
    opacity: 0.5;
    cursor: not-allowed;
  }

  .switch__label {
    display: inline-block;
    line-height: var(--height);
    margin-inline-start: 0.5em;
    user-select: none;
  }

  :host([required]) .switch__label::after {
    content: var(--lynk-input-required-content);
    margin-inline-start: var(--lynk-input-required-content-offset);
  }
`;

export {
  switch_styles_default
};
