import {
  option_styles_default
} from "./chunk.GQEHHCEJ.js";
import {
  LocalizeController
} from "./chunk.6CTB5ZDJ.js";
import {
  LynkIcon
} from "./chunk.OTHQ47SZ.js";
import {
  watch
} from "./chunk.GMYPQTFK.js";
import {
  LynkElement
} from "./chunk.7M4AVQ6D.js";
import {
  component_styles_default
} from "./chunk.Y7724W4D.js";
import {
  __decorateClass
} from "./chunk.KAW7D32O.js";

// src/components/option/option.component.ts
import { classMap } from "lit/directives/class-map.js";
import { html } from "lit";
import { property, query, state } from "lit/decorators.js";
var LynkOption = class extends LynkElement {
  constructor() {
    super(...arguments);
    // @ts-expect-error - Controller is currently unused
    this.localize = new LocalizeController(this);
    this.isInitialized = false;
    this.current = false;
    this.selected = false;
    this.hasHover = false;
    this.value = "";
    this.disabled = false;
  }
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "option");
    this.setAttribute("aria-selected", "false");
  }
  handleDefaultSlotChange() {
    if (this.isInitialized) {
      customElements.whenDefined("lynk-combobox").then(() => {
        const controller = this.closest("lynk-combobox");
        if (controller) {
          controller.handleDefaultSlotChange();
        }
      });
      customElements.whenDefined("lynk-select").then(() => {
        const controller = this.closest("lynk-select");
        if (controller) {
          controller.handleDefaultSlotChange();
        }
      });
    } else {
      this.isInitialized = true;
    }
  }
  handleMouseEnter() {
    this.hasHover = true;
  }
  handleMouseLeave() {
    this.hasHover = false;
  }
  handleDisabledChange() {
    this.setAttribute("aria-disabled", this.disabled ? "true" : "false");
  }
  handleSelectedChange() {
    this.setAttribute("aria-selected", this.selected ? "true" : "false");
  }
  handleValueChange() {
    if (typeof this.value !== "string") {
      this.value = String(this.value);
    }
    if (this.value.includes(" ")) {
      console.error(`Option values cannot include a space. All spaces have been replaced with underscores.`, this);
      this.value = this.value.replace(/ /g, "_");
    }
  }
  /** Returns a plain text label based on the option's content. */
  getTextLabel() {
    const nodes = this.childNodes;
    let label = "";
    [...nodes].forEach((node) => {
      if (node.nodeType === Node.ELEMENT_NODE) {
        if (!node.hasAttribute("slot")) {
          label += node.textContent;
        }
      }
      if (node.nodeType === Node.TEXT_NODE) {
        label += node.textContent;
      }
    });
    return label.trim();
  }
  render() {
    return html`
      <div
        part="base"
        class=${classMap({
      option: true,
      "option--current": this.current,
      "option--disabled": this.disabled,
      "option--selected": this.selected,
      "option--hover": this.hasHover
    })}
        @mouseenter=${this.handleMouseEnter}
        @mouseleave=${this.handleMouseLeave}
      >
        <lynk-icon
          part="checked-icon"
          class="option__check"
          name="check"
          library="system"
          aria-hidden="true"
        ></lynk-icon>
        <slot part="prefix" name="prefix" class="option__prefix"></slot>
        <slot part="label" class="option__label" @slotchange=${this.handleDefaultSlotChange}></slot>
        <slot part="suffix" name="suffix" class="option__suffix"></slot>
      </div>
    `;
  }
};
LynkOption.styles = [component_styles_default, option_styles_default];
LynkOption.dependencies = { "lynk-icon": LynkIcon };
__decorateClass([
  query(".option__label")
], LynkOption.prototype, "defaultSlot", 2);
__decorateClass([
  state()
], LynkOption.prototype, "current", 2);
__decorateClass([
  state()
], LynkOption.prototype, "selected", 2);
__decorateClass([
  state()
], LynkOption.prototype, "hasHover", 2);
__decorateClass([
  property({ reflect: true })
], LynkOption.prototype, "value", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkOption.prototype, "disabled", 2);
__decorateClass([
  watch("disabled")
], LynkOption.prototype, "handleDisabledChange", 1);
__decorateClass([
  watch("selected")
], LynkOption.prototype, "handleSelectedChange", 1);
__decorateClass([
  watch("value")
], LynkOption.prototype, "handleValueChange", 1);

export {
  LynkOption
};
