// src/components/button/button.styles.ts
import { css } from "lit";
var button_styles_default = css`
  :host {
    display: inline-block;
    position: relative;
    width: auto;
    cursor: pointer;
    line-height: initial;
  }

  :host([block]) {
    display: block;
  }

  .button {
    display: inline-flex;
    align-items: stretch;
    justify-content: center;
    width: 100%;
    border-style: solid;
    border-width: var(--lynk-button-border-width);
    font-family: var(--lynk-button-font-family);
    font-weight: var(--lynk-font-weight-bold);
    text-decoration: none;
    user-select: none;
    -webkit-user-select: none;
    white-space: nowrap;
    vertical-align: middle;
    padding: 0;
    transition:
      var(--lynk-transition-x-fast) background-color,
      var(--lynk-transition-x-fast) color,
      var(--lynk-transition-x-fast) border,
      var(--lynk-transition-x-fast) box-shadow;
    cursor: inherit;
  }

  .button::-moz-focus-inner {
    border: 0;
  }

  .button:focus {
    outline: none;
  }

  .button:focus-visible {
    outline: var(--lynk-focus-ring);
    outline-offset: var(--lynk-focus-ring-offset);
  }

  .button--disabled {
    opacity: 0.4;
    cursor: not-allowed;
  }

  /* When disabled, prevent mouse events from bubbling up from children */
  .button--disabled * {
    pointer-events: none;
  }

  .button__prefix,
  .button__suffix {
    flex: 0 0 auto;
    display: flex;
    align-items: center;
    pointer-events: none;
  }

  .button__label {
    display: inline-block;
  }

  .button__label::slotted(lynk-icon) {
    vertical-align: -2px;
  }

  /*
   * Standard buttons
   */

  /* Default */
  .button--standard.button--default {
    background-color: var(--lynk-color-neutral-0);
    border-color: var(--lynk-color-neutral-300);
    color: var(--lynk-color-neutral-700);
  }

  .button--standard.button--default:hover:not(.button--disabled) {
    background-color: var(--lynk-color-primary-50);
    border-color: var(--lynk-color-primary-300);
    color: var(--lynk-color-primary-700);
  }

  .button--standard.button--default:active:not(.button--disabled) {
    background-color: var(--lynk-color-primary-100);
    border-color: var(--lynk-color-primary-400);
    color: var(--lynk-color-primary-700);
  }

  .button--standard.button--default.button--checked:not(.button--disabled) {
    background-color: var(--lynk-color-primary-500);
    border-color: var(--lynk-color-primary-500);
    color: var(--lynk-color-neutral-0);
  }

  /* Primary */
  .button--standard.button--primary {
    background-color: var(--lynk-color-primary-600);
    border-color: var(--lynk-color-primary-600);
    color: var(--lynk-color-neutral-0);
  }

  .button--standard.button--primary:hover:not(.button--disabled) {
    background-color: var(--lynk-color-primary-500);
    border-color: var(--lynk-color-primary-500);
    color: var(--lynk-color-neutral-0);
  }

  .button--standard.button--primary:active:not(.button--disabled) {
    background-color: var(--lynk-color-primary-400);
    border-color: var(--lynk-color-primary-400);
    color: var(--lynk-color-neutral-0);
  }

  /* Accent */
  .button--standard.button--accent {
    background-color: var(--lynk-color-accent-500);
    border-color: var(--lynk-color-accent-500);
    color: var(--lynk-color-neutral-0);
  }

  .button--standard.button--accent:hover:not(.button--disabled) {
    background-color: var(--lynk-color-accent-400);
    border-color: var(--lynk-color-accent-400);
    color: var(--lynk-color-neutral-0);
  }

  .button--standard.button--accent:active:not(.button--disabled) {
    background-color: var(--lynk-color-accent-300);
    border-color: var(--lynk-color-accent-300);
    color: var(--lynk-color-neutral-0);
  }

  /* Success */
  .button--standard.button--success {
    background-color: var(--lynk-color-success-600);
    border-color: var(--lynk-color-success-600);
    color: var(--lynk-color-neutral-0);
  }

  .button--standard.button--success:hover:not(.button--disabled) {
    background-color: var(--lynk-color-success-500);
    border-color: var(--lynk-color-success-500);
    color: var(--lynk-color-neutral-0);
  }

  .button--standard.button--success:active:not(.button--disabled) {
    background-color: var(--lynk-color-success-400);
    border-color: var(--lynk-color-success-400);
    color: var(--lynk-color-neutral-0);
  }

  /* Neutral */
  .button--standard.button--neutral {
    background-color: var(--lynk-color-neutral-600);
    border-color: var(--lynk-color-neutral-600);
    color: var(--lynk-color-neutral-0);
  }

  .button--standard.button--neutral:hover:not(.button--disabled) {
    background-color: var(--lynk-color-neutral-500);
    border-color: var(--lynk-color-neutral-500);
    color: var(--lynk-color-neutral-0);
  }

  .button--standard.button--neutral:active:not(.button--disabled) {
    background-color: var(--lynk-color-neutral-400);
    border-color: var(--lynk-color-neutral-400);
    color: var(--lynk-color-neutral-0);
  }

  /* Warning */
  .button--standard.button--warning {
    background-color: var(--lynk-color-warning-600);
    border-color: var(--lynk-color-warning-600);
    color: var(--lynk-color-neutral-0);
  }
  .button--standard.button--warning:hover:not(.button--disabled) {
    background-color: var(--lynk-color-warning-500);
    border-color: var(--lynk-color-warning-500);
    color: var(--lynk-color-neutral-0);
  }

  .button--standard.button--warning:active:not(.button--disabled) {
    background-color: var(--lynk-color-warning-400);
    border-color: var(--lynk-color-warning-400);
    color: var(--lynk-color-neutral-0);
  }

  /* Danger */
  .button--standard.button--danger {
    background-color: var(--lynk-color-danger-600);
    border-color: var(--lynk-color-danger-600);
    color: var(--lynk-color-neutral-0);
  }

  .button--standard.button--danger:hover:not(.button--disabled) {
    background-color: var(--lynk-color-danger-500);
    border-color: var(--lynk-color-danger-500);
    color: var(--lynk-color-neutral-0);
  }

  .button--standard.button--danger:active:not(.button--disabled) {
    background-color: var(--lynk-color-danger-400);
    border-color: var(--lynk-color-danger-400);
    color: var(--lynk-color-neutral-0);
  }

  /* Info */
  .button--standard.button--info {
    background-color: var(--lynk-color-info-500);
    border-color: var(--lynk-color-info-500);
    color: var(--lynk-color-neutral-0);
  }

  .button--standard.button--info:hover:not(.button--disabled) {
    background-color: var(--lynk-color-info-400);
    border-color: var(--lynk-color-info-400);
    color: var(--lynk-color-neutral-0);
  }

  .button--standard.button--info:active:not(.button--disabled) {
    background-color: var(--lynk-color-info-300);
    border-color: var(--lynk-color-info-300);
    color: var(--lynk-color-neutral-0);
  }

  /*
   * Outline buttons
   */

  .button--outline {
    background: none;
    border: solid 1px;
  }

  /* Default */
  .button--outline.button--default {
    border-color: var(--lynk-color-neutral-300);
    color: var(--lynk-color-neutral-800);
  }

  .button--outline.button--default:hover:not(.button--disabled),
  .button--outline.button--default.button--checked:not(.button--disabled) {
    background-color: var(--lynk-color-primary-50);
    border-color: var(--lynk-color-primary-300);
    color: var(--lynk-color-primary-700);
  }

  .button--outline.button--default:active:not(.button--disabled) {
    background-color: var(--lynk-color-primary-100);
    border-color: var(--lynk-color-primary-400);
    color: var(--lynk-color-primary-700);
  }

  /* Primary */
  .button--outline.button--primary {
    border-color: var(--lynk-color-primary-500);
    background-color: var(--lynk-color-primary-a10);
    color: var(--lynk-color-primary-500);
  }

  .button--outline.button--primary:hover:not(.button--disabled),
  .button--outline.button--primary.button--checked:not(.button--disabled) {
    background-color: var(--lynk-color-primary-500);
    color: var(--lynk-color-neutral-0);
  }

  .button--outline.button--primary:active:not(.button--disabled) {
    border-color: var(--lynk-color-primary-400);
    background-color: var(--lynk-color-primary-400);
    color: var(--lynk-color-neutral-0);
  }

  /* Accent */
  .button--outline.button--accent {
    border-color: var(--lynk-color-accent-500);
    background-color: var(--lynk-color-accent-a10);
    color: var(--lynk-color-accent-500);
  }

  .button--outline.button--accent:hover:not(.button--disabled),
  .button--outline.button--accent.button--checked:not(.button--disabled) {
    background-color: var(--lynk-color-accent-500);
    color: var(--lynk-color-neutral-0);
  }

  .button--outline.button--accent:active:not(.button--disabled) {
    border-color: var(--lynk-color-accent-400);
    background-color: var(--lynk-color-accent-400);
    color: var(--lynk-color-neutral-0);
  }

  /* Success */
  .button--outline.button--success {
    border-color: var(--lynk-color-success-600);
    background-color: var(--lynk-color-success-a10);
    color: var(--lynk-color-success-600);
  }

  .button--outline.button--success:hover:not(.button--disabled),
  .button--outline.button--success.button--checked:not(.button--disabled) {
    background-color: var(--lynk-color-success-600);
    color: var(--lynk-color-neutral-0);
  }

  .button--outline.button--success:active:not(.button--disabled) {
    border-color: var(--lynk-color-success-500);
    background-color: var(--lynk-color-success-500);
    color: var(--lynk-color-neutral-0);
  }

  /* Neutral */
  .button--outline.button--neutral {
    border-color: var(--lynk-color-neutral-600);
    background-color: var(--lynk-color-gray-a10);
    color: var(--lynk-color-neutral-600);
  }

  .button--outline.button--neutral:hover:not(.button--disabled),
  .button--outline.button--neutral.button--checked:not(.button--disabled) {
    background-color: var(--lynk-color-neutral-600);
    color: var(--lynk-color-neutral-0);
  }

  .button--outline.button--neutral:active:not(.button--disabled) {
    border-color: var(--lynk-color-neutral-500);
    background-color: var(--lynk-color-neutral-500);
    color: var(--lynk-color-neutral-0);
  }

  /* Warning */
  .button--outline.button--warning {
    border-color: var(--lynk-color-warning-600);
    background-color: var(--lynk-color-warning-a10);
    color: var(--lynk-color-warning-600);
  }

  .button--outline.button--warning:hover:not(.button--disabled),
  .button--outline.button--warning.button--checked:not(.button--disabled) {
    background-color: var(--lynk-color-warning-600);
    color: var(--lynk-color-neutral-0);
  }

  .button--outline.button--warning:active:not(.button--disabled) {
    border-color: var(--lynk-color-warning-500);
    background-color: var(--lynk-color-warning-500);
    color: var(--lynk-color-neutral-0);
  }

  /* Danger */
  .button--outline.button--danger {
    border-color: var(--lynk-color-danger-600);
    background-color: var(--lynk-color-danger-a10);
    color: var(--lynk-color-danger-600);
  }

  .button--outline.button--danger:hover:not(.button--disabled),
  .button--outline.button--danger.button--checked:not(.button--disabled) {
    background-color: var(--lynk-color-danger-600);
    color: var(--lynk-color-neutral-0);
  }

  .button--outline.button--danger:active:not(.button--disabled) {
    border-color: var(--lynk-color-danger-500);
    background-color: var(--lynk-color-danger-500);
    color: var(--lynk-color-neutral-0);
  }

  /* Info */
  .button--outline.button--info {
    border-color: var(--lynk-color-info-600);
    background-color: var(--lynk-color-info-a10);
    color: var(--lynk-color-info-600);
  }

  .button--outline.button--info:hover:not(.button--disabled),
  .button--outline.button--info.button--checked:not(.button--disabled) {
    background-color: var(--lynk-color-info-600);
    color: var(--lynk-color-neutral-0);
  }

  .button--outline.button--info:active:not(.button--disabled) {
    border-color: var(--lynk-color-info-500);
    background-color: var(--lynk-color-info-500);
    color: var(--lynk-color-neutral-0);
  }

  .button--outline.button--disabled {
    opacity: 0.4;
  }

  @media (forced-colors: active) {
    .button.button--outline.button--checked:not(.button--disabled) {
      outline: solid 2px transparent;
    }
  }

  /*
   * Stealth buttons
   */

  .button--stealth {
    background: none;
    border-color: transparent;
  }

  /* Default */
  .button--stealth.button--default {
    color: var(--lynk-color-primary-500);
  }

  .button--stealth.button--default:hover:not(.button--disabled) {
    color: var(--lynk-color-primary-400);
  }

  .button--stealth.button--default:active:not(.button--disabled) {
    color: var(--lynk-color-neutral-0);
  }

  /* Primary */
  .button--stealth.button--primary {
    color: var(--lynk-color-primary-500);
  }

  .button--stealth.button--primary:hover:not(.button--disabled) {
    color: var(--lynk-color-primary-500);
    background-color: var(--lynk-color-primary-a25);
  }

  .button--stealth.button--primary:active:not(.button--disabled) {
    color: var(--lynk-color-primary-600);
    background-color: var(--lynk-color-primary-a50);
  }

  /* Accent */
  .button--stealth.button--accent {
    color: var(--lynk-color-accent-500);
  }

  .button--stealth.button--accent:hover:not(.button--disabled) {
    color: var(--lynk-color-accent-500);
    background-color: var(--lynk-color-accent-a25);
  }

  .button--stealth.button--accent:active:not(.button--disabled) {
    color: var(--lynk-color-accent-600);
    background-color: var(--lynk-color-accent-a50);
  }

  /* Success */
  .button--stealth.button--success {
    color: var(--lynk-color-success-600);
  }

  .button--stealth.button--success:hover:not(.button--disabled) {
    color: var(--lynk-color-success-600);
    background-color: var(--lynk-color-success-a10);
  }

  .button--stealth.button--success:active:not(.button--disabled) {
    color: var(--lynk-color-success-700);
    background-color: var(--lynk-color-success-a25);
  }

  /* Neutral */
  .button--stealth.button--neutral {
    color: var(--lynk-color-neutral-600);
  }

  .button--stealth.button--neutral:hover:not(.button--disabled) {
    color: var(--lynk-color-neutral-600);
    background-color: var(--lynk-color-neutral-50);
  }

  .button--stealth.button--neutral:active:not(.button--disabled) {
    color: var(--lynk-color-neutral-700);
    background-color: var(--lynk-color-neutral-100);
  }

  /* Warning */
  .button--stealth.button--warning {
    color: var(--lynk-color-warning-600);
  }

  .button--stealth.button--warning:hover:not(.button--disabled) {
    color: var(--lynk-color-warning-600);
    background-color: var(--lynk-color-warning-a10);
  }

  .button--stealth.button--warning:active:not(.button--disabled) {
    color: var(--lynk-color-warning-700);
    background-color: var(--lynk-color-warning-a25);
  }

  /* Danger */
  .button--stealth.button--danger {
    color: var(--lynk-color-danger-600);
  }

  .button--stealth.button--danger:hover:not(.button--disabled) {
    color: var(--lynk-color-danger-600);
    background-color: var(--lynk-color-danger-a10);
  }

  .button--stealth.button--danger:active:not(.button--disabled) {
    color: var(--lynk-color-danger-700);
    background-color: var(--lynk-color-danger-a25);
  }

  /* Info */
  .button--stealth.button--info {
    color: var(--lynk-color-info-600);
  }

  .button--stealth.button--info:hover:not(.button--disabled) {
    color: var(--lynk-color-info-600);
    background-color: var(--lynk-color-info-a10);
  }

  .button--stealth.button--info:active:not(.button--disabled) {
    color: var(--lynk-color-info-700);
    background-color: var(--lynk-color-info-a25);
  }

  /*
   * Text buttons
   */

  .button--text {
    background-color: transparent;
    border-color: transparent;
    color: var(--lynk-color-primary-600);
  }

  .button--text:hover:not(.button--disabled) {
    background-color: transparent;
    border-color: transparent;
    color: var(--lynk-color-primary-500);
  }

  .button--text:focus-visible:not(.button--disabled) {
    background-color: transparent;
    border-color: transparent;
    color: var(--lynk-color-primary-500);
  }

  .button--text:active:not(.button--disabled) {
    background-color: transparent;
    border-color: transparent;
    color: var(--lynk-color-primary-700);
  }

  /*
   * Size modifiers
   */

  .button--tiny {
    font-size: var(--lynk-button-font-size-small);
    height: auto;
    min-height: var(--lynk-button-height-tiny);
    line-height: calc(var(--lynk-button-height-tiny) - var(--lynk-button-border-width) * 2);
    border-radius: var(--lynk-button-border-radius-small);
  }
  .button--tiny .button__label::slotted(lynk-icon) {
    font-size: var(--lynk-font-size-small);
  }

  .button--small {
    font-size: var(--lynk-button-font-size-small);
    min-height: var(--lynk-button-height-small);
    height: auto;
    line-height: calc(var(--lynk-button-height-small) - var(--lynk-button-border-width) * 2);
    border-radius: var(--lynk-button-border-radius-small);
  }
  .button--small .button__label::slotted(lynk-icon) {
    font-size: var(--lynk-font-size-medium);
    vertical-align: -3px;
  }

  .button--medium {
    font-size: var(--lynk-button-font-size-medium);
    min-height: var(--lynk-button-height-medium);
    height: auto;
    line-height: calc(var(--lynk-button-height-medium) - var(--lynk-button-border-width) * 2);
    border-radius: var(--lynk-button-border-radius-medium);
  }
  .button--medium .button__label::slotted(lynk-icon) {
    font-size: var(--lynk-font-size-base);
    vertical-align: -3px;
  }

  .button--large {
    font-size: var(--lynk-button-font-size-large);
    min-height: var(--lynk-button-height-large);
    height: auto;
    line-height: calc(var(--lynk-button-height-large) - var(--lynk-button-border-width) * 2);
    border-radius: var(--lynk-button-border-radius-large);
  }
  .button--large .button__label::slotted(lynk-icon) {
    font-size: var(--lynk-font-size-large);
    vertical-align: -4px;
  }

  /*
   * Pill modifier
   */

  .button--pill.button--tiny {
    border-radius: var(--lynk-button-height-tiny);
  }

  .button--pill.button--small {
    border-radius: var(--lynk-button-height-small);
  }

  .button--pill.button--medium {
    border-radius: var(--lynk-button-height-medium);
  }

  .button--pill.button--large {
    border-radius: var(--lynk-button-height-large);
  }

  /*
   * Circle modifier for icon only buttons
   */

  .button--circle {
    padding-left: 0;
    padding-right: 0;
  }

  .button--circle.button--tiny {
    width: var(--lynk-button-height-tiny);
    border-radius: 50%;
  }

  .button--circle.button--small {
    width: var(--lynk-button-height-small);
    border-radius: 50%;
  }

  .button--circle.button--medium {
    width: var(--lynk-button-height-medium);
    border-radius: 50%;
  }

  .button--circle.button--large {
    width: var(--lynk-button-height-large);
    border-radius: 50%;
  }

  .button--circle .button__prefix,
  .button--circle .button__suffix,
  .button--circle .button__caret {
    display: none;
  }

  /*
   * Square modifier for icon only buttons
   */

  .button--square {
    padding-left: 0;
    padding-right: 0;
  }

  .button--square.button--tiny {
    width: var(--lynk-button-height-tiny);
    border-radius: var(--lynk-button-border-radius-small);
  }

  .button--square.button--small {
    width: var(--lynk-button-height-small);
    border-radius: var(--lynk-button-border-radius-small);
  }

  .button--square.button--medium {
    width: var(--lynk-button-height-medium);
    border-radius: var(--lynk-button-border-radius-medium);
  }

  .button--square.button--large {
    width: var(--lynk-button-height-large);
    border-radius: var(--lynk-button-border-radius-large);
  }

  .button--square .button__prefix,
  .button--square .button__suffix,
  .button--square .button__caret {
    display: none;
  }

  /*
   * Caret modifier
   */

  .button--caret .button__suffix {
    display: none;
  }

  .button--caret .button__caret {
    height: auto;
  }

  /*
   * thinking modifier
   */

  .button--thinking {
    position: relative;
    cursor: wait;
  }

  .button--thinking .button__prefix,
  .button--thinking .button__label,
  .button--thinking .button__suffix,
  .button--thinking .button__caret {
    visibility: hidden;
  }

  .button--thinking lynk-spinner {
    --indicator-color: currentColor;
    position: absolute;
    font-size: 1em;
    height: 1em;
    width: 1em;
    top: calc(50% - 0.5em);
    left: calc(50% - 0.5em);
  }

  /*
   * Badges
   */

  .button ::slotted(lynk-badge) {
    position: absolute;
    top: 0;
    right: 0;
    transform: translateY(-50%) translateX(50%);
    pointer-events: none;
  }

  .button--rtl ::slotted(lynk-badge) {
    right: auto;
    left: 0;
    transform: translateY(-50%) translateX(-50%);
  }

  /*
   * Button spacing
   */

  .button--has-label.button--tiny .button__label {
    padding: 0 var(--lynk-spacing-x-small);
  }

  .button--has-label.button--small .button__label {
    padding: 0 var(--lynk-spacing-small);
  }

  .button--has-label.button--medium .button__label {
    padding: 0 var(--lynk-spacing-medium);
  }

  .button--has-label.button--large .button__label {
    padding: 0 var(--lynk-spacing-large);
  }

  .button--has-prefix.button--tiny {
    padding-inline-start: var(--lynk-spacing-2x-small);
  }

  .button--has-prefix.button--tiny .button__label {
    padding-inline-start: var(--lynk-spacing-2x-small);
  }

  .button--has-prefix.button--small {
    padding-inline-start: var(--lynk-spacing-x-small);
  }

  .button--has-prefix.button--small .button__label {
    padding-inline-start: var(--lynk-spacing-x-small);
  }

  .button--has-prefix.button--medium {
    padding-inline-start: var(--lynk-spacing-small);
  }

  .button--has-prefix.button--medium .button__label {
    padding-inline-start: var(--lynk-spacing-small);
  }

  .button--has-prefix.button--large {
    padding-inline-start: var(--lynk-spacing-small);
  }

  .button--has-prefix.button--large .button__label {
    padding-inline-start: var(--lynk-spacing-small);
  }

  .button--has-suffix.button--tiny,
  .button--caret.button--tiny {
    padding-inline-end: var(--lynk-spacing-2x-small);
  }

  .button--has-suffix.button--tiny .button__label,
  .button--caret.button--tiny .button__label {
    padding-inline-end: var(--lynk-spacing-2x-small);
  }

  .button--has-suffix.button--small,
  .button--caret.button--small {
    padding-inline-end: var(--lynk-spacing-x-small);
  }

  .button--has-suffix.button--small .button__label,
  .button--caret.button--small .button__label {
    padding-inline-end: var(--lynk-spacing-x-small);
  }

  .button--has-suffix.button--medium,
  .button--caret.button--medium {
    padding-inline-end: var(--lynk-spacing-small);
  }

  .button--has-suffix.button--medium .button__label,
  .button--caret.button--medium .button__label {
    padding-inline-end: var(--lynk-spacing-small);
  }

  .button--has-suffix.button--large,
  .button--caret.button--large {
    padding-inline-end: var(--lynk-spacing-small);
  }

  .button--has-suffix.button--large .button__label,
  .button--caret.button--large .button__label {
    padding-inline-end: var(--lynk-spacing-small);
  }

  /*
    * Button groups support a variety of button types (e.g. buttons with tooltips, buttons as dropdown triggers, etc.).
    * This means buttons aren't always direct descendants of the button group, thus we can't target them with the
    * ::slotted selector. To work around this, the button group component does some magic to add these special classes to
    * buttons and we style them here instead.
    */

  :host([data-lynk-button-group__button--first]:not([data-lynk-button-group__button--last])) .button {
    border-start-end-radius: 0;
    border-end-end-radius: 0;
  }

  :host([data-lynk-button-group__button--inner]) .button {
    border-radius: 0;
  }

  :host([data-lynk-button-group__button--last]:not([data-lynk-button-group__button--first])) .button {
    border-start-start-radius: 0;
    border-end-start-radius: 0;
  }

  /* All except the first */
  :host([data-lynk-button-group__button]:not([data-lynk-button-group__button--first])) {
    margin-inline-start: calc(-1 * var(--lynk-input-border-width));
  }

  /* Add a visual separator between solid buttons */
  :host(
      [data-lynk-button-group__button]:not(
          [data-lynk-button-group__button--first],
          [data-lynk-button-group__button--radio],
          [variant='default']
        ):not(:hover)
    )
    .button:after {
    content: '';
    position: absolute;
    top: 0;
    inset-inline-start: 0;
    bottom: 0;
    border-left: solid 1px rgb(128 128 128 / 33%);
    mix-blend-mode: multiply;
  }

  /* Bump hovered, focused, and checked buttons up so their focus ring isn't clipped */
  :host([data-lynk-button-group__button--hover]) {
    z-index: 1;
  }

  /* Focus and checked are always on top */
  :host([data-lynk-button-group__button--focus]),
  :host([data-lynk-button-group__button][checked]) {
    z-index: 2;
  }
`;

export {
  button_styles_default
};
