import {
  LynkOption
} from "./chunk.OYWEPZMT.js";
import {
  LynkStack
} from "./chunk.FS46XE6I.js";
import {
  defaultOptionRenderer
} from "./chunk.2GOQR7WJ.js";
import {
  createOptionFromDifferentTypes,
  filterOnlyOptgroups,
  getAllOptions,
  getAssignedElementsForSlot,
  normalizeString
} from "./chunk.C3XO55VB.js";
import {
  LynkPopup
} from "./chunk.MKUPR4HT.js";
import {
  scrollIntoView
} from "./chunk.WSPFGNPB.js";
import {
  combobox_custom_styles_default
} from "./chunk.3QDNRTLD.js";
import {
  combobox_styles_default
} from "./chunk.AG6HEIKV.js";
import {
  defaultValue
} from "./chunk.GI7VDIWX.js";
import {
  form_control_styles_default
} from "./chunk.6GN7NPQ7.js";
import {
  FormControlController
} from "./chunk.74PYJKHH.js";
import {
  animateTo,
  stopAnimations,
  waitForEvent
} from "./chunk.YEUBLCCQ.js";
import {
  getAnimation,
  setDefaultAnimation
} from "./chunk.K7JGTRV7.js";
import {
  HasSlotController
} from "./chunk.OW5NIGGX.js";
import {
  LocalizeController
} from "./chunk.6CTB5ZDJ.js";
import {
  LynkIcon
} from "./chunk.OTHQ47SZ.js";
import {
  watch
} from "./chunk.GMYPQTFK.js";
import {
  LynkElement
} from "./chunk.7M4AVQ6D.js";
import {
  component_styles_default
} from "./chunk.Y7724W4D.js";
import {
  __decorateClass
} from "./chunk.KAW7D32O.js";

// src/components/combobox/combobox.component.ts
import { classMap } from "lit/directives/class-map.js";
import { html } from "lit";
import { property, query, state } from "lit/decorators.js";
var LynkCombobox = class extends LynkElement {
  constructor() {
    super(...arguments);
    this.formControlController = new FormControlController(this, {
      assumeInteractionOn: ["ev-blur", "ev-input"]
    });
    this.hasSlotController = new HasSlotController(this, "action", "help-text", "help-tip", "label");
    this.localize = new LocalizeController(this);
    /** The last value of a lynk-option, that was selected by click or via keyboard navigation */
    this.lastOptionValue = "";
    this.isOptionRendererTriggered = false;
    this.hasFocus = false;
    this.displayLabel = "";
    this.numberFilteredOptions = 0;
    this.cachedOptions = [];
    this.name = "";
    this.value = "";
    this.defaultValue = "";
    this.state = "default";
    this.size = "medium";
    this.placeholder = "";
    this.disabled = false;
    this.clearable = false;
    this.open = false;
    this.hoist = false;
    this.label = "";
    this.placement = "bottom";
    this.helpTip = "";
    this.helpText = "";
    this.form = "";
    this.required = false;
    this.getOption = defaultOptionRenderer;
    this.filter = (option, queryStr) => {
      let content = (option == null ? void 0 : option.textContent) || "";
      if (option instanceof LynkOption) {
        content = option.getTextLabel();
      }
      const normalizedOption = normalizeString(content);
      const normalizedQuery = normalizeString(queryStr);
      return normalizedOption.includes(normalizedQuery);
    };
    this.handleDocumentFocusIn = (event) => {
      const path = event.composedPath();
      if (this && !path.includes(this)) {
        this.hide();
      }
    };
    /* eslint-disable @typescript-eslint/no-floating-promises */
    // eslint-disable-next-line complexity
    this.handleDocumentKeyDown = (event) => {
      const target = event.target;
      const isClearButton = target.closest(".combobox__clear") !== null;
      if (isClearButton) {
        return;
      }
      if (event.key === "Escape") {
        if (this.open && !this.closeWatcher) {
          event.preventDefault();
          event.stopPropagation();
          this.hide();
          this.displayInput.focus({ preventScroll: true });
        } else if (!this.open) {
          this.clearCombobox();
        }
      }
      if (event.key === "Enter") {
        const currentOption = this.getCurrentOption();
        const hasModifier = event.metaKey || event.ctrlKey || event.shiftKey || event.altKey;
        if (!this.open && !hasModifier) {
          setTimeout(() => {
            if (!event.defaultPrevented) {
              this.formControlController.submit();
            }
          });
          return;
        }
        if (!this.open || currentOption && currentOption.disabled) {
          return;
        }
        if (currentOption) {
          const oldValue = this.lastOptionValue;
          this.setSelectedOption(currentOption);
          if (this.value !== oldValue) {
            this.updateComplete.then(() => {
              this.emit("ev-input");
              this.emit("ev-change");
            });
          }
        }
        this.hide();
        this.displayInput.focus({ preventScroll: true });
        return;
      }
      if (["ArrowUp", "ArrowDown"].includes(event.key)) {
        event.preventDefault();
        event.stopPropagation();
        if (!this.open) {
          this.show();
        }
        this.selectNextOption(event.key === "ArrowDown");
      }
      if (["Home", "End"].includes(event.key)) {
        event.preventDefault();
        event.stopPropagation();
        if (event.key === "Home") {
          this.displayInput.setSelectionRange(0, 0);
        } else if (event.key === "End") {
          this.displayInput.setSelectionRange(this.displayInput.value.length, this.displayInput.value.length);
        }
      }
    };
    /* eslint-enable @typescript-eslint/no-floating-promises */
    this.handleDocumentMouseDown = (event) => {
      const path = event.composedPath();
      if (this && !path.includes(this)) {
        this.hide();
      }
    };
  }
  /** Gets the validity state object */
  get validity() {
    return this.valueInput.validity;
  }
  /** Gets the validation message */
  get validationMessage() {
    return this.valueInput.validationMessage;
  }
  connectedCallback() {
    super.connectedCallback();
    this.open = false;
  }
  firstUpdated() {
    this.updateComplete.then(() => {
      this.displayLabel = this.value;
    });
    this.formControlController.updateValidity();
  }
  addOpenListeners() {
    var _a;
    document.addEventListener("focusin", this.handleDocumentFocusIn);
    document.addEventListener("keydown", this.handleDocumentKeyDown);
    document.addEventListener("mousedown", this.handleDocumentMouseDown);
    if (this.getRootNode() !== document) {
      this.getRootNode().addEventListener("focusin", this.handleDocumentFocusIn);
    }
    if ("CloseWatcher" in window) {
      (_a = this.closeWatcher) == null ? void 0 : _a.destroy();
      this.closeWatcher = new CloseWatcher();
      this.closeWatcher.onclose = () => {
        if (this.open) {
          this.hide();
          this.displayInput.focus({ preventScroll: true });
        }
      };
    }
  }
  removeOpenListeners() {
    var _a;
    document.removeEventListener("focusin", this.handleDocumentFocusIn);
    document.removeEventListener("keydown", this.handleDocumentKeyDown);
    document.removeEventListener("mousedown", this.handleDocumentMouseDown);
    if (this.getRootNode() !== document) {
      this.getRootNode().removeEventListener("focusin", this.handleDocumentFocusIn);
    }
    (_a = this.closeWatcher) == null ? void 0 : _a.destroy();
  }
  handleFocus() {
    this.hasFocus = true;
    this.emit("ev-focus");
  }
  handleBlur() {
    this.hasFocus = false;
    this.emit("ev-blur");
  }
  handleLabelClick() {
    this.displayInput.focus();
  }
  handleComboboxMouseDown(event) {
    if (this.disabled) {
      return;
    }
    const toggleListboxOpen = () => this.open ? this.hide() : this.show();
    event.preventDefault();
    toggleListboxOpen().then(() => {
      setTimeout(() => this.displayInput.focus({ preventScroll: true }));
    });
  }
  handleComboboxKeyDown(event) {
    if (event.key === "Tab") {
      return;
    }
    this.handleDocumentKeyDown(event);
  }
  handleClearClick(event) {
    event.stopPropagation();
    this.clearCombobox();
  }
  clearCombobox() {
    if (this.value !== "") {
      this.value = "";
      this.displayInput.value = "";
      this.lastOptionValue = "";
      this.setSelectedOption(void 0);
      this.displayInput.focus({ preventScroll: true });
      this.updateComplete.then(() => {
        this.emit("ev-clear");
        this.emit("ev-input");
        this.emit("ev-change");
      });
    }
  }
  // eslint-disable-next-line class-methods-use-this
  preventLoosingFocus(event) {
    event.stopPropagation();
    event.preventDefault();
  }
  /* eslint-disable @typescript-eslint/no-floating-promises */
  handleOptionClick(event) {
    const target = event.target;
    const option = target.closest("lynk-option");
    const oldValue = this.lastOptionValue;
    if (option && !option.disabled) {
      this.setSelectedOption(option);
      this.updateComplete.then(() => this.displayInput.focus({ preventScroll: true }));
      if (this.value !== oldValue) {
        this.updateComplete.then(() => {
          this.emit("ev-input");
          this.emit("ev-change");
        });
      }
      this.hide();
      this.displayInput.focus({ preventScroll: true });
    }
  }
  /* eslint-enable @typescript-eslint/no-floating-promises */
  /**
   * Selects the following or previous option.
   *
   * @param isNext - A boolean indicating whether to select the following option (true)
   *                 or the previous option (false).
   */
  selectNextOption(isNext) {
    const filteredOptions = this.getAllFilteredOptions();
    if (filteredOptions.length === 0) {
      return;
    }
    const currentOption = this.getCurrentOption();
    const currentIndex = filteredOptions.indexOf(currentOption);
    let newIndex = Math.max(0, currentIndex);
    if (isNext) {
      const nextIndex = currentIndex + 1;
      newIndex = nextIndex > filteredOptions.length - 1 ? 0 : nextIndex;
    } else {
      const previousIndex = currentIndex - 1;
      newIndex = previousIndex < 0 ? filteredOptions.length - 1 : previousIndex;
    }
    this.setCurrentOption(filteredOptions[newIndex]);
    scrollIntoView(this.getCurrentOption(), this.listbox, "vertical", "auto");
  }
  getAllFilteredOptions() {
    return this.getSlottedOptions().filter((option) => !option.hidden);
  }
  getCurrentOption() {
    return this.getAllFilteredOptions().find((option) => option.current);
  }
  // Sets the current option, which is the option the user is currently interacting with
  // (e.g. via keyboard). Only one option may be "current" at a time.
  setCurrentOption(option) {
    const allOptions = this.getAllFilteredOptions();
    this.displayInput.removeAttribute("aria-activedescendant");
    allOptions.forEach((el) => {
      el.current = false;
      el.setAttribute("aria-selected", "false");
    });
    if (option) {
      option.current = true;
      option.setAttribute("aria-selected", "true");
      this.displayInput.setAttribute("aria-activedescendant", option.id);
    }
  }
  /**
   * Updates the selected options cache, the current value, and the display value
   */
  setSelectedOption(option) {
    var _a, _b;
    this.selectedOption = option;
    const optionValue = ((_a = this.selectedOption) == null ? void 0 : _a.value) || ((_b = this.selectedOption) == null ? void 0 : _b.getTextLabel());
    if (option) {
      this.lastOptionValue = optionValue || "";
    }
    this.value = optionValue != null ? optionValue : this.displayInput.value;
    this.updateComplete.then(() => {
      var _a2, _b2;
      this.displayLabel = (_b2 = (_a2 = this.selectedOption) == null ? void 0 : _a2.getTextLabel()) != null ? _b2 : this.displayInput.value;
      this.formControlController.updateValidity();
    });
  }
  handleInvalid(event) {
    this.formControlController.setValidity(false);
    this.formControlController.emitInvalidEvent(event);
  }
  handlePropertiesChange() {
    this.createComboboxOptionsFromQuery(this.value);
  }
  handleDisabledChange() {
    this.formControlController.setValidity(this.disabled);
    if (this.disabled) {
      this.open = false;
      this.handleOpenChange();
    }
  }
  handleValueChange() {
    this.displayLabel = this.value;
    this.createComboboxOptionsFromQuery(this.value);
    this.setCurrentOption(null);
  }
  async handleOpenChange() {
    if (this.open && !this.disabled) {
      if (this.numberFilteredOptions === 0) {
        this.open = false;
        this.emit("ev-error");
        return;
      }
      this.emit("ev-show");
      this.addOpenListeners();
      await stopAnimations(this);
      this.listbox.hidden = false;
      this.popup.active = true;
      const { keyframes: keyframes2, options: options2 } = getAnimation(this, "combobox.show", { dir: this.localize.dir() });
      await animateTo(this.popup.popup, keyframes2, options2);
      this.emit("ev-after-show");
      return;
    }
    this.setCurrentOption(null);
    this.displayInput.removeAttribute("aria-activedescendant");
    this.emit("ev-hide");
    this.removeOpenListeners();
    await stopAnimations(this);
    const { keyframes, options } = getAnimation(this, "combobox.hide", { dir: this.localize.dir() });
    await animateTo(this.popup.popup, keyframes, options);
    this.listbox.hidden = true;
    this.popup.active = false;
    this.emit("ev-after-hide");
  }
  /**
   * Shows the listbox. If it is not possible to open the listbox, because there are no
   * appropriate filtered options, a ev-error is emitted and the listbox stays closed.
   */
  async show() {
    if (this.open || this.disabled) {
      this.open = false;
      return void 0;
    }
    this.open = true;
    return Promise.race([waitForEvent(this, "ev-after-show"), waitForEvent(this, "ev-error")]);
  }
  /** Hides the listbox. */
  async hide() {
    if (!this.open || this.disabled) {
      this.open = false;
      return void 0;
    }
    this.open = false;
    return waitForEvent(this, "ev-after-hide");
  }
  /**
   * Checks for validity but does not show a validation message.
   * Returns `true` when valid and `false` when invalid.
   */
  checkValidity() {
    return this.valueInput.checkValidity();
  }
  /** Gets the associated form, if one exists. */
  getForm() {
    return this.formControlController.getForm();
  }
  /** Checks for validity and shows the browser's validation message if the control is invalid. */
  reportValidity() {
    return this.valueInput.reportValidity();
  }
  /** Sets a custom validation message. Pass an empty string to restore validity. */
  setCustomValidity(message) {
    this.valueInput.setCustomValidity(message);
    this.formControlController.updateValidity();
  }
  /** Sets focus on the control. */
  focus(options) {
    this.displayInput.focus(options);
  }
  /** Removes focus from the control. */
  blur() {
    this.displayInput.blur();
  }
  /* eslint-disable no-param-reassign, @typescript-eslint/no-floating-promises */
  createComboboxOptionsFromQuery(queryString) {
    var _a;
    this.numberFilteredOptions = 0;
    this.isOptionRendererTriggered = true;
    if (this.cachedOptions.length === 0) {
      this.cacheSlottedOptionsAndOptgroups();
    }
    this.getSlottedOptions().forEach((option) => {
      const cachedOption = this.cachedOptions.find((o) => o.id === option.id) || option;
      const optionResult = this.getOption(cachedOption, queryString);
      let updatedOption = createOptionFromDifferentTypes(optionResult);
      if (!updatedOption) {
        updatedOption = cachedOption;
      }
      const hideOption = !(this.filter(updatedOption, queryString) || queryString === "");
      updatedOption.hidden = hideOption;
      option.replaceWith(updatedOption);
      if (!hideOption) {
        this.numberFilteredOptions += 1;
      }
    });
    const visibleOptgroups = this.getSlottedOptGroups().filter((optgroup) => {
      const options = getAllOptions(Array.from(optgroup.children)).flat();
      const isVisible = options.some((option) => !option.hidden);
      optgroup.hidden = !isVisible;
      return isVisible;
    });
    (_a = visibleOptgroups[0]) == null ? void 0 : _a.style.setProperty("--display-divider", "none");
    setTimeout(() => {
      this.isOptionRendererTriggered = false;
    }, 0);
  }
  /* eslint-enable no-param-reassign, @typescript-eslint/no-floating-promises */
  async handleInput() {
    const inputValue = this.displayInput.value;
    this.value = inputValue;
    await this.updateComplete;
    this.open = this.numberFilteredOptions > 0;
    this.setSelectedOption(void 0);
    this.formControlController.updateValidity();
    this.emit("ev-input");
  }
  handleChange() {
    if (!this.selectedOption) {
      this.value = this.displayInput.value;
      this.updateComplete.then(() => {
        this.formControlController.updateValidity();
      });
      this.emit("ev-change");
    }
  }
  getSlottedOptions() {
    return getAllOptions(getAssignedElementsForSlot(this.defaultSlot)).flat();
  }
  getSlottedOptGroups() {
    return filterOnlyOptgroups(getAssignedElementsForSlot(this.defaultSlot));
  }
  /* eslint-disable no-param-reassign */
  cacheSlottedOptionsAndOptgroups() {
    const slottedOptions = this.getSlottedOptions();
    const slottedOptgroups = this.getSlottedOptGroups();
    slottedOptions.forEach((option, index) => {
      option.id = option.id || `lynk-combobox-option-${index}`;
    });
    slottedOptgroups.forEach((optgroup, index) => {
      optgroup.id = optgroup.id || `lynk-combobox-optgroup-${index}`;
    });
    this.cachedOptions = [...slottedOptions];
  }
  /* eslint-enable no-param-reassign */
  /* eslint-disable @typescript-eslint/no-floating-promises, complexity */
  /* @internal - used by options to update labels */
  handleDefaultSlotChange() {
    if (!this.isOptionRendererTriggered) {
      if (!customElements.get("lynk-option")) {
        customElements.whenDefined("lynk-option").then(() => this.handleDefaultSlotChange());
        return;
      }
      this.cacheSlottedOptionsAndOptgroups();
      this.createComboboxOptionsFromQuery(this.value);
      if (this.hasFocus && this.value.length > 0 && !this.open) {
        this.show();
      }
    }
  }
  /* eslint-enable @typescript-eslint/no-floating-promises, complexity */
  /* eslint-disable @typescript-eslint/unbound-method */
  // eslint-disable-next-line complexity
  render() {
    const hasLabelSlot = this.hasSlotController.test("label");
    const hasHelpTextSlot = this.hasSlotController.test("help-text");
    const hasHelpTipSlot = this.hasSlotController.test("help-tip");
    const hasLabel = this.label ? true : !!hasLabelSlot;
    const hasHelpText = this.helpText ? true : !!hasHelpTextSlot;
    const hasHelpTip = this.helpTip ? true : !!hasHelpTipSlot;
    const hasClearIcon = this.clearable && !this.disabled && this.value.length > 0;
    const isPlaceholderVisible = this.placeholder && this.value.length === 0;
    return html`
      <div
        part="form-control"
        class=${classMap({
      "form-control": true,
      "form-control--has-help-text": hasHelpText,
      "form-control--has-label": hasLabel,
      "form-control--large": this.size === "large",
      "form-control--medium": this.size === "medium",
      "form-control--small": this.size === "small",
      "form-control--has-error": this.state === "error" || this.hasAttribute("data-user-invalid"),
      "form-control--has-warning": this.state === "warning",
      "form-control--has-success": this.state === "success"
    })}
      >
        <label
          id="label"
          part="form-control-label"
          class=${classMap({
      "form-control__label": true,
      "form-control--focused": this.hasFocus
    })}
          aria-hidden=${hasLabel ? "false" : "true"}
          @click=${this.handleLabelClick}
        >
          <slot name="label">${this.label}</slot>

          ${this.required ? html`
                <lynk-tooltip content="Required" hoist>
                  <lynk-icon style="font-size: 9px;" name="asterisk" library="system"></lynk-icon>
                </lynk-tooltip>
              ` : ""}
          ${hasHelpTip ? html`
                <lynk-tooltip hoist>
                  <div slot="content">
                    <slot name="help-tip">${this.helpTip}</slot>
                  </div>
                  <lynk-icon style="font-size: 11px;" name="question-fill" library="system"></lynk-icon>
                </lynk-tooltip>
              ` : ""}
        </label>

        <lynk-stack part="form-control-input" class="form-control-input" gap="var(--lynk-spacing-2x-small)" horizontal>
          <lynk-popup
            class=${classMap({
      combobox: true,
      "combobox--bottom": this.placement === "bottom",
      "combobox--disabled": this.disabled,
      "combobox--focused": this.hasFocus,
      "combobox--large": this.size === "large",
      "combobox--medium": this.size === "medium",
      "combobox--open": this.open,
      "combobox--placeholder-visible": isPlaceholderVisible,
      "combobox--small": this.size === "small",
      "combobox--standard": true,
      "combobox--top": this.placement === "top"
    })}
            placement=${this.placement}
            strategy=${this.hoist ? "fixed" : "absolute"}
            flip
            shift
            sync="width"
            auto-size="vertical"
            auto-size-padding="10"
          >
            <div
              part="combobox"
              class="combobox__inputs"
              slot="anchor"
              @keydown=${this.handleComboboxKeyDown}
              @mousedown=${this.handleComboboxMouseDown}
            >
              <slot part="prefix" name="prefix" class="combobox__prefix"></slot>

              <input
                part="display-input"
                class="combobox__display-input"
                type="text"
                placeholder=${this.placeholder}
                .disabled=${this.disabled}
                .value=${this.displayLabel}
                autocomplete="off"
                spellcheck="false"
                autocapitalize="off"
                aria-controls="listbox"
                aria-expanded=${this.open ? "true" : "false"}
                aria-haspopup="listbox"
                aria-labelledby="label"
                aria-disabled=${this.disabled ? "true" : "false"}
                aria-describedby="help-text"
                role="combobox"
                tabindex="0"
                @focus=${this.handleFocus}
                @blur=${this.handleBlur}
                aria-autocomplete="list"
                aria-owns="listbox"
                @input=${this.handleInput}
                @change=${this.handleChange}
              />

              <input
                class="combobox__value-input"
                type="text"
                ?disabled=${this.disabled}
                ?required=${this.required}
                .value=${this.value}
                tabindex="-1"
                aria-hidden="true"
                @focus=${() => this.focus()}
                @invalid=${this.handleInvalid}
              />

              ${hasClearIcon ? html`
                    <button
                      part="clear-button"
                      class="combobox__clear"
                      type="button"
                      aria-label=${this.localize.term("clearEntry")}
                      @mousedown=${this.preventLoosingFocus}
                      @click=${this.handleClearClick}
                      tabindex="-1"
                    >
                      <slot name="clear-icon">
                        <lynk-icon name="x-circle-fill" library="system"></lynk-icon>
                      </slot>
                    </button>
                  ` : ""}

              <slot name="suffix" part="suffix" class="combobox__suffix"></slot>

              <slot name="expand-icon" part="expand-icon" class="combobox__expand-icon">
                <lynk-icon library="system" name="chevron-down"></lynk-icon>
              </slot>
            </div>

            <div
              id="listbox"
              role="listbox"
              aria-expanded=${this.open ? "true" : "false"}
              aria-labelledby="label"
              part="listbox"
              class="combobox__listbox"
              tabindex="-1"
              @mousedown=${this.preventLoosingFocus}
              @mouseup=${this.handleOptionClick}
            >
              <div class="listbox__options" part="filtered-listbox">
                <slot @slotchange=${this.handleDefaultSlotChange}></slot>
              </div>
            </div>
          </lynk-popup>
          <slot name="action"></slot>
        </lynk-stack>

        <div
          part="form-control-help-text"
          id="help-text"
          class="form-control__help-text"
          aria-hidden=${hasHelpText ? "false" : "true"}
        >
          <slot name="help-text">${this.helpText}</slot>
        </div>
      </div>
    `;
  }
  /* eslint-enable @typescript-eslint/unbound-method */
};
LynkCombobox.styles = [component_styles_default, form_control_styles_default, combobox_styles_default, combobox_custom_styles_default];
LynkCombobox.dependencies = {
  "lynk-icon": LynkIcon,
  "lynk-stack": LynkStack,
  "lynk-popup": LynkPopup
};
__decorateClass([
  query(".combobox")
], LynkCombobox.prototype, "popup", 2);
__decorateClass([
  query(".combobox__inputs")
], LynkCombobox.prototype, "combobox", 2);
__decorateClass([
  query(".combobox__display-input")
], LynkCombobox.prototype, "displayInput", 2);
__decorateClass([
  query(".combobox__value-input")
], LynkCombobox.prototype, "valueInput", 2);
__decorateClass([
  query(".combobox__listbox")
], LynkCombobox.prototype, "listbox", 2);
__decorateClass([
  query("slot:not([name])")
], LynkCombobox.prototype, "defaultSlot", 2);
__decorateClass([
  state()
], LynkCombobox.prototype, "hasFocus", 2);
__decorateClass([
  state()
], LynkCombobox.prototype, "displayLabel", 2);
__decorateClass([
  state()
], LynkCombobox.prototype, "selectedOption", 2);
__decorateClass([
  state()
], LynkCombobox.prototype, "numberFilteredOptions", 2);
__decorateClass([
  state()
], LynkCombobox.prototype, "cachedOptions", 2);
__decorateClass([
  property()
], LynkCombobox.prototype, "name", 2);
__decorateClass([
  property()
], LynkCombobox.prototype, "value", 2);
__decorateClass([
  defaultValue()
], LynkCombobox.prototype, "defaultValue", 2);
__decorateClass([
  property({ reflect: true })
], LynkCombobox.prototype, "state", 2);
__decorateClass([
  property({ reflect: true })
], LynkCombobox.prototype, "size", 2);
__decorateClass([
  property()
], LynkCombobox.prototype, "placeholder", 2);
__decorateClass([
  property({ reflect: true, type: Boolean })
], LynkCombobox.prototype, "disabled", 2);
__decorateClass([
  property({ type: Boolean })
], LynkCombobox.prototype, "clearable", 2);
__decorateClass([
  property({ reflect: true, type: Boolean })
], LynkCombobox.prototype, "open", 2);
__decorateClass([
  property({ type: Boolean })
], LynkCombobox.prototype, "hoist", 2);
__decorateClass([
  property()
], LynkCombobox.prototype, "label", 2);
__decorateClass([
  property({ reflect: true })
], LynkCombobox.prototype, "placement", 2);
__decorateClass([
  property({ attribute: "help-tip" })
], LynkCombobox.prototype, "helpTip", 2);
__decorateClass([
  property({ attribute: "help-text" })
], LynkCombobox.prototype, "helpText", 2);
__decorateClass([
  property({ reflect: true })
], LynkCombobox.prototype, "form", 2);
__decorateClass([
  property({ reflect: true, type: Boolean })
], LynkCombobox.prototype, "required", 2);
__decorateClass([
  property()
], LynkCombobox.prototype, "getOption", 2);
__decorateClass([
  property()
], LynkCombobox.prototype, "filter", 2);
__decorateClass([
  watch(["filter", "getOption"], { waitUntilFirstUpdate: true })
], LynkCombobox.prototype, "handlePropertiesChange", 1);
__decorateClass([
  watch("disabled", { waitUntilFirstUpdate: true })
], LynkCombobox.prototype, "handleDisabledChange", 1);
__decorateClass([
  watch("value", { waitUntilFirstUpdate: true })
], LynkCombobox.prototype, "handleValueChange", 1);
__decorateClass([
  watch("open", { waitUntilFirstUpdate: true })
], LynkCombobox.prototype, "handleOpenChange", 1);
setDefaultAnimation("combobox.show", {
  keyframes: [
    { opacity: 0, scale: 0.9 },
    { opacity: 1, scale: 1 }
  ],
  options: { duration: 100, easing: "ease" }
});
setDefaultAnimation("combobox.hide", {
  keyframes: [
    { opacity: 1, scale: 1 },
    { opacity: 0, scale: 0.9 }
  ],
  options: { duration: 100, easing: "ease" }
});

export {
  LynkCombobox
};
