import {
  form_field_styles_default
} from "./chunk.KBAVWRJS.js";
import {
  LynkTooltip
} from "./chunk.TNZ6RBLS.js";
import {
  getTabbableBoundary
} from "./chunk.LXDTFLWU.js";
import {
  HasSlotController
} from "./chunk.OW5NIGGX.js";
import {
  LynkIcon
} from "./chunk.OTHQ47SZ.js";
import {
  LynkElement
} from "./chunk.7M4AVQ6D.js";
import {
  component_styles_default
} from "./chunk.Y7724W4D.js";
import {
  __decorateClass
} from "./chunk.KAW7D32O.js";

// src/components/form-field/form-field.component.ts
import { classMap } from "lit/directives/class-map.js";
import { html } from "lit";
import { property, query, state } from "lit/decorators.js";
var LynkFormField = class extends LynkElement {
  constructor() {
    super(...arguments);
    this.hasSlotController = new HasSlotController(this, "help-text", "help-tip", "label");
    this.hasFocus = false;
    this.state = "default";
    this.size = "medium";
    this.label = "";
    this.id = "";
    this.helpText = "";
    this.helpTip = "";
    this.required = false;
  }
  connectedCallback() {
    super.connectedCallback();
    this.handleDocumentKeyDown = this.handleDocumentKeyDown.bind(this);
    this.handleDocumentMouseDown = this.handleDocumentMouseDown.bind(this);
    if (!this.containingElement) {
      this.containingElement = this;
    }
  }
  firstUpdated() {
    this.addOpenListeners();
  }
  disconnectedCallback() {
    super.disconnectedCallback();
    this.removeOpenListeners();
  }
  addOpenListeners() {
    document.addEventListener("keydown", this.handleDocumentKeyDown);
    document.addEventListener("mousedown", this.handleDocumentMouseDown);
  }
  removeOpenListeners() {
    document.removeEventListener("keydown", this.handleDocumentKeyDown);
    document.removeEventListener("mousedown", this.handleDocumentMouseDown);
  }
  handleFocus() {
    this.hasFocus = true;
    this.emit("ev-focus");
  }
  handleBlur() {
    this.hasFocus = false;
    this.emit("ev-blur");
  }
  handleLabelClick() {
    this.focus();
  }
  handleDefaultSlotChange() {
    this.manageAccessibleTarget();
  }
  handleDocumentKeyDown(event) {
    if (event.key === "Tab") {
      setTimeout(() => {
        var _a, _b, _c;
        const activeElement = ((_a = this.containingElement) == null ? void 0 : _a.getRootNode()) instanceof ShadowRoot ? (_c = (_b = document.activeElement) == null ? void 0 : _b.shadowRoot) == null ? void 0 : _c.activeElement : document.activeElement;
        if (!this.containingElement || (activeElement == null ? void 0 : activeElement.closest(this.containingElement.tagName.toLowerCase())) !== this.containingElement) {
          this.blur();
        }
      });
    }
  }
  handleDocumentMouseDown(event) {
    const path = event.composedPath();
    if (this && this.containingElement && !path.includes(this.containingElement)) {
      this.blur();
    }
  }
  //
  // Slotted elements can be arbitrary content or form elements, but we need to link them to the label with `aria-labelledby`.
  // This must be applied to the "accessible element" (the tabbable portion of the trigger element
  // that gets slotted in) so screen readers will understand them. The accessible element could be a slotted form element,
  // a child of the slotted element, or an element in the slotted element's shadow root.
  //
  // To determine this, we assume the first tabbable element in the element slot is the "accessible element."
  //
  manageAccessibleTarget() {
    const assignedElements = this.defaultSlot.assignedElements({ flatten: true });
    const accessibleTarget = assignedElements.find((el) => getTabbableBoundary(el).start);
    if (accessibleTarget) {
      this.target = accessibleTarget;
      this.target.setAttribute("aria-label", this.label);
    }
  }
  /** Sets focus on the control. */
  focus(options) {
    var _a;
    if (this.target && typeof ((_a = this.target) == null ? void 0 : _a.focus) === "function") {
      this.target.focus(options);
    }
    this.handleFocus();
  }
  /** Removes focus from the control. */
  blur() {
    var _a;
    if (this.target && typeof ((_a = this.target) == null ? void 0 : _a.blur) === "function") {
      this.target.blur();
    }
    this.handleBlur();
  }
  render() {
    const hasLabelSlot = this.hasSlotController.test("label");
    const hasHelpTextSlot = this.hasSlotController.test("help-text");
    const hasHelpTipSlot = this.hasSlotController.test("help-tip");
    const hasLabel = this.label ? true : !!hasLabelSlot;
    const hasHelpText = this.helpText ? true : !!hasHelpTextSlot;
    const hasHelpTip = this.helpTip ? true : !!hasHelpTipSlot;
    return html`
      <fieldset
        part="base"
        class=${classMap({
      "form-field": true,
      "form-field--small": this.size === "small",
      "form-field--medium": this.size === "medium",
      "form-field--large": this.size === "large",
      "form-field--has-label": hasLabel,
      "form-field--has-help-text": hasHelpText,
      "form-field--has-error": this.state === "error" || this.hasAttribute("data-user-invalid"),
      "form-field--has-warning": this.state === "warning",
      "form-field--has-success": this.state === "success",
      "form-field--focused": this.hasFocus
    })}
      >
        <label
          id="label"
          part="label"
          class=${classMap({
      "form-field__label": true
    })}
          aria-hidden=${hasLabel ? "false" : "true"}
          @click=${this.handleLabelClick}
        >
          <slot name="label">${this.label}</slot>

          ${this.required ? html`
                <lynk-tooltip content="Required" hoist>
                  <lynk-icon style="font-size: 9px;" name="asterisk" library="system"></lynk-icon>
                </lynk-tooltip>
              ` : ""}
          ${hasHelpTip ? html`
                <lynk-tooltip hoist>
                  <div slot="content">
                    <slot name="help-tip">${this.helpTip}</slot>
                  </div>
                  <lynk-icon style="font-size: 11px;" name="question-fill" library="system"></lynk-icon>
                </lynk-tooltip>
              ` : ""}
        </label>

        <slot
          part="control"
          class="form-field__control"
          @click=${this.focus}
          @slotchange=${this.handleDefaultSlotChange}
        ></slot>

        <div
          part="help-text"
          id="help-text"
          class="form-field__help-text"
          aria-hidden=${hasHelpText ? "false" : "true"}
        >
          <slot name="help-text">${this.helpText}</slot>
        </div>
      </fieldset>
    `;
  }
};
LynkFormField.styles = [component_styles_default, form_field_styles_default];
LynkFormField.dependencies = {
  "lynk-icon": LynkIcon,
  "lynk-tooltip": LynkTooltip
};
__decorateClass([
  query("slot:not([name])")
], LynkFormField.prototype, "defaultSlot", 2);
__decorateClass([
  state()
], LynkFormField.prototype, "hasFocus", 2);
__decorateClass([
  property({ attribute: false })
], LynkFormField.prototype, "containingElement", 2);
__decorateClass([
  property({ reflect: true })
], LynkFormField.prototype, "state", 2);
__decorateClass([
  property({ reflect: true })
], LynkFormField.prototype, "size", 2);
__decorateClass([
  property()
], LynkFormField.prototype, "label", 2);
__decorateClass([
  property()
], LynkFormField.prototype, "id", 2);
__decorateClass([
  property({ attribute: "help-text" })
], LynkFormField.prototype, "helpText", 2);
__decorateClass([
  property({ attribute: "help-tip" })
], LynkFormField.prototype, "helpTip", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkFormField.prototype, "required", 2);

export {
  LynkFormField
};
