import {
  defaultValue
} from "./chunk.GI7VDIWX.js";
import {
  form_control_styles_default
} from "./chunk.6GN7NPQ7.js";
import {
  checkbox_styles_default
} from "./chunk.66FHFCF6.js";
import {
  FormControlController
} from "./chunk.74PYJKHH.js";
import {
  HasSlotController
} from "./chunk.OW5NIGGX.js";
import {
  LynkIcon
} from "./chunk.OTHQ47SZ.js";
import {
  watch
} from "./chunk.GMYPQTFK.js";
import {
  LynkElement
} from "./chunk.7M4AVQ6D.js";
import {
  component_styles_default
} from "./chunk.Y7724W4D.js";
import {
  __decorateClass
} from "./chunk.KAW7D32O.js";

// src/components/checkbox/checkbox.component.ts
import { classMap } from "lit/directives/class-map.js";
import { html } from "lit";
import { ifDefined } from "lit/directives/if-defined.js";
import { live } from "lit/directives/live.js";
import { property, query, state } from "lit/decorators.js";
var LynkCheckbox = class extends LynkElement {
  constructor() {
    super(...arguments);
    this.formControlController = new FormControlController(this, {
      value: (control) => control.checked ? control.value || "on" : void 0,
      defaultValue: (control) => control.defaultChecked,
      setValue: (control, checked) => control.checked = checked
    });
    this.hasSlotController = new HasSlotController(this, "help-text");
    this.hasLabel = false;
    this.hasFocus = false;
    this.title = "";
    this.name = "";
    this.size = "medium";
    this.disabled = false;
    this.checked = false;
    this.indeterminate = false;
    this.defaultChecked = false;
    this.form = "";
    this.required = false;
    this.noBubble = false;
    this.state = "default";
    this.helpText = "";
  }
  /** Gets the validity state object */
  get validity() {
    return this.input.validity;
  }
  /** Gets the validation message */
  get validationMessage() {
    return this.input.validationMessage;
  }
  firstUpdated() {
    this.formControlController.updateValidity();
  }
  connectedCallback() {
    super.connectedCallback();
    this.handleHostClick = this.handleHostClick.bind(this);
    this.addEventListener("click", this.handleHostClick);
  }
  disconnectedCallback() {
    super.disconnectedCallback();
    this.removeEventListener("click", this.handleHostClick);
  }
  handleHostClick(event) {
    if (this.disabled) {
      event.preventDefault();
      event.stopImmediatePropagation();
    }
    if (this.noBubble) {
      event.stopPropagation();
    }
  }
  handleClick() {
    this.checked = !this.checked;
    this.indeterminate = false;
    this.emit("ev-change", { bubbles: !this.noBubble });
  }
  handleBlur() {
    this.hasFocus = false;
    this.emit("ev-blur");
  }
  handleInput() {
    this.emit("ev-input");
  }
  handleInvalid(event) {
    this.formControlController.setValidity(false);
    this.formControlController.emitInvalidEvent(event);
  }
  handleFocus() {
    this.hasFocus = true;
    this.emit("ev-focus");
  }
  handleSlotChange() {
    const slottedElements = [...this.defaultSlot.assignedNodes({ flatten: true })];
    if (slottedElements.length) {
      this.hasLabel = true;
    } else {
      this.hasLabel = false;
    }
  }
  handleDisabledChange() {
    this.formControlController.setValidity(this.disabled);
  }
  handleStateChange() {
    this.input.checked = this.checked;
    this.input.indeterminate = this.indeterminate;
    this.formControlController.updateValidity();
  }
  /** Simulates a click on the checkbox. */
  click() {
    this.input.click();
  }
  /** Sets focus on the checkbox. */
  focus(options) {
    this.input.focus(options);
  }
  /** Removes focus from the checkbox. */
  blur() {
    this.input.blur();
  }
  /** Checks for validity but does not show a validation message. Returns true when valid and false when invalid. */
  checkValidity() {
    return this.input.checkValidity();
  }
  /** Gets the associated form, if one exists. */
  getForm() {
    return this.formControlController.getForm();
  }
  /** Checks for validity and shows a validation message if the control is invalid. */
  reportValidity() {
    return this.input.reportValidity();
  }
  /**
   * Sets a custom validation message. The value provided will be shown to the user when the form is submitted. To clear
   * the custom validation message, call this method with an empty string.
   */
  setCustomValidity(message) {
    this.input.setCustomValidity(message);
    this.formControlController.updateValidity();
  }
  render() {
    const hasHelpTextSlot = this.hasSlotController.test("help-text");
    const hasHelpText = this.helpText ? true : !!hasHelpTextSlot;
    return html`
      <div
        class=${classMap({
      "form-control": true,
      "form-control--small": this.size === "small",
      "form-control--medium": this.size === "medium",
      "form-control--large": this.size === "large",
      "form-control--has-help-text": hasHelpText
    })}
      >
        <label
          part="base"
          class=${classMap({
      checkbox: true,
      "checkbox--checked": this.checked,
      "checkbox--disabled": this.disabled,
      "checkbox--focused": this.hasFocus,
      "checkbox--has-label": this.hasLabel,
      "checkbox--indeterminate": this.indeterminate,
      "checkbox--small": this.size === "small",
      "checkbox--medium": this.size === "medium",
      "checkbox--large": this.size === "large",
      "checkbox--has-error": this.state === "error" || this.hasAttribute("data-user-invalid"),
      "checkbox--has-warning": this.state === "warning",
      "checkbox--has-success": this.state === "success"
    })}
        >
          <input
            class="checkbox__input"
            type="checkbox"
            title=${this.title}
            name=${this.name}
            value=${ifDefined(this.value)}
            .indeterminate=${live(this.indeterminate)}
            .checked=${live(this.checked)}
            .disabled=${this.disabled}
            .required=${this.required}
            aria-checked=${this.checked ? "true" : "false"}
            aria-describedby="help-text"
            @click=${this.handleClick}
            @input=${this.handleInput}
            @invalid=${this.handleInvalid}
            @blur=${this.handleBlur}
            @focus=${this.handleFocus}
          />

          <span
            part="control${this.checked ? " control--checked" : ""}${this.indeterminate ? " control--indeterminate" : ""}"
            class="checkbox__control"
          >
            ${this.checked ? html`
                  <lynk-icon
                    part="checked-icon"
                    class="checkbox__checked-icon"
                    library="system"
                    name="check"
                  ></lynk-icon>
                ` : ""}
            ${!this.checked && this.indeterminate ? html`
                  <lynk-icon
                    part="indeterminate-icon"
                    class="checkbox__indeterminate-icon"
                    library="system"
                    name="indeterminate"
                  ></lynk-icon>
                ` : ""}
          </span>

          <div part="label" class="checkbox__label">
            <slot @slotchange=${this.handleSlotChange}></slot>
          </div>
        </label>

        <div
          aria-hidden=${hasHelpText ? "false" : "true"}
          class="form-control__help-text"
          id="help-text"
          part="form-control-help-text"
        >
          <slot name="help-text">${this.helpText}</slot>
        </div>
      </div>
    `;
  }
};
LynkCheckbox.styles = [component_styles_default, form_control_styles_default, checkbox_styles_default];
LynkCheckbox.dependencies = { "lynk-icon": LynkIcon };
__decorateClass([
  query("slot")
], LynkCheckbox.prototype, "defaultSlot", 2);
__decorateClass([
  query('input[type="checkbox"]')
], LynkCheckbox.prototype, "input", 2);
__decorateClass([
  state()
], LynkCheckbox.prototype, "hasLabel", 2);
__decorateClass([
  state()
], LynkCheckbox.prototype, "hasFocus", 2);
__decorateClass([
  property()
], LynkCheckbox.prototype, "title", 2);
__decorateClass([
  property()
], LynkCheckbox.prototype, "name", 2);
__decorateClass([
  property()
], LynkCheckbox.prototype, "value", 2);
__decorateClass([
  property({ reflect: true })
], LynkCheckbox.prototype, "size", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkCheckbox.prototype, "disabled", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkCheckbox.prototype, "checked", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkCheckbox.prototype, "indeterminate", 2);
__decorateClass([
  defaultValue("checked")
], LynkCheckbox.prototype, "defaultChecked", 2);
__decorateClass([
  property({ reflect: true })
], LynkCheckbox.prototype, "form", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkCheckbox.prototype, "required", 2);
__decorateClass([
  property({ attribute: "no-bubble", type: Boolean, reflect: true })
], LynkCheckbox.prototype, "noBubble", 2);
__decorateClass([
  property({ reflect: true })
], LynkCheckbox.prototype, "state", 2);
__decorateClass([
  property({ attribute: "help-text" })
], LynkCheckbox.prototype, "helpText", 2);
__decorateClass([
  watch("disabled", { waitUntilFirstUpdate: true })
], LynkCheckbox.prototype, "handleDisabledChange", 1);
__decorateClass([
  watch(["checked", "indeterminate"], { waitUntilFirstUpdate: true })
], LynkCheckbox.prototype, "handleStateChange", 1);

export {
  LynkCheckbox
};
