import {
  textarea_styles_default
} from "./chunk.D5YKVSBU.js";
import {
  LynkTooltip
} from "./chunk.TNZ6RBLS.js";
import {
  defaultValue
} from "./chunk.GI7VDIWX.js";
import {
  form_control_styles_default
} from "./chunk.6GN7NPQ7.js";
import {
  FormControlController
} from "./chunk.74PYJKHH.js";
import {
  HasSlotController
} from "./chunk.OW5NIGGX.js";
import {
  LynkIcon
} from "./chunk.OTHQ47SZ.js";
import {
  watch
} from "./chunk.GMYPQTFK.js";
import {
  LynkElement
} from "./chunk.7M4AVQ6D.js";
import {
  component_styles_default
} from "./chunk.Y7724W4D.js";
import {
  __decorateClass
} from "./chunk.KAW7D32O.js";

// src/components/textarea/textarea.component.ts
import { classMap } from "lit/directives/class-map.js";
import { html } from "lit";
import { ifDefined } from "lit/directives/if-defined.js";
import { live } from "lit/directives/live.js";
import { property, query, state } from "lit/decorators.js";
var LynkTextarea = class extends LynkElement {
  constructor() {
    super(...arguments);
    this.formControlController = new FormControlController(this, {
      assumeInteractionOn: ["ev-blur", "ev-input"]
    });
    this.hasSlotController = new HasSlotController(this, "help-text", "help-tip", "label");
    this.hasFocus = false;
    this.title = "";
    this.name = "";
    this.value = "";
    this.state = "default";
    this.size = "medium";
    this.filled = false;
    this.label = "";
    this.helpText = "";
    this.helpTip = "";
    this.placeholder = "";
    this.rows = 4;
    this.resize = "vertical";
    this.disabled = false;
    this.readonly = false;
    this.restricted = false;
    this.form = "";
    this.required = false;
    this.spellcheck = true;
    this.defaultValue = "";
  }
  /** Gets the validity state object */
  get validity() {
    return this.input.validity;
  }
  /** Gets the validation message */
  get validationMessage() {
    return this.input.validationMessage;
  }
  connectedCallback() {
    super.connectedCallback();
    this.resizeObserver = new ResizeObserver(() => this.setTextareaHeight());
    this.updateComplete.then(() => {
      this.setTextareaHeight();
      this.resizeObserver.observe(this.input);
    });
  }
  firstUpdated() {
    this.formControlController.updateValidity();
  }
  disconnectedCallback() {
    var _a;
    super.disconnectedCallback();
    if (this.input) {
      (_a = this.resizeObserver) == null ? void 0 : _a.unobserve(this.input);
    }
  }
  handleBlur() {
    this.hasFocus = false;
    this.emit("ev-blur");
  }
  handleChange() {
    this.value = this.input.value;
    this.setTextareaHeight();
    this.emit("ev-change");
  }
  handleFocus() {
    this.hasFocus = true;
    this.emit("ev-focus");
  }
  handleInput() {
    this.value = this.input.value;
    this.emit("ev-input");
  }
  handleInvalid(event) {
    this.formControlController.setValidity(false);
    this.formControlController.emitInvalidEvent(event);
  }
  setTextareaHeight() {
    if (this.resize === "auto") {
      this.sizeAdjuster.style.height = `${this.input.clientHeight}px`;
      this.input.style.height = "auto";
      this.input.style.height = `${this.input.scrollHeight}px`;
    } else {
      this.input.style.height = "";
    }
  }
  handleDisabledChange() {
    this.formControlController.setValidity(this.disabled);
  }
  handleRowsChange() {
    this.setTextareaHeight();
  }
  async handleValueChange() {
    await this.updateComplete;
    this.formControlController.updateValidity();
    this.setTextareaHeight();
  }
  /** Sets focus on the textarea. */
  focus(options) {
    this.input.focus(options);
  }
  /** Removes focus from the textarea. */
  blur() {
    this.input.blur();
  }
  /** Selects all the text in the textarea. */
  select() {
    this.input.select();
  }
  /** Gets or sets the textarea's scroll position. */
  scrollPosition(position) {
    if (position) {
      if (typeof position.top === "number") this.input.scrollTop = position.top;
      if (typeof position.left === "number") this.input.scrollLeft = position.left;
      return void 0;
    }
    return {
      top: this.input.scrollTop,
      left: this.input.scrollTop
    };
  }
  /** Sets the start and end positions of the text selection (0-based). */
  setSelectionRange(selectionStart, selectionEnd, selectionDirection = "none") {
    this.input.setSelectionRange(selectionStart, selectionEnd, selectionDirection);
  }
  /** Replaces a range of text with a new string. */
  setRangeText(replacement, start, end, selectMode) {
    this.input.setRangeText(replacement, start, end, selectMode);
    if (this.value !== this.input.value) {
      this.value = this.input.value;
    }
    if (this.value !== this.input.value) {
      this.value = this.input.value;
      this.setTextareaHeight();
    }
  }
  /** Checks for validity but does not show the browser's validation message. */
  checkValidity() {
    return this.input.checkValidity();
  }
  /** Gets the associated form, if one exists. */
  getForm() {
    return this.formControlController.getForm();
  }
  /** Checks for validity and shows the browser's validation message if the control is invalid. */
  reportValidity() {
    return this.input.reportValidity();
  }
  /** Sets a custom validation message. If `message` is not empty, the field will be considered invalid. */
  setCustomValidity(message) {
    this.input.setCustomValidity(message);
    this.formControlController.updateValidity();
  }
  render() {
    const hasLabelSlot = this.hasSlotController.test("label");
    const hasHelpTextSlot = this.hasSlotController.test("help-text");
    const hasHelpTipSlot = this.hasSlotController.test("help-tip");
    const hasLabel = this.label ? true : !!hasLabelSlot;
    const hasHelpText = this.helpText ? true : !!hasHelpTextSlot;
    const hasHelpTip = this.helpTip ? true : !!hasHelpTipSlot;
    return html`
      <div
        part="form-control"
        class=${classMap({
      "form-control": true,
      "form-control--small": this.size === "small",
      "form-control--medium": this.size === "medium",
      "form-control--large": this.size === "large",
      "form-control--has-label": hasLabel,
      "form-control--has-help-text": hasHelpText,
      "form-control--has-error": this.state === "error" || this.hasAttribute("data-user-invalid"),
      "form-control--has-warning": this.state === "warning",
      "form-control--has-success": this.state === "success"
    })}
      >
        <label
          part="form-control-label"
          class=${classMap({
      "form-control__label": true,
      "form-control--focused": this.hasFocus
    })}
          for="input"
          aria-hidden=${hasLabel ? "false" : "true"}
        >
          <slot name="label">${this.label}</slot>

          ${this.required ? html`
                <lynk-tooltip content="Required" hoist>
                  <lynk-icon style="font-size: 9px;" name="asterisk" library="system"></lynk-icon>
                </lynk-tooltip>
              ` : ""}
          ${hasHelpTip ? html`
                <lynk-tooltip hoist>
                  <div slot="content">
                    <slot name="help-tip">${this.helpTip}</slot>
                  </div>
                  <lynk-icon style="font-size: 11px;" name="question-fill" library="system"></lynk-icon>
                </lynk-tooltip>
              ` : ""}
        </label>

        <div part="form-control-input" class="form-control-input">
          <div
            part="base"
            class=${classMap({
      textarea: true,
      "textarea--small": this.size === "small",
      "textarea--medium": this.size === "medium",
      "textarea--large": this.size === "large",
      "textarea--standard": !this.filled,
      "textarea--filled": this.filled,
      "textarea--disabled": this.disabled,
      "textarea--restricted": this.restricted,
      "textarea--focused": this.hasFocus,
      "textarea--empty": !this.value,
      "textarea--resize-none": this.resize === "none",
      "textarea--resize-vertical": this.resize === "vertical",
      "textarea--resize-auto": this.resize === "auto",
      "textarea--has-error": this.state === "error" || this.hasAttribute("data-user-invalid"),
      "textarea--has-warning": this.state === "warning",
      "textarea--has-success": this.state === "success"
    })}
          >
            ${this.restricted ? html`
                  <div
                    part="textarea"
                    aria-describedby="help-text"
                    class="textarea__control textarea__control--restricted"
                  >
                    ${this.value || "None"}
                  </div>
                ` : html`
                  <textarea
                    part="textarea"
                    id="input"
                    class="textarea__control"
                    title=${this.title}
                    name=${ifDefined(this.name)}
                    .value=${live(this.value)}
                    ?disabled=${this.disabled}
                    ?readonly=${this.readonly}
                    ?required=${this.required}
                    placeholder=${ifDefined(this.placeholder)}
                    rows=${ifDefined(this.rows)}
                    minlength=${ifDefined(this.minlength)}
                    maxlength=${ifDefined(this.maxlength)}
                    autocapitalize=${ifDefined(this.autocapitalize)}
                    autocorrect=${ifDefined(this.autocorrect)}
                    ?autofocus=${this.autofocus}
                    spellcheck=${ifDefined(this.spellcheck)}
                    enterkeyhint=${ifDefined(this.enterkeyhint)}
                    inputmode=${ifDefined(this.inputmode)}
                    aria-describedby="help-text"
                    @change=${this.handleChange}
                    @input=${this.handleInput}
                    @invalid=${this.handleInvalid}
                    @focus=${this.handleFocus}
                    @blur=${this.handleBlur}
                  ></textarea>
                `}
            <!-- This "adjuster" exists to prevent layout shifting. https://github.com/shoelace-style/shoelace/issues/2180 -->
            <div part="textarea-adjuster" class="textarea__size-adjuster" ?hidden=${this.resize !== "auto"}></div>
          </div>
        </div>

        <div
          part="form-control-help-text"
          id="help-text"
          class="form-control__help-text"
          aria-hidden=${hasHelpText ? "false" : "true"}
        >
          <slot name="help-text">${this.helpText}</slot>
        </div>
      </div>
    `;
  }
};
LynkTextarea.styles = [component_styles_default, form_control_styles_default, textarea_styles_default];
LynkTextarea.dependencies = { "lynk-icon": LynkIcon, "lynk-tooltip": LynkTooltip };
__decorateClass([
  query(".textarea__control")
], LynkTextarea.prototype, "input", 2);
__decorateClass([
  query(".textarea__size-adjuster")
], LynkTextarea.prototype, "sizeAdjuster", 2);
__decorateClass([
  state()
], LynkTextarea.prototype, "hasFocus", 2);
__decorateClass([
  property()
], LynkTextarea.prototype, "title", 2);
__decorateClass([
  property()
], LynkTextarea.prototype, "name", 2);
__decorateClass([
  property()
], LynkTextarea.prototype, "value", 2);
__decorateClass([
  property({ reflect: true })
], LynkTextarea.prototype, "state", 2);
__decorateClass([
  property({ reflect: true })
], LynkTextarea.prototype, "size", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkTextarea.prototype, "filled", 2);
__decorateClass([
  property()
], LynkTextarea.prototype, "label", 2);
__decorateClass([
  property({ attribute: "help-text" })
], LynkTextarea.prototype, "helpText", 2);
__decorateClass([
  property({ attribute: "help-tip" })
], LynkTextarea.prototype, "helpTip", 2);
__decorateClass([
  property()
], LynkTextarea.prototype, "placeholder", 2);
__decorateClass([
  property({ type: Number })
], LynkTextarea.prototype, "rows", 2);
__decorateClass([
  property()
], LynkTextarea.prototype, "resize", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkTextarea.prototype, "disabled", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkTextarea.prototype, "readonly", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkTextarea.prototype, "restricted", 2);
__decorateClass([
  property({ reflect: true })
], LynkTextarea.prototype, "form", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkTextarea.prototype, "required", 2);
__decorateClass([
  property({ type: Number })
], LynkTextarea.prototype, "minlength", 2);
__decorateClass([
  property({ type: Number })
], LynkTextarea.prototype, "maxlength", 2);
__decorateClass([
  property()
], LynkTextarea.prototype, "autocapitalize", 2);
__decorateClass([
  property()
], LynkTextarea.prototype, "autocorrect", 2);
__decorateClass([
  property()
], LynkTextarea.prototype, "autocomplete", 2);
__decorateClass([
  property({ type: Boolean })
], LynkTextarea.prototype, "autofocus", 2);
__decorateClass([
  property()
], LynkTextarea.prototype, "enterkeyhint", 2);
__decorateClass([
  property({
    type: Boolean,
    converter: {
      // Allow "true|false" attribute values but keep the property boolean
      fromAttribute: (value) => !value || value === "false" ? false : true,
      toAttribute: (value) => value ? "true" : "false"
    }
  })
], LynkTextarea.prototype, "spellcheck", 2);
__decorateClass([
  property()
], LynkTextarea.prototype, "inputmode", 2);
__decorateClass([
  defaultValue()
], LynkTextarea.prototype, "defaultValue", 2);
__decorateClass([
  watch("disabled", { waitUntilFirstUpdate: true })
], LynkTextarea.prototype, "handleDisabledChange", 1);
__decorateClass([
  watch("rows", { waitUntilFirstUpdate: true })
], LynkTextarea.prototype, "handleRowsChange", 1);
__decorateClass([
  watch("value", { waitUntilFirstUpdate: true })
], LynkTextarea.prototype, "handleValueChange", 1);

export {
  LynkTextarea
};
