import {
  page_sidebar_styles_default
} from "./chunk.VPCTQLJ3.js";
import {
  page_default
} from "./chunk.NA654ER3.js";
import {
  LynkTooltip
} from "./chunk.TNZ6RBLS.js";
import {
  LynkButton
} from "./chunk.6SMHA74H.js";
import {
  waitForEvent
} from "./chunk.YEUBLCCQ.js";
import {
  HasSlotController
} from "./chunk.OW5NIGGX.js";
import {
  LocalizeController
} from "./chunk.6CTB5ZDJ.js";
import {
  watch
} from "./chunk.GMYPQTFK.js";
import {
  LynkElement
} from "./chunk.7M4AVQ6D.js";
import {
  component_styles_default
} from "./chunk.Y7724W4D.js";
import {
  __decorateClass
} from "./chunk.KAW7D32O.js";

// src/components/page-sidebar/page-sidebar.component.ts
import { classMap } from "lit/directives/class-map.js";
import { html } from "lit";
import { property, query } from "lit/decorators.js";
var LynkPageSidebar = class extends LynkElement {
  constructor() {
    super(...arguments);
    this.hasSlotController = new HasSlotController(this, "footer", "header", "heading", "header-actions");
    this.localize = new LocalizeController(this);
    this.open = false;
    this.placement = "left";
    this.toggle = "none";
    this.togglePlacement = "top";
    this.toggleTipHideText = "Hide Sidebar";
    this.toggleTipShowText = "Show Sidebar";
  }
  connectedCallback() {
    super.connectedCallback();
    if (!this.slot && this.hasParentLayout()) {
      this.slot = `${this.placement}-sidebar`;
    }
    if (this.toggle === "none") {
      this.open = true;
    }
  }
  firstUpdated() {
    this.updateVisibility();
  }
  /** Shows the sidebar */
  async show() {
    if (this.open) {
      return void 0;
    }
    this.open = true;
    return waitForEvent(this, "ev-after-show");
  }
  /** Hides the sidebar */
  async hide() {
    if (!this.open) {
      return void 0;
    }
    this.open = false;
    return waitForEvent(this, "ev-after-hide");
  }
  // Checks whether the item is nested into an item
  hasParentLayout() {
    const parent = this.parentElement;
    return parent instanceof page_default;
  }
  handleToggleClick() {
    if (this.open) {
      this.hide();
    } else {
      this.show();
    }
  }
  updateVisibility() {
    if (this.toggle === "visibility") {
      this.sidebar.hidden = !this.open;
    }
    if (this.toggle === "contents") {
      this.tooltip.hide();
      this.body.hidden = !this.open;
      this.header.hidden = !this.open;
      this.footer.hidden = !this.open;
    }
  }
  handleOpenChange() {
    if (this.open) {
      this.emit("ev-show");
      this.updateVisibility();
      this.emit("ev-after-show");
    } else {
      this.emit("ev-hide");
      this.updateVisibility();
      this.emit("ev-after-hide");
    }
  }
  render() {
    const hasHeading = this.heading ? true : false;
    return html`
      <aside
        part="base"
        class=${classMap({
      "page-sidebar": true,
      "page-sidebar--open": this.open,
      "page-sidebar--left": this.placement === "left",
      "page-sidebar--right": this.placement === "right",
      "page-sidebar--left-inset": this.placement === "left-inset",
      "page-sidebar--right-inset": this.placement === "right-inset",
      "page-sidebar--rtl": this.localize.dir() === "rtl",
      "page-sidebar--has-header": this.hasSlotController.test("header") || this.hasSlotController.test("heading") || this.hasSlotController.test("header-actions") || hasHeading,
      "page-sidebar--has-footer": this.hasSlotController.test("footer")
    })}
      >
        <slot name="nav" part="nav" class="page-sidebar__nav"></slot>
        <div part="container" class="page-sidebar__container">
          <header part="header" class="page-sidebar__header">
            <slot name="header">
              <h2 part="title" class="page-sidebar__title" id="title">
                <!-- If there's no label, use an invisible character to prevent the header from collapsing -->
                <slot name="heading">
                  ${this.heading && this.heading.length > 0 ? this.heading : String.fromCharCode(65279)}
                </slot>
              </h2>
              <div part="header-actions" class="page-sidebar__header-actions">
                <slot name="header-actions">
                  ${this.toggle === "visibility" ? html`
                        <lynk-button
                          part="close-button"
                          size="tiny"
                          circle
                          label=${this.localize.term("close")}
                          @click=${this.handleToggleClick}
                        >
                          <lynk-icon library="system" name="x-lg"></lynk-icon>
                        </lynk-button>
                      ` : ""}
                </slot>
              </div>
            </slot>
          </header>

          <slot part="body" class="page-sidebar__body"></slot>

          <footer part="footer" class="page-sidebar__footer">
            <slot name="footer"></slot>
          </footer>
        </div>

        ${this.toggle === "contents" ? html`
              <lynk-tooltip
                hoist
                placement="bottom"
                class="page-sidebar__trigger-tooltip"
                content="${this.open ? this.toggleTipHideText : this.toggleTipShowText}"
              >
                <lynk-button
                  part="close-button"
                  size="tiny"
                  circle
                  exportparts="base:close-button__base"
                  class=${classMap({
      "page-sidebar__toggle": true,
      "page-sidebar__toggle--center": this.togglePlacement === "center",
      "page-sidebar__toggle--bottom": this.togglePlacement === "bottom",
      "page-sidebar__toggle--hidden": this.togglePlacement === "hidden"
    })}
                  label=${this.localize.term("close")}
                  @click=${this.handleToggleClick}
                >
                  <lynk-icon library="system" name="${this.open ? "chevron-left" : "chevron-right"}"></lynk-icon>
                </lynk-button>
              </lynk-tooltip>
            ` : ""}
      </aside>
    `;
  }
};
LynkPageSidebar.styles = [component_styles_default, page_sidebar_styles_default];
LynkPageSidebar.dependencies = { "lynk-button": LynkButton, "lynk-tooltip": LynkTooltip };
__decorateClass([
  query(".page-sidebar")
], LynkPageSidebar.prototype, "sidebar", 2);
__decorateClass([
  query(".page-sidebar__container")
], LynkPageSidebar.prototype, "container", 2);
__decorateClass([
  query(".page-sidebar__body")
], LynkPageSidebar.prototype, "body", 2);
__decorateClass([
  query(".page-sidebar__header")
], LynkPageSidebar.prototype, "header", 2);
__decorateClass([
  query(".page-sidebar__footer")
], LynkPageSidebar.prototype, "footer", 2);
__decorateClass([
  query(".page-sidebar__trigger-tooltip")
], LynkPageSidebar.prototype, "tooltip", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], LynkPageSidebar.prototype, "open", 2);
__decorateClass([
  property({ reflect: true })
], LynkPageSidebar.prototype, "heading", 2);
__decorateClass([
  property({ reflect: true })
], LynkPageSidebar.prototype, "placement", 2);
__decorateClass([
  property({ reflect: true })
], LynkPageSidebar.prototype, "toggle", 2);
__decorateClass([
  property({ attribute: "toggle-placement", reflect: true })
], LynkPageSidebar.prototype, "togglePlacement", 2);
__decorateClass([
  property({ attribute: "toggle-tip-hide-text", reflect: false })
], LynkPageSidebar.prototype, "toggleTipHideText", 2);
__decorateClass([
  property({ attribute: "toggle-tip-show-text", reflect: false })
], LynkPageSidebar.prototype, "toggleTipShowText", 2);
__decorateClass([
  watch("open", { waitUntilFirstUpdate: true })
], LynkPageSidebar.prototype, "handleOpenChange", 1);

export {
  LynkPageSidebar
};
