import LynkElement from '../../internal/lynk-element.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary Cards can be used to group media with related subjects into a container.
 * @documentation https://lynk.design/components/card
 * @status stable
 * @since 1.0.0
 *
 * @slot - The card's main content.
 * @slot header - An optional header for the card.
 * @slot footer - An optional footer for the card.
 * @slot image - An optional image to render at the start of the card.
 *
 * @csspart base - The component's base wrapper.
 * @csspart image - The container that wraps the card's image.
 * @csspart header - The container that wraps the card's header.
 * @csspart body - The container that wraps the card's main content.
 * @csspart footer - The container that wraps the card's footer.
 *
 * @cssproperty --border-color - The card's border color, including borders that occur inside the card.
 * @cssproperty --border-radius - The border radius for the card's edges.
 * @cssproperty --border-width - The width of the card's borders.
 * @cssproperty --state-color - A custom color for the interactive state.
 * @cssproperty --pulse-speed - A custom speed for the pulse animation.
 * @cssproperty --padding - The padding to use for the card's sections.
 */
export default class LynkCard extends LynkElement {
    static styles: CSSResultGroup;
    private readonly hasSlotController;
    /** Draws the card without outlines or background except when being interacted with */
    stealth: boolean;
    /** The component's size. Will be inherited by any descendants with a size attribute. */
    size: 'small' | 'medium' | 'large' | 'inherit';
    /** Draws the card using status colors */
    state: 'primary' | 'accent' | 'danger' | 'success' | 'warning' | 'info' | 'neutral';
    /** Determines whether to style the card on hover */
    interactive: boolean;
    /** Draws the card in a highlighted state  */
    active: boolean;
    /** Pulse the status colors for increased visibility */
    pulse: boolean;
    /** The image block aspect ratio. */
    aspectRatio: '1:1' | '3:4' | '4:3' | '16:9' | '2.35:1';
    render(): import("lit").TemplateResult<1>;
}
