import LynkElement from '../../internal/lynk-element.js';
import LynkIcon from '../icon/icon.component.js';
import LynkTooltip from '../tooltip/tooltip.component.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary A container for customized or non-standard form inputs.
 * @documentation https://lynk.design/components/form-field
 * @since 1.0.0
 * @status experimental
 *
 * @dependency lynk-icon
 * @dependency lynk-tooltip
 *
 * @event ev-focus - Emitted when field or slotted element gains focus.
 * @event ev-blur - Emitted when field or slotted element loses focus.
 *
 * @slot - The default slot.
 * @slot help-tip - Custom help-tip content.
 * @slot help-text - Custom help-text content.
 * @slot label - Custom label content.
 *
 * @csspart base - The component's base wrapper.
 * @csspart label - The component's label wrapper.
 * @csspart control - The component's slotted control wrapper.
 * @csspart help-text - The component's help-text wrapper.
 *
 */
export default class LynkFormField extends LynkElement {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-icon': typeof LynkIcon;
        'lynk-tooltip': typeof LynkTooltip;
    };
    defaultSlot: HTMLSlotElement;
    private target?;
    private readonly hasSlotController;
    private hasFocus;
    /** The field will lose focus when the user interacts outside of this element (e.g. clicking). */
    containingElement?: HTMLElement;
    /** The fields's styled validity state  */
    state: 'error' | 'warning' | 'success' | 'default';
    /** The input's size. */
    size: 'small' | 'medium' | 'large';
    /** The input's label. Alternatively, you can use the label slot. */
    label: string;
    id: string;
    /** The help text below the input. Alternatively, you can use the help-text slot. */
    helpText: string;
    /** The help tooltip appended to the label. Alternatively, you can use the help-tip slot. */
    helpTip: string;
    /** Adds the required mark. */
    required: boolean;
    connectedCallback(): void;
    firstUpdated(): void;
    disconnectedCallback(): void;
    private addOpenListeners;
    private removeOpenListeners;
    private handleFocus;
    private handleBlur;
    private handleLabelClick;
    private handleDefaultSlotChange;
    private handleDocumentKeyDown;
    private handleDocumentMouseDown;
    private manageAccessibleTarget;
    /** Sets focus on the control. */
    focus(options?: FocusOptions): void;
    /** Removes focus from the control. */
    blur(): void;
    render(): import("lit").TemplateResult<1>;
}
