import LynkElement from '../../internal/lynk-element.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary The Intersection Observer component offers a thin, declarative interface to the [`IntersectionObserver API`](https://developer.mozilla.org/en-US/docs/Web/API/IntersectionObserver).
 * @documentation https://lynk.design/components/intersection-observer
 * @since 1.0.0
 * @status stable
 *
 * @slot - One or more elements to watch for intersection.
 *
 * @event {{ entry: IntersectionObserverEntry[] }} ev-enter-view - Emitted when a slotted element enters the view.
 * @event {{ entry: IntersectionObserverEntry[] }} ev-exit-view - Emitted when a slotted element exits the view.

 */
export default class LynkIntersectionObserver extends LynkElement {
    static styles: CSSResultGroup;
    private intersectionObserver;
    private observedElements;
    /** Disables the observer. */
    disabled: boolean;
    connectedCallback(): void;
    handleSlotChange(): void;
    disconnectedCallback(): void;
    startObserver(): void;
    stopObserver(): void;
    handleDisabledChange(): void;
    render(): import("lit").TemplateResult<1>;
}
