import LynkElement from '../../internal/lynk-element.js';
import type { CSSResultGroup } from 'lit';
import type LynkMenuItem from '../menu-item/menu-item.component.js';
export interface MenuSelectEventDetail {
    item: LynkMenuItem;
}
/**
 * @summary Menus provide a list of options for the user to choose from.
 * @documentation https://lynk.design/components/menu
 * @since 1.0.0
 * @status stable
 *
 * @slot - The menu's content, including menu items, menu labels, and dividers.
 *
 * @event {{ item: LynkMenuItem }} ev-select - Emitted when a menu item is selected.
 */
export default class LynkMenu extends LynkElement {
    static styles: CSSResultGroup;
    defaultSlot: HTMLSlotElement;
    connectedCallback(): void;
    private handleClick;
    private handleKeyDown;
    private handleMouseDown;
    private handleSlotChange;
    private isMenuItem;
    /** @internal Gets all slotted menu items, ignoring dividers, headers, and other elements. */
    getAllItems(): LynkMenuItem[];
    /**
     * @internal Gets the current menu item, which is the menu item that has `tabindex="0"` within the roving tab index.
     * The menu item may or may not have focus, but for keyboard interaction purposes it's considered the "active" item.
     */
    getCurrentItem(): LynkMenuItem | undefined;
    /**
     * @internal Sets the current menu item to the specified element. This sets `tabindex="0"` on the target element and
     * `tabindex="-1"` to all other items. This method must be called prior to setting focus on a menu item.
     */
    setCurrentItem(item: LynkMenuItem): void;
    render(): import("lit").TemplateResult<1>;
}
