import LynkElement from '../../internal/lynk-element.js';
import LynkPage from '../page/page.component.js';
import LynkPageContent from '../page-content/page-content.component.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary The Page Header is used inside a [Page Layout](/components/page) to standardized header content and controls.
 * @documentation https://lynk.design/components/page-header
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-page
 * @dependency lynk-page-content
 *
 * @slot - The default slot for the title, description, and other relevant metadata.
 * @slot breadcrumb - Designated top-left area for breadcrumb navigation.
 * @slot controls - Designated area to right of default slot for standard header actions.
 * @slot aux - Designated top-right area for auxiliary header actions.
 * @slot tabs - Designated bottom area for tab navigation.
 *
 * @csspart base - The component's base wrapper.
 * @csspart breadcrumb - The component's breadcrumb area wrapper.
 * @csspart controls - The component's controls area wrapper.
 * @csspart main - The component's main area wrapper.
 * @csspart aux - The component's auxiliary controls area wrapper.
 * @csspart tabs - The component's tab area wrapper.
 *
 * @cssproperty --gap - The gutter spacing between slots.
 */
export default class LynkPageHeader extends LynkElement {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-page-content': typeof LynkPageContent;
        'lynk-page': typeof LynkPage;
    };
    /** Set an optional maximum width for page header  */
    width: 'auto' | 'small' | 'medium' | 'large' | 'x-large' | '2x-large' | 'fluid';
    connectedCallback(): void;
    private hasParentLayout;
    render(): import("lit").TemplateResult<1>;
}
