import LynkElement from '../../internal/lynk-element.js';
import LynkIcon from '../icon/icon.component.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary Radios allow the user to select a single option from a group.
 * @documentation https://lynk.design/components/radio
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon
 *
 * @slot - The radio's label.
 *
 * @event ev-blur - Emitted when the control loses focus.
 * @event ev-focus - Emitted when the control gains focus.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart control - The circular container that wraps the radio's checked state.
 * @csspart control--checked - The radio control when the radio is checked.
 * @csspart checked-icon - The checked icon, an `<lynk-icon>` element.
 * @csspart label - The container that wraps the radio's label.
 */
export default class LynkRadio extends LynkElement {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-icon': typeof LynkIcon;
    };
    checked: boolean;
    protected hasFocus: boolean;
    /** The radio's value. When selected, the radio group will receive this value. */
    value: string;
    /** The radio's size. */
    size: 'small' | 'medium' | 'large';
    /** Disables the radio. */
    disabled: boolean;
    constructor();
    connectedCallback(): void;
    private handleBlur;
    private handleClick;
    private handleFocus;
    private setInitialAttributes;
    handleCheckedChange(): void;
    handleDisabledChange(): void;
    render(): import("lit").TemplateResult<1>;
}
