import LynkElement from '../../internal/lynk-element.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary Stacks are a fundamental building block for laying out and aligning small bits of content or simple components in a vertical or horizontal space.
 * @documentation https://lynk.design/components/stack
 * @since 1.0.0
 * @status stable
 *
 * @slot - The default slot.
 *
 * @csspart base - The component's internal wrapper.
 *
 * @cssproperty [--width=100%] - Customize the width of the stack group.
 * @cssproperty [--height=auto] - Customize the width of the stack group.
 * @cssproperty [--gap=var(--lynk-spacing-small)] - Customize the gap of the stack group.
 * @cssproperty [--margin=0] - Customize the margin of the stack group.
 */
export default class LynkStack extends LynkElement {
    static styles: CSSResultGroup;
    /** Stack items horizontally */
    horizontal: boolean;
    /** Reverse the order of stack items */
    reverse: boolean;
    /** How to justify stack items */
    justify?: 'start' | 'center' | 'end' | 'between' | 'around' | 'evenly';
    /** How to align stack items to each-other */
    align?: 'start' | 'center' | 'end' | 'stretch' | 'baseline';
    /** How to wrap the stack */
    wrap: boolean;
    /** The space between stack items. Use spacing tokens or any custom size. */
    gap: string;
    render(): import("lit").TemplateResult<1>;
}
