import Component from '../../components/animation/animation.component.js';
import { type EventName } from '@lit/react';
import type { LynkCancelEvent } from '../../events/events.js';
import type { LynkFinishEvent } from '../../events/events.js';
import type { LynkStartEvent } from '../../events/events.js';
export type { LynkCancelEvent } from '../../events/events.js';
export type { LynkFinishEvent } from '../../events/events.js';
export type { LynkStartEvent } from '../../events/events.js';
/**
 * @summary Animate elements declaratively with nearly 100 baked-in presets, or roll your own with custom keyframes. Powered by the [Web Animations API](https://developer.mozilla.org/en-US/docs/Web/API/Web_Animations_API).
 * @documentation https://lynk.design/components/animation
 * @since 1.0.0
 * @status stable
 *
 * @event ev-cancel - Emitted when the animation is canceled.
 * @event ev-finish - Emitted when the animation finishes.
 * @event ev-start - Emitted when the animation starts or restarts.
 *
 * @slot - The element to animate. Avoid slotting in more than one element, as subsequent ones will be ignored. To
 *  animate multiple elements, either wrap them in a single container or use multiple `<lynk-animation>` elements.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvCancel: EventName<LynkCancelEvent>;
    EvFinish: EventName<LynkFinishEvent>;
    EvStart: EventName<LynkStartEvent>;
}>;
export default reactWrapper;
