import Component from '../../components/button/button.component.js';
import { type EventName } from '@lit/react';
import type { LynkBlurEvent } from '../../events/events.js';
import type { LynkClickEvent } from '../../events/events.js';
import type { LynkFocusEvent } from '../../events/events.js';
import type { LynkInvalidEvent } from '../../events/events.js';
export type { LynkBlurEvent } from '../../events/events.js';
export type { LynkClickEvent } from '../../events/events.js';
export type { LynkFocusEvent } from '../../events/events.js';
export type { LynkInvalidEvent } from '../../events/events.js';
/**
 * @summary Buttons represent actions that are available to the user.
 * @documentation https://lynk.design/components/button
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon
 * @dependency lynk-spinner
 *
 * @event ev-blur - Emitted when the button loses focus.
 * @event ev-click - Emitted when the button is clicked.
 * @event ev-focus - Emitted when the button gains focus.
 * @event ev-invalid - Emitted when the form control has been checked for validity and its constraints aren't satisfied..
 *
 * @slot - The button's label.
 * @slot prefix - Used to prepend an icon or similar element to the button.
 * @slot suffix - Used to append an icon or similar element to the button.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart prefix - The prefix slot's container.
 * @csspart label - The button's label.
 * @csspart suffix - The suffix slot's container.
 * @csspart caret - The button's caret.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvBlur: EventName<LynkBlurEvent>;
    EvClick: EventName<LynkClickEvent>;
    EvFocus: EventName<LynkFocusEvent>;
    EvInvalid: EventName<LynkInvalidEvent>;
}>;
export default reactWrapper;
