import Component from '../../components/dropdown/dropdown.component.js';
import { type EventName } from '@lit/react';
import type { LynkShowEvent } from '../../events/events.js';
import type { LynkAfterShowEvent } from '../../events/events.js';
import type { LynkHideEvent } from '../../events/events.js';
import type { LynkAfterHideEvent } from '../../events/events.js';
export type { LynkShowEvent } from '../../events/events.js';
export type { LynkAfterShowEvent } from '../../events/events.js';
export type { LynkHideEvent } from '../../events/events.js';
export type { LynkAfterHideEvent } from '../../events/events.js';
/**
 * @summary Dropdowns expose additional content that "drops down" in a panel.
 * @documentation https:/lynk.design/components/dropdown
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-popup
 *
 * @slot - The dropdown's content.
 * @slot trigger - The dropdown's trigger, usually a `<lynk-button>` element.
 *
 * @event ev-show - Emitted when the dropdown opens.
 * @event ev-after-show - Emitted after the dropdown opens and all animations are complete.
 * @event ev-hide - Emitted when the dropdown closes.
 * @event ev-after-hide - Emitted after the dropdown closes and all animations are complete.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart trigger - The container that wraps the trigger.
 * @csspart panel - The panel that gets shown when the dropdown is open.
 *
 * @animation dropdown.show - The animation to use when showing the dropdown.
 * @animation dropdown.hide - The animation to use when hiding the dropdown.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvShow: EventName<LynkShowEvent>;
    EvAfterShow: EventName<LynkAfterShowEvent>;
    EvHide: EventName<LynkHideEvent>;
    EvAfterHide: EventName<LynkAfterHideEvent>;
}>;
export default reactWrapper;
