import Component from '../../components/form-field/form-field.component.js';
import { type EventName } from '@lit/react';
import type { LynkFocusEvent } from '../../events/events.js';
import type { LynkBlurEvent } from '../../events/events.js';
export type { LynkFocusEvent } from '../../events/events.js';
export type { LynkBlurEvent } from '../../events/events.js';
/**
 * @summary A container for customized or non-standard form inputs.
 * @documentation https://lynk.design/components/form-field
 * @since 1.0.0
 * @status experimental
 *
 * @dependency lynk-icon
 * @dependency lynk-tooltip
 *
 * @event ev-focus - Emitted when field or slotted element gains focus.
 * @event ev-blur - Emitted when field or slotted element loses focus.
 *
 * @slot - The default slot.
 * @slot help-tip - Custom help-tip content.
 * @slot help-text - Custom help-text content.
 * @slot label - Custom label content.
 *
 * @csspart base - The component's base wrapper.
 * @csspart label - The component's label wrapper.
 * @csspart control - The component's slotted control wrapper.
 * @csspart help-text - The component's help-text wrapper.
 *
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvFocus: EventName<LynkFocusEvent>;
    EvBlur: EventName<LynkBlurEvent>;
}>;
export default reactWrapper;
