import Component from '../../components/intersection-observer/intersection-observer.component.js';
import { type EventName } from '@lit/react';
import type { LynkEnterViewEvent } from '../../events/events.js';
import type { LynkExitViewEvent } from '../../events/events.js';
export type { LynkEnterViewEvent } from '../../events/events.js';
export type { LynkExitViewEvent } from '../../events/events.js';
/**
 * @summary The Intersection Observer component offers a thin, declarative interface to the [`IntersectionObserver API`](https://developer.mozilla.org/en-US/docs/Web/API/IntersectionObserver).
 * @documentation https://lynk.design/components/intersection-observer
 * @since 1.0.0
 * @status stable
 *
 * @slot - One or more elements to watch for intersection.
 *
 * @event {{ entry: IntersectionObserverEntry[] }} ev-enter-view - Emitted when a slotted element enters the view.
 * @event {{ entry: IntersectionObserverEntry[] }} ev-exit-view - Emitted when a slotted element exits the view.

 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvEnterView: EventName<LynkEnterViewEvent>;
    EvExitView: EventName<LynkExitViewEvent>;
}>;
export default reactWrapper;
