import Component from '../../components/page-sidebar/page-sidebar.component.js';
import { type EventName } from '@lit/react';
import type { LynkShowEvent } from '../../events/events.js';
import type { LynkAfterShowEvent } from '../../events/events.js';
import type { LynkHideEvent } from '../../events/events.js';
import type { LynkAfterHideEvent } from '../../events/events.js';
export type { LynkShowEvent } from '../../events/events.js';
export type { LynkAfterShowEvent } from '../../events/events.js';
export type { LynkHideEvent } from '../../events/events.js';
export type { LynkAfterHideEvent } from '../../events/events.js';
/**
 * @summary The Page Sidebar is used inside a [Page Layout](/components/page) to render navigation and selection menus, or other related content that would normally be placed in a native `<aside>` element.
 * @documentation https://lynk.design/components/page-sidebar
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-button
 * @dependency lynk-tooltip
 *
 * @slot - The sidebar's content.
 * @slot label - The sidebar's label. Alternatively, you can use the label prop.
 * @slot footer - The sidebar's footer, usually one or more buttons representing various options.
 * @slot nav - An optional slot that can be used to display nav controls even when sidebar is collapsed.
 *
 * @event ev-show - Emitted when the sidebar opens.
 * @event ev-after-show - Emitted after the sidebar opens and all animations are complete.
 * @event ev-hide - Emitted when the sidebar closes.
 * @event ev-after-hide - Emitted after the sidebar closes and all animations are complete.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart panel - The sidebar panel (where the sidebar and its content is rendered).
 * @csspart header - The sidebar header.
 * @csspart header-actions - Optional actions to add to the header. Works best with `<lynk-icon-button>`.
 * @csspart title - The sidebar title.
 * @csspart close-button - The close button.
 * @csspart close-button__base - The close button's `base` part.
 * @csspart body - The sidebar body.
 * @csspart footer - The sidebar footer.
 * @csspart nav - The optional sidebar nav do display controls even when the sidebar is collapsed.
 *
 * @cssproperty --width - The preferred width of the sidebar.
 * @cssproperty --header-spacing - The amount of padding to use for the header.
 * @cssproperty --body-spacing - The amount of padding to use for the body.
 * @cssproperty --footer-spacing - The amount of padding to use for the footer.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvShow: EventName<LynkShowEvent>;
    EvAfterShow: EventName<LynkAfterShowEvent>;
    EvHide: EventName<LynkHideEvent>;
    EvAfterHide: EventName<LynkAfterHideEvent>;
}>;
export default reactWrapper;
