import Component from '../../components/page/page.component.js';
/**
 * @summary A standardized page layout container using css grid based layout areas.
 * @documentation https://lynk.design/components/page
 * @since 1.0.0
 * @status stable
 *
 * @slot - The page's main content area. Works best with `<lynk-page-content>`.
 * @slot header - The page's header area. Breadcrumb, title, tabs and other page level controls go in here. Works best with `<lynk-page-header>`
 * @slot left-sidebar - The page's left sidebar with a primary navigation menu. Works best with `<lynk-page-sidebar>`.
 * @slot right-sidebar - The page's right sidebar with a secondary navigation menu. Works best with `<lynk-page-sidebar>`.
 * @slot left-inset-sidebar - A visually nested left sidebar for displaying content specific menus or aside details. Works best with `<lynk-page-sidebar>`
 * @slot right-inset-sidebar - A visually nested right sidebar for displaying content specific menus or aside details. Works best with `<lynk-page-sidebar>`
 * @slot footer - The pages footer, usually one or more buttons representing various primary or secondary options like save or table pagination. Works best with `<lynk-page-footer>`
 *
 * @csspart base - The page layout internal wrapper.
 * @csspart header - The page header area's internal wrapper.
 * @csspart left-sidebar - The page left sidebar area's internal wrapper.
 * @csspart left-inset-sidebar - The page left inset sidebar area's internal wrapper.
 * @csspart main - The main content area's internal wrapper.
 * @csspart right-inset-sidebar - The page right inset sidebar area's internal wrapper.
 * @csspart right-sidebar - The page right sidebar area's internal wrapper.
 * @csspart footer - The page footer areas internal wrapper.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {}>;
export default reactWrapper;
