import Component from '../../components/panel/panel.component.js';
import { type EventName } from '@lit/react';
import type { LynkExpandEvent } from '../../events/events.js';
import type { LynkAfterExpandEvent } from '../../events/events.js';
import type { LynkCollapseEvent } from '../../events/events.js';
import type { LynkAfterCollapseEvent } from '../../events/events.js';
export type { LynkExpandEvent } from '../../events/events.js';
export type { LynkAfterExpandEvent } from '../../events/events.js';
export type { LynkCollapseEvent } from '../../events/events.js';
export type { LynkAfterCollapseEvent } from '../../events/events.js';
/**
 * @summary Panels are lightweight content containers that may either stand alone or be grouped together to form an [Accordion](/components/accordion).
 * @documentation https://lynk.design/components/panel
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon
 *
 * @slot - The panels' content.
 * @slot heading - The panels' heading. Alternatively, you can use the `heading` attribute.
 * @slot prefix - The panels' summary prefix `<slot>`.
 * @slot suffix - The panels' summary suffix `<slot>`.
 * @slot expand-icon - The expand icon's `<slot>`.
 * @slot collapse-icon - The collapse icon's `<slot>`.
 * @slot footer - The panels' footer `<slot>`.
 *
 * @event ev-expand - Emitted when the panel expands.
 * @event ev-after-expand - Emitted after the panel expands and all animations are complete.
 * @event ev-collapse - Emitted when the panel closes.
 * @event ev-after-collapse - Emitted after the panel closes and all animations are complete.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart header - The panel header area.
 * @csspart heading - The panel heading.
 * @csspart prefix - The panel header prefix area.
 * @csspart suffix - The panel header suffix area.
 * @csspart toggle-icon - The expand/collapse toggle icon in the header.
 * @csspart content - The panel content.
 * @csspart footer - The panel footer.
 *
 * @cssproperty --background-color - The panels background color
 * @cssproperty --spacing - The amount of padding to use for the header, body, and footer.
 * @cssproperty --border-color - Apply a panel border of your choosing.
 * @cssproperty --border-radius - The panels border radius.
 *
 * @animation panel.expand - The animation to use when expanding the panel. You can use `height: auto` with this animation.
 * @animation panel.collapse - The animation to use when collapsing the panel. You can use `height: auto` with this animation.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvExpand: EventName<LynkExpandEvent>;
    EvAfterExpand: EventName<LynkAfterExpandEvent>;
    EvCollapse: EventName<LynkCollapseEvent>;
    EvAfterCollapse: EventName<LynkAfterCollapseEvent>;
}>;
export default reactWrapper;
