import Component from '../../components/radio-button/radio-button.component.js';
import { type EventName } from '@lit/react';
import type { LynkBlurEvent } from '../../events/events.js';
import type { LynkFocusEvent } from '../../events/events.js';
export type { LynkBlurEvent } from '../../events/events.js';
export type { LynkFocusEvent } from '../../events/events.js';
/**
 * @summary Radios buttons allow the user to select a single option from a group using a button-like control.
 * @documentation https://lynk.design/components/radio-button
 * @since 1.0.0
 * @status stable
 *
 * @slot - The button's label.
 * @slot prefix - Used to prepend an icon or similar element to the button.
 * @slot suffix - Used to append an icon or similar element to the button.
 *
 * @event ev-blur - Emitted when the button loses focus.
 * @event ev-focus - Emitted when the button gains focus.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart button - The internal button element.
 * @csspart button--checked - The internal button element if checked
 * @csspart prefix - The prefix slot's container.
 * @csspart label - The button's label.
 * @csspart suffix - The suffix slot's container.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvBlur: EventName<LynkBlurEvent>;
    EvFocus: EventName<LynkFocusEvent>;
}>;
export default reactWrapper;
