import Component from '../../components/radio-group/radio-group.component.js';
import { type EventName } from '@lit/react';
import type { LynkChangeEvent } from '../../events/events.js';
import type { LynkInputEvent } from '../../events/events.js';
import type { LynkInvalidEvent } from '../../events/events.js';
export type { LynkChangeEvent } from '../../events/events.js';
export type { LynkInputEvent } from '../../events/events.js';
export type { LynkInvalidEvent } from '../../events/events.js';
/**
 * @summary Radio groups are used to group multiple [radios](/components/radio) or [radio buttons](/components/radio-button) so they function as a single form control.
 * @documentation https://lynk.design/components/radio-group
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-button-group
 * @dependency lynk-tooltip
 *
 * @slot - The default slot where `<lynk-radio>` or `<lynk-radio-button>` elements are placed.
 * @slot help-tip - Custom help-tip content.
 * @slot help-text - Custom help-text content.
 * @slot label - The radio group label. Required for proper accessibility. Alternatively, you can use the label attribute.
 *
 * @event ev-change - Emitted when the radio group's selected value changes.
 * @event ev-input - Emitted when the radio group receives user input.
 * @event ev-invalid - Emitted when the form control has been checked for validity and its constraints aren't satisfied.
 *
 * @csspart form-control - The form control that wraps the label, input, and help-text.
 * @csspart form-control-label - The label's wrapper.
 * @csspart form-control-input - The input's wrapper.
 * @csspart form-control-help-text - The help text's wrapper.
 * @csspart button-group - The button group that wraps radio buttons.
 * @csspart button-group__base - The button group's `base` part.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvChange: EventName<LynkChangeEvent>;
    EvInput: EventName<LynkInputEvent>;
    EvInvalid: EventName<LynkInvalidEvent>;
}>;
export default reactWrapper;
