import Component from '../../components/radio/radio.component.js';
import { type EventName } from '@lit/react';
import type { LynkBlurEvent } from '../../events/events.js';
import type { LynkFocusEvent } from '../../events/events.js';
export type { LynkBlurEvent } from '../../events/events.js';
export type { LynkFocusEvent } from '../../events/events.js';
/**
 * @summary Radios allow the user to select a single option from a group.
 * @documentation https://lynk.design/components/radio
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon
 *
 * @slot - The radio's label.
 *
 * @event ev-blur - Emitted when the control loses focus.
 * @event ev-focus - Emitted when the control gains focus.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart control - The circular container that wraps the radio's checked state.
 * @csspart control--checked - The radio control when the radio is checked.
 * @csspart checked-icon - The checked icon, an `<lynk-icon>` element.
 * @csspart label - The container that wraps the radio's label.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvBlur: EventName<LynkBlurEvent>;
    EvFocus: EventName<LynkFocusEvent>;
}>;
export default reactWrapper;
