import Component from '../../components/select/select.component.js';
import { type EventName } from '@lit/react';
import type { LynkChangeEvent } from '../../events/events.js';
import type { LynkClearEvent } from '../../events/events.js';
import type { LynkInputEvent } from '../../events/events.js';
import type { LynkFocusEvent } from '../../events/events.js';
import type { LynkBlurEvent } from '../../events/events.js';
import type { LynkShowEvent } from '../../events/events.js';
import type { LynkAfterShowEvent } from '../../events/events.js';
import type { LynkHideEvent } from '../../events/events.js';
import type { LynkAfterHideEvent } from '../../events/events.js';
import type { LynkInvalidEvent } from '../../events/events.js';
export type { LynkChangeEvent } from '../../events/events.js';
export type { LynkClearEvent } from '../../events/events.js';
export type { LynkInputEvent } from '../../events/events.js';
export type { LynkFocusEvent } from '../../events/events.js';
export type { LynkBlurEvent } from '../../events/events.js';
export type { LynkShowEvent } from '../../events/events.js';
export type { LynkAfterShowEvent } from '../../events/events.js';
export type { LynkHideEvent } from '../../events/events.js';
export type { LynkAfterHideEvent } from '../../events/events.js';
export type { LynkInvalidEvent } from '../../events/events.js';
/**
 * @summary Selects allow you to choose items from a menu of predefined options.
 * @documentation https://lynk-design/components/select
 * @since 1.0.0
 * @status stable
 *
 * @dependency lynk-icon
 * @dependency lynk-popup
 * @dependency lynk-tag
 *
 * @slot - The listbox options. Must be `<lynk-option>` elements. You can use `<lynk-divider>` to group items visually.
 * @slot label - The input's label. Alternatively, you can use the `label` attribute.
 * @slot prefix - Used to prepend a presentational icon or similar element to the combobox.
 * @slot suffix - Used to append a presentational icon or similar element to the combobox.
 * @slot clear-icon - An icon to use in lieu of the default clear icon.
 * @slot expand-icon - The icon to show when the control is expanded and collapsed. Rotates on open and close.
 * @slot help-text - Text that describes how to use the input. Alternatively, you can use the `help-text` attribute.
 *
 * @event ev-change - Emitted when the control's value changes.
 * @event ev-clear - Emitted when the control's value is cleared.
 * @event ev-input - Emitted when the control receives input.
 * @event ev-focus - Emitted when the control gains focus.
 * @event ev-blur - Emitted when the control loses focus.
 * @event ev-show - Emitted when the select's menu opens.
 * @event ev-after-show - Emitted after the select's menu opens and all animations are complete.
 * @event ev-hide - Emitted when the select's menu closes.
 * @event ev-after-hide - Emitted after the select's menu closes and all animations are complete.
 * @event ev-invalid - Emitted when the form control has been checked for validity and its constraints aren't satisfied.
 *
 * @csspart form-control - The form control that wraps the label, input, and help text.
 * @csspart form-control-label - The label's wrapper.
 * @csspart form-control-input - The select's wrapper.
 * @csspart form-control-help-text - The help text's wrapper.
 * @csspart combobox - The container the wraps the prefix, combobox, clear icon, and expand button.
 * @csspart prefix - The container that wraps the prefix slot.
 * @csspart suffix - The container that wraps the suffix slot.
 * @csspart display-input - The element that displays the selected option's label, an `<input>` element.
 * @csspart listbox - The listbox container where options are slotted.
 * @csspart tags - The container that houses option tags when `multiselect` is used.
 * @csspart tag - The individual tags that represent each multiselect option.
 * @csspart tag__base - The tag's base part.
 * @csspart tag__content - The tag's content part.
 * @csspart tag__remove-button - The tag's remove button.
 * @csspart tag__remove-button__base - The tag's remove button base part.
 * @csspart clear-button - The clear button.
 * @csspart expand-icon - The container that wraps the expand icon.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvChange: EventName<LynkChangeEvent>;
    EvClear: EventName<LynkClearEvent>;
    EvInput: EventName<LynkInputEvent>;
    EvFocus: EventName<LynkFocusEvent>;
    EvBlur: EventName<LynkBlurEvent>;
    EvShow: EventName<LynkShowEvent>;
    EvAfterShow: EventName<LynkAfterShowEvent>;
    EvHide: EventName<LynkHideEvent>;
    EvAfterHide: EventName<LynkAfterHideEvent>;
    EvInvalid: EventName<LynkInvalidEvent>;
}>;
export default reactWrapper;
