import Component from '../../components/switch/switch.component.js';
import { type EventName } from '@lit/react';
import type { LynkBlurEvent } from '../../events/events.js';
import type { LynkChangeEvent } from '../../events/events.js';
import type { LynkInputEvent } from '../../events/events.js';
import type { LynkFocusEvent } from '../../events/events.js';
import type { LynkInvalidEvent } from '../../events/events.js';
export type { LynkBlurEvent } from '../../events/events.js';
export type { LynkChangeEvent } from '../../events/events.js';
export type { LynkInputEvent } from '../../events/events.js';
export type { LynkFocusEvent } from '../../events/events.js';
export type { LynkInvalidEvent } from '../../events/events.js';
/**
 * @summary Switches allow the user to toggle an option on or off.
 * @documentation https://lynk.design/components/switch
 * @since 1.0.0
 * @status stable
 *
 * @slot - The switch's label.
 *
 * @event ev-blur - Emitted when the control loses focus.
 * @event ev-change - Emitted when the control's checked state changes.
 * @event ev-input - Emitted when the control receives input.
 * @event ev-focus - Emitted when the control gains focus.
 * @event ev-invalid - Emitted when the form control has been checked for validity and its constraints aren't satisfied.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart control - The switch control.
 * @csspart thumb - The switch position indicator.
 * @csspart label - The switch label.
 *
 * @cssproperty --width - The width of the switch.
 * @cssproperty --height - The height of the switch.
 * @cssproperty --thumb-size - The size of the thumb.
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvBlur: EventName<LynkBlurEvent>;
    EvChange: EventName<LynkChangeEvent>;
    EvInput: EventName<LynkInputEvent>;
    EvFocus: EventName<LynkFocusEvent>;
    EvInvalid: EventName<LynkInvalidEvent>;
}>;
export default reactWrapper;
