import Component from '../../components/tab-group/tab-group.component.js';
import { type EventName } from '@lit/react';
import type { LynkTabShowEvent } from '../../events/events.js';
import type { LynkTabHideEvent } from '../../events/events.js';
export type { LynkTabShowEvent } from '../../events/events.js';
export type { LynkTabHideEvent } from '../../events/events.js';
/**
 * @summary Tab groups organize content into a container that shows one section at a time.
 * @documentation https://lynk.design/components/tab-group
 * @since 1.0.0
 * @status experimental
 *
 * @dependency lynk-icon-button
 *
 * @slot - Used for grouping tab panels in the tab group. Must be `<lynk-tab-panel>` elements.
 * @slot nav - Used for grouping tabs in the tab group. Must be `<lynk-tab>` elements.
 *
 * @event {{ name: String }} ev-tab-show - Emitted when a tab is shown.
 * @event {{ name: String }} ev-tab-hide - Emitted when a tab is hidden.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart nav - The tab group navigation container.
 * @csspart tabs - The container that wraps the slotted tabs.
 * @csspart active-tab-indicator - The line that highlights the currently selected tab.
 * @csspart body - The tab group body where tab panels are slotted in.
 * @csspart scroll-button - The previous/next scroll buttons that show when tabs are scrollable, an `<lynk-icon-button>`.
 * @csspart scroll-button--start - Targets the starting scroll button.
 * @csspart scroll-button--end - Targets the ending scroll button.
 * @csspart scroll-button__base - The scroll button's `base` part.
 *
 * @cssproperty --indicator-color - The color of the active tab indicator.
 * @cssproperty --track-color - The color of the indicator's track (the line that separates tabs from panels).
 * @cssproperty --track-width - The width of the indicator's track (the line that separates tabs from panels).
 */
declare const reactWrapper: import("@lit/react").ReactWebComponent<Component, {
    EvTabShow: EventName<LynkTabShowEvent>;
    EvTabHide: EventName<LynkTabHideEvent>;
}>;
export default reactWrapper;
