import LynkElement from '../../internal/lynk-element.js';
import LynkIconButton from '../icon-button/icon-button.component.js';
import type { CSSResultGroup } from 'lit';
/**
 * @summary Tabs are used inside [tab groups](/components/tab-group) to represent and activate [tab panels](/components/tab-panel).
 * @documentation https://lynk.design/components/tab
 * @status experimental
 * @since 1.0.0
 *
 * @dependency lynk-icon-button
 *
 * @slot - The tab's label.
 *
 * @event ev-close - Emitted when the tab is closable and the close button is activated.
 *
 * @csspart base - The component's base wrapper.
 * @csspart close-button - The close button, an `<lynk-icon-button>`.
 * @csspart close-button__base - The close button's exported `base` part.
 */
export default class LynkTab extends LynkElement {
    static styles: CSSResultGroup;
    static dependencies: {
        'lynk-icon-button': typeof LynkIconButton;
    };
    private readonly localize;
    private readonly attrId;
    private readonly componentId;
    tab: HTMLElement;
    /** The name of the tab panel this tab is associated with. The panel must be located in the same tab group. */
    panel: string;
    /** Draws the tab in an active state. */
    active: boolean;
    /** Makes the tab closable and shows a close button. */
    closable: boolean;
    /** Disables the tab and prevents selection. */
    disabled: boolean;
    /** When set, the underlying button will be rendered as an `<a>` with this `href` instead of a `<button>`. */
    href: string;
    /**
     * When using `href`, this attribute will map to the underlying link's `rel` attribute. Unlike regular links, the
     * default is `noreferrer noopener` to prevent security exploits. However, if you're using `target` to point to a
     * specific tab/window, this will prevent that from working correctly. You can remove or change the default value by
     * setting the attribute to an empty string or a value of your choice, respectively.
     */
    rel: string;
    connectedCallback(): void;
    private handleCloseClick;
    private isLink;
    handleActiveChange(): void;
    handleDisabledChange(): void;
    /** Sets focus to the tab. */
    focus(options?: FocusOptions): void;
    /** Removes focus from the tab. */
    blur(): void;
    render(): import("lit").TemplateResult;
}
